import { ZodRawShape, objectOutputType, ZodTypeAny, z } from 'zod';

/**
 * A selection of generic utility types
 */

type UnionToIntersection<U> = (U extends any ? (k: U) => void : never) extends (k: infer I) => void ? I : never;
type PromiseOrNot<T> = T | Promise<T>;
/**
 * A better type inference for zod schemas that retains the TSDoc comments
 * from the members in the compiled output.
 */
type zInfer<T extends {
    shape: ZodRawShape;
}> = objectOutputType<T["shape"], ZodTypeAny, "strip">;
type UnwrapPromise<T> = T extends Promise<infer U> ? U : T;

/**
 * Represents a point in world coordinates.
 */
interface LatLng {
    latitude: number;
    longitude: number;
}
/**
 * A tuple representing a longitude and latitude coordinate.
 *
 * This is used hen serializing geometry because that's the standard used in
 * GeoJSON.
 */
type LngLatTuple = [longitude: number, latitude: number];
/**
 * A GeoJSON properties object.
 */
type GeoJsonProperties = Record<string, unknown>;
/**
 * A GeoJSON feature object, compliant with:
 * https://datatracker.ietf.org/doc/html/rfc7946#section-3.2
 *
 * @interface
 */
type GeoJsonFeature = {
    type: "Feature";
    /**
     * The bounding box of the feature in [west, south, east, north] order.
     */
    bbox?: FeltBoundary;
    /**
     * The feature's geometry
     */
    geometry: GeoJsonGeometry;
    /**
     * A value that uniquely identifies this feature in a
     * https://tools.ietf.org/html/rfc7946#section-3.2.
     */
    id?: string | number | undefined;
    /**
     * Properties associated with this feature.
     */
    properties: GeoJsonProperties;
};
interface PointGeometry {
    type: "Point";
    coordinates: LngLatTuple;
}
/**
 * A GeoJSON multi-point geometry.
 *
 * @remarks
 * You shouldn't expect this to come from Felt - it is here for completeness
 * of the GeoJSON spec.
 */
interface MultiPointGeometry {
    type: "MultiPoint";
    coordinates: PointGeometry["coordinates"][];
}
interface PolygonGeometry extends zInfer<typeof PolygonGeometrySchema> {
}
/**
 * A GeoJSON polygon geometry.
 */
declare const PolygonGeometrySchema: z.ZodObject<{
    type: z.ZodLiteral<"Polygon">;
    /**
     * The coordinates of a polygon. The first array is the exterior ring, and
     * any subsequent arrays are the interior rings.
     *
     * Each ring must have at least 4 points: 3 to make a valid triangle and the
     * last to close the path, which must be identical to the first.
     */
    coordinates: z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">;
}, "strip", z.ZodTypeAny, {
    type: "Polygon";
    coordinates: [number, number][][];
}, {
    type: "Polygon";
    coordinates: [number, number][][];
}>;
/**
 * A GeoJSON multi-polygon geometry.
 *
 * @interface
 */
type MultiPolygonGeometry = {
    type: "MultiPolygon";
    coordinates: PolygonGeometry["coordinates"][];
};
/**
 * A GeoJSON line string geometry.
 *
 * @interface
 */
type LineStringGeometry = {
    type: "LineString";
    coordinates: LngLatTuple[];
};
/**
 * A GeoJSON multi-line string geometry.
 *
 * @interface
 */
type MultiLineStringGeometry = {
    type: "MultiLineString";
    coordinates: LineStringGeometry["coordinates"][];
};
/**
 * A GeoJSON geometry of any type
 */
type GeoJsonGeometry = PointGeometry | PolygonGeometry | LineStringGeometry | MultiLineStringGeometry | MultiPolygonGeometry | MultiPointGeometry;
/**
 * @ignore
 * @internal
 */
declare const FeltZoomSchema: z.ZodNumber;
/**
 * The zoom level of the map.
 *
 * It is a floating-point number between 1 and 23, where 1 is the most
 * zoomed out and 23 is the most zoomed in.
 *
 * @group Types
 * @public
 */
type FeltZoom = z.infer<typeof FeltZoomSchema>;
/**
 * @ignore
 * @internal
 */
declare const FeltBoundarySchema: z.ZodTuple<[z.ZodNumber, z.ZodNumber, z.ZodNumber, z.ZodNumber], null>;
/**
 * The edges of the map in the form of a bounding box.
 *
 * The boundary is a tuple of the form `[west, south, east, north]`.
 *
 * @group Types
 * @public
 */
type FeltBoundary = z.infer<typeof FeltBoundarySchema>;
/**
 * The parameters for the methods that change the visibility of entities.
 *
 * @public
 * @category Visibility
 */
interface SetVisibilityRequest extends zInfer<typeof SetVisibilityRequestSchema> {
}
/**
 * @internal
 */
declare const SetVisibilityRequestSchema: z.ZodObject<{
    /**
     * The ids of the entities you want to change the visibility of.
     */
    show: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    hide: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
}, "strip", z.ZodTypeAny, {
    show?: string[] | undefined;
    hide?: string[] | undefined;
}, {
    show?: string[] | undefined;
    hide?: string[] | undefined;
}>;
/**
 * Specifies the direction to sort data in
 *
 * @group Types
 */
type SortDirection = z.infer<typeof SortDirectionSchema>;
/** @ignore */
declare const SortDirectionSchema: z.ZodEnum<["asc", "desc"]>;
/**
 * Configuration for sorting data by a specific attribute
 *
 * @group Types
 */
interface SortConfig extends zInfer<typeof SortConfigSchema> {
    direction: SortDirection;
}
/** @ignore */
declare const SortConfigSchema: z.ZodObject<{
    /**
     * The attribute to sort by. What this represents depends on the context.
     * For instance, when sorting features in a data table, the attribute is
     * the column to sort by.
     */
    attribute: z.ZodString;
    /**
     * The direction to sort in
     */
    direction: z.ZodEnum<["asc", "desc"]>;
}, "strip", z.ZodTypeAny, {
    attribute: string;
    direction: "asc" | "desc";
}, {
    attribute: string;
    direction: "asc" | "desc";
}>;

declare const PlaceCreateSchema: z.ZodObject<Omit<z.objectUtil.extendShape<{
    id: z.ZodOptional<z.ZodString>;
    groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    color: z.ZodOptional<z.ZodString>;
    name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
    imageUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    type: z.ZodOptional<z.ZodLiteral<"Place">>;
    coordinates: z.ZodOptional<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>>;
    symbol: z.ZodOptional<z.ZodString>;
    frame: z.ZodOptional<z.ZodNullable<z.ZodEnum<["frame-circle", "frame-square"]>>>;
    hideLabel: z.ZodOptional<z.ZodBoolean>;
}, Pick<z.objectUtil.extendShape<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    /**
     * The URL of an image that has been added to the element.
     */
    imageUrl: z.ZodNullable<z.ZodString>;
}>, {
    type: z.ZodLiteral<"Place">;
    coordinates: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
    /**
     * The symbol that is rendered for the Place.
     *
     * This can be an emoji by using colon-enclosed characters (e.g. `":smiley:"`)
     * or one of the symbols available in Felt's symbol library.
     *
     * You can see the available symbols in the Felt UI when editing a Place
     * by hovering a symbol and converting the tooltip to kebab-case. For example,
     * the "Oil barrel" symbol is `oil-barrel`.
     */
    symbol: z.ZodString;
    /**
     * The frame that is rendered around the Place's symbol. This is
     * only available for non-emoji symbols.
     */
    frame: z.ZodNullable<z.ZodEnum<["frame-circle", "frame-square"]>>;
    /**
     * Whether the element's label is hidden on the map. This allows you
     * to add a name to the element and can show in popups, but not have
     * it visible on the map.
     *
     * This will also hide the faint placeholder label that is shown when
     * an editable Place is selected.
     *
     * @default false
     */
    hideLabel: z.ZodBoolean;
}>, "type" | "coordinates">>, "id">, "strip", z.ZodTypeAny, {
    type: "Place";
    coordinates: [number, number];
    symbol?: string | undefined;
    groupId?: string | null | undefined;
    color?: string | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    imageUrl?: string | null | undefined;
    frame?: "frame-circle" | "frame-square" | null | undefined;
    hideLabel?: boolean | undefined;
}, {
    type: "Place";
    coordinates: [number, number];
    symbol?: string | undefined;
    groupId?: string | null | undefined;
    color?: string | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    imageUrl?: string | null | undefined;
    frame?: "frame-circle" | "frame-square" | null | undefined;
    hideLabel?: boolean | undefined;
}>;
declare const PathCreateSchema: z.ZodObject<Omit<z.objectUtil.extendShape<{
    id: z.ZodOptional<z.ZodString>;
    groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    color: z.ZodOptional<z.ZodString>;
    name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
    imageUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    strokeOpacity: z.ZodOptional<z.ZodNumber>;
    strokeWidth: z.ZodOptional<z.ZodNumber>;
    strokeStyle: z.ZodOptional<z.ZodEnum<["solid", "dashed", "dotted"]>>;
    type: z.ZodOptional<z.ZodLiteral<"Path">>;
    coordinates: z.ZodOptional<z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">>;
    distanceMarker: z.ZodOptional<z.ZodBoolean>;
    routingMode: z.ZodOptional<z.ZodNullable<z.ZodEnum<["driving", "cycling", "walking", "flying"]>>>;
    endCaps: z.ZodOptional<z.ZodBoolean>;
}, Pick<z.objectUtil.extendShape<z.objectUtil.extendShape<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    /**
     * The URL of an image that has been added to the element.
     */
    imageUrl: z.ZodNullable<z.ZodString>;
}>, {
    /**
     * A value between 0 and 1 that describes the opacity of the element's stroke.
     *
     * @default 1
     */
    strokeOpacity: z.ZodNumber;
    /**
     * The width of the element's stroke in pixels.
     *
     * @default 2
     */
    strokeWidth: z.ZodNumber;
    /**
     * The style of the element's stroke.
     *
     * @default "solid"
     */
    strokeStyle: z.ZodEnum<["solid", "dashed", "dotted"]>;
}>, {
    type: z.ZodLiteral<"Path">;
    coordinates: z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">;
    /**
     * Whether a distance marker is shown at the midpoint of the path.
     *
     * @default false
     */
    distanceMarker: z.ZodBoolean;
    /**
     * Whether this represents a route, and if so, what mode of transport
     * is used.
     *
     * If this is `null`, the path is not considered to be a route, so while it
     * can have a `distanceMarker`, it will does not have a start or end cap.
     *
     * @default null
     */
    routingMode: z.ZodNullable<z.ZodEnum<["driving", "cycling", "walking", "flying"]>>;
    /**
     * Whether or not to show Start and End caps on the path. This is
     * only available if the `routingMode` is set.
     *
     * @default false
     */
    endCaps: z.ZodBoolean;
}>, "type" | "coordinates">>, "id">, "strip", z.ZodTypeAny, {
    type: "Path";
    coordinates: [number, number][][];
    groupId?: string | null | undefined;
    color?: string | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    imageUrl?: string | null | undefined;
    strokeOpacity?: number | undefined;
    strokeWidth?: number | undefined;
    strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
    distanceMarker?: boolean | undefined;
    routingMode?: "driving" | "cycling" | "walking" | "flying" | null | undefined;
    endCaps?: boolean | undefined;
}, {
    type: "Path";
    coordinates: [number, number][][];
    groupId?: string | null | undefined;
    color?: string | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    imageUrl?: string | null | undefined;
    strokeOpacity?: number | undefined;
    strokeWidth?: number | undefined;
    strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
    distanceMarker?: boolean | undefined;
    routingMode?: "driving" | "cycling" | "walking" | "flying" | null | undefined;
    endCaps?: boolean | undefined;
}>;
declare const PolygonCreateSchema: z.ZodObject<Omit<z.objectUtil.extendShape<{
    id: z.ZodOptional<z.ZodString>;
    groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    color: z.ZodOptional<z.ZodString>;
    name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
    imageUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    strokeOpacity: z.ZodOptional<z.ZodNumber>;
    strokeWidth: z.ZodOptional<z.ZodNumber>;
    strokeStyle: z.ZodOptional<z.ZodEnum<["solid", "dashed", "dotted"]>>;
    type: z.ZodOptional<z.ZodLiteral<"Polygon">>;
    coordinates: z.ZodOptional<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">>;
    fillOpacity: z.ZodOptional<z.ZodNumber>;
    areaMarker: z.ZodOptional<z.ZodBoolean>;
}, Pick<z.objectUtil.extendShape<z.objectUtil.extendShape<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    /**
     * The URL of an image that has been added to the element.
     */
    imageUrl: z.ZodNullable<z.ZodString>;
}>, {
    /**
     * A value between 0 and 1 that describes the opacity of the element's stroke.
     *
     * @default 1
     */
    strokeOpacity: z.ZodNumber;
    /**
     * The width of the element's stroke in pixels.
     *
     * @default 2
     */
    strokeWidth: z.ZodNumber;
    /**
     * The style of the element's stroke.
     *
     * @default "solid"
     */
    strokeStyle: z.ZodEnum<["solid", "dashed", "dotted"]>;
}>, {
    type: z.ZodLiteral<"Polygon">;
    coordinates: z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">;
    /**
     * The opacity of the polygon's fill, between 0 and 1.
     *
     * @default 0.25
     */
    fillOpacity: z.ZodNumber;
    /**
     * Whether to show an area marker on the polygon.
     *
     * @default false
     */
    areaMarker: z.ZodBoolean;
}>, "type" | "coordinates">>, "id">, "strip", z.ZodTypeAny, {
    type: "Polygon";
    coordinates: [number, number][][];
    groupId?: string | null | undefined;
    color?: string | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    imageUrl?: string | null | undefined;
    strokeOpacity?: number | undefined;
    strokeWidth?: number | undefined;
    strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
    fillOpacity?: number | undefined;
    areaMarker?: boolean | undefined;
}, {
    type: "Polygon";
    coordinates: [number, number][][];
    groupId?: string | null | undefined;
    color?: string | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    imageUrl?: string | null | undefined;
    strokeOpacity?: number | undefined;
    strokeWidth?: number | undefined;
    strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
    fillOpacity?: number | undefined;
    areaMarker?: boolean | undefined;
}>;
declare const CircleCreateSchema: z.ZodObject<Omit<z.objectUtil.extendShape<{
    id: z.ZodOptional<z.ZodString>;
    groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    color: z.ZodOptional<z.ZodString>;
    name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
    imageUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    strokeOpacity: z.ZodOptional<z.ZodNumber>;
    strokeWidth: z.ZodOptional<z.ZodNumber>;
    strokeStyle: z.ZodOptional<z.ZodEnum<["solid", "dashed", "dotted"]>>;
    type: z.ZodOptional<z.ZodLiteral<"Circle">>;
    center: z.ZodOptional<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>>;
    radius: z.ZodOptional<z.ZodNumber>;
    radiusMarker: z.ZodOptional<z.ZodBoolean>;
    radiusDisplayAngle: z.ZodOptional<z.ZodNumber>;
    radiusDisplayUnit: z.ZodOptional<z.ZodNullable<z.ZodEnum<["meter", "kilometer", "foot", "mile"]>>>;
    fillOpacity: z.ZodOptional<z.ZodNumber>;
}, Pick<z.objectUtil.extendShape<z.objectUtil.extendShape<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    /**
     * The URL of an image that has been added to the element.
     */
    imageUrl: z.ZodNullable<z.ZodString>;
}>, {
    /**
     * A value between 0 and 1 that describes the opacity of the element's stroke.
     *
     * @default 1
     */
    strokeOpacity: z.ZodNumber;
    /**
     * The width of the element's stroke in pixels.
     *
     * @default 2
     */
    strokeWidth: z.ZodNumber;
    /**
     * The style of the element's stroke.
     *
     * @default "solid"
     */
    strokeStyle: z.ZodEnum<["solid", "dashed", "dotted"]>;
}>, {
    type: z.ZodLiteral<"Circle">;
    /**
     * The center of the circle.
     */
    center: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
    /**
     * The radius of the circle in meters.
     */
    radius: z.ZodNumber;
    /**
     * Whether to show a marker on the circle that indicates the radius
     *
     * @default false
     */
    radiusMarker: z.ZodBoolean;
    /**
     * The angle at which the control point for setting the radius is displayed,
     * in degrees. When the `radiusMarker` is `true`, there is a dotted line rendered
     * from the center of the circle to the control point, and the marker is shown
     * at the midpoint of this line.
     *
     * @default 90
     */
    radiusDisplayAngle: z.ZodNumber;
    /**
     * The unit of the radius used when the `radiusMarker` is `true`.
     *
     * A value of `null` means that the unit matches the user's locale.
     *
     * @default null
     */
    radiusDisplayUnit: z.ZodNullable<z.ZodEnum<["meter", "kilometer", "foot", "mile"]>>;
    /**
     * The opacity of the circle's fill.
     *
     * @default 0.25
     */
    fillOpacity: z.ZodNumber;
}>, "type" | "center" | "radius">>, "id">, "strip", z.ZodTypeAny, {
    type: "Circle";
    center: [number, number];
    radius: number;
    groupId?: string | null | undefined;
    color?: string | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    imageUrl?: string | null | undefined;
    strokeOpacity?: number | undefined;
    strokeWidth?: number | undefined;
    strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
    fillOpacity?: number | undefined;
    radiusMarker?: boolean | undefined;
    radiusDisplayAngle?: number | undefined;
    radiusDisplayUnit?: "meter" | "kilometer" | "foot" | "mile" | null | undefined;
}, {
    type: "Circle";
    center: [number, number];
    radius: number;
    groupId?: string | null | undefined;
    color?: string | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    imageUrl?: string | null | undefined;
    strokeOpacity?: number | undefined;
    strokeWidth?: number | undefined;
    strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
    fillOpacity?: number | undefined;
    radiusMarker?: boolean | undefined;
    radiusDisplayAngle?: number | undefined;
    radiusDisplayUnit?: "meter" | "kilometer" | "foot" | "mile" | null | undefined;
}>;
declare const MarkerCreateSchema: z.ZodObject<Omit<z.objectUtil.extendShape<{
    id: z.ZodOptional<z.ZodString>;
    groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    color: z.ZodOptional<z.ZodString>;
    name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
    type: z.ZodOptional<z.ZodLiteral<"Marker">>;
    coordinates: z.ZodOptional<z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">>;
    opacity: z.ZodOptional<z.ZodNumber>;
    size: z.ZodOptional<z.ZodNumber>;
    zoom: z.ZodOptional<z.ZodNumber>;
}, Pick<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    type: z.ZodLiteral<"Marker">;
    coordinates: z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">;
    /**
     * The opacity of the marker, between 0 and 1.
     *
     * @default 1
     */
    opacity: z.ZodNumber;
    /**
     * The size of the marker, used in conjunction with the `zoom` to determine
     * the actual size of the marker.
     *
     * @default 10
     */
    size: z.ZodNumber;
    /**
     * The zoom level at which the marker was created. This is combined with
     * the `size` to determine the actual size of the marker.
     *
     * When creating a marker, if you don't supply this value it defaults to
     * the current zoom of the map when you call `createElement`.
     */
    zoom: z.ZodNumber;
}>, "type" | "coordinates">>, "id">, "strip", z.ZodTypeAny, {
    type: "Marker";
    coordinates: [number, number][][];
    groupId?: string | null | undefined;
    color?: string | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    opacity?: number | undefined;
    size?: number | undefined;
    zoom?: number | undefined;
}, {
    type: "Marker";
    coordinates: [number, number][][];
    groupId?: string | null | undefined;
    color?: string | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    opacity?: number | undefined;
    size?: number | undefined;
    zoom?: number | undefined;
}>;
declare const HighlighterCreateSchema: z.ZodObject<Omit<z.objectUtil.extendShape<{
    id: z.ZodOptional<z.ZodString>;
    groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    color: z.ZodOptional<z.ZodString>;
    name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
    type: z.ZodOptional<z.ZodLiteral<"Highlighter">>;
    coordinates: z.ZodOptional<z.ZodArray<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">, "many">>;
    renderHoles: z.ZodOptional<z.ZodBoolean>;
    opacity: z.ZodOptional<z.ZodNumber>;
}, Pick<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    type: z.ZodLiteral<"Highlighter">;
    /**
     * A multipolygon describing the area that is highlighted.
     *
     * If `renderHoles` is set to false, only the outer ring of each polygon
     * will be rendered, filling in the area inside the highlighted region.
     */
    coordinates: z.ZodArray<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">, "many">;
    /**
     * Whether to render the holes of the highlighted area.
     *
     * @default false
     */
    renderHoles: z.ZodBoolean;
    /**
     * The opacity of the highlighter, between 0 and 1.
     *
     * @default 0.5
     */
    opacity: z.ZodNumber;
}>, "type" | "coordinates">>, "id">, "strip", z.ZodTypeAny, {
    type: "Highlighter";
    coordinates: [number, number][][][];
    groupId?: string | null | undefined;
    color?: string | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    opacity?: number | undefined;
    renderHoles?: boolean | undefined;
}, {
    type: "Highlighter";
    coordinates: [number, number][][][];
    groupId?: string | null | undefined;
    color?: string | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    opacity?: number | undefined;
    renderHoles?: boolean | undefined;
}>;
declare const TextCreateSchema: z.ZodObject<z.objectUtil.extendShape<Omit<{
    id: z.ZodOptional<z.ZodString>;
    groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    color: z.ZodOptional<z.ZodString>;
    description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
    position: z.ZodOptional<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>>;
    rotation: z.ZodOptional<z.ZodNumber>;
    scale: z.ZodOptional<z.ZodNumber>;
    zoom: z.ZodOptional<z.ZodNumber>;
    text: z.ZodOptional<z.ZodString>;
    align: z.ZodOptional<z.ZodEnum<["left", "center", "right"]>>;
    style: z.ZodOptional<z.ZodEnum<["italic", "light", "regular", "caps"]>>;
    name: z.ZodOptional<z.ZodString>;
    type: z.ZodOptional<z.ZodLiteral<"Text">>;
}, "type" | "id" | "name">, {
    type: z.ZodLiteral<"Text">;
    text: z.ZodString;
}>, "strip", z.ZodTypeAny, {
    type: "Text";
    text: string;
    groupId?: string | null | undefined;
    color?: string | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    zoom?: number | undefined;
    position?: [number, number] | undefined;
    rotation?: number | undefined;
    scale?: number | undefined;
    align?: "center" | "left" | "right" | undefined;
    style?: "italic" | "light" | "regular" | "caps" | undefined;
}, {
    type: "Text";
    text: string;
    groupId?: string | null | undefined;
    color?: string | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    zoom?: number | undefined;
    position?: [number, number] | undefined;
    rotation?: number | undefined;
    scale?: number | undefined;
    align?: "center" | "left" | "right" | undefined;
    style?: "italic" | "light" | "regular" | "caps" | undefined;
}>;
declare const NoteCreateSchema: z.ZodObject<z.objectUtil.extendShape<Omit<{
    id: z.ZodOptional<z.ZodString>;
    groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    color: z.ZodOptional<z.ZodString>;
    description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
    position: z.ZodOptional<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>>;
    rotation: z.ZodOptional<z.ZodNumber>;
    scale: z.ZodOptional<z.ZodNumber>;
    zoom: z.ZodOptional<z.ZodNumber>;
    text: z.ZodOptional<z.ZodString>;
    align: z.ZodOptional<z.ZodEnum<["left", "center", "right"]>>;
    style: z.ZodOptional<z.ZodEnum<["italic", "light", "regular", "caps"]>>;
    name: z.ZodOptional<z.ZodString>;
    type: z.ZodOptional<z.ZodLiteral<"Note">>;
    widthScale: z.ZodOptional<z.ZodNumber>;
}, "type" | "id" | "name">, {
    type: z.ZodLiteral<"Note">;
    text: z.ZodString;
}>, "strip", z.ZodTypeAny, {
    type: "Note";
    text: string;
    groupId?: string | null | undefined;
    color?: string | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    zoom?: number | undefined;
    position?: [number, number] | undefined;
    rotation?: number | undefined;
    scale?: number | undefined;
    align?: "center" | "left" | "right" | undefined;
    style?: "italic" | "light" | "regular" | "caps" | undefined;
    widthScale?: number | undefined;
}, {
    type: "Note";
    text: string;
    groupId?: string | null | undefined;
    color?: string | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    zoom?: number | undefined;
    position?: [number, number] | undefined;
    rotation?: number | undefined;
    scale?: number | undefined;
    align?: "center" | "left" | "right" | undefined;
    style?: "italic" | "light" | "regular" | "caps" | undefined;
    widthScale?: number | undefined;
}>;
declare const ImageCreateSchema: z.ZodObject<Omit<z.objectUtil.extendShape<{
    type: z.ZodOptional<z.ZodLiteral<"Image">>;
    coordinates: z.ZodOptional<z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">>;
    id: z.ZodOptional<z.ZodString>;
    groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
    imageUrl: z.ZodOptional<z.ZodString>;
    opacity: z.ZodOptional<z.ZodNumber>;
}, Pick<Omit<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    type: z.ZodLiteral<"Image">;
    coordinates: z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">;
    /**
     * The URL of the image that is rendered in this element
     */
    imageUrl: z.ZodString;
    /**
     * The opacity of the image, between 0 and 1.
     *
     * @default 1
     */
    opacity: z.ZodNumber;
}>, "color">, "type" | "coordinates" | "imageUrl">>, "id">, "strip", z.ZodTypeAny, {
    type: "Image";
    coordinates: [number, number][][];
    imageUrl: string;
    groupId?: string | null | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    opacity?: number | undefined;
}, {
    type: "Image";
    coordinates: [number, number][][];
    imageUrl: string;
    groupId?: string | null | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    opacity?: number | undefined;
}>;
declare const PlaceReadSchema: z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    /**
     * The URL of an image that has been added to the element.
     */
    imageUrl: z.ZodNullable<z.ZodString>;
}>, {
    type: z.ZodLiteral<"Place">;
    coordinates: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
    /**
     * The symbol that is rendered for the Place.
     *
     * This can be an emoji by using colon-enclosed characters (e.g. `":smiley:"`)
     * or one of the symbols available in Felt's symbol library.
     *
     * You can see the available symbols in the Felt UI when editing a Place
     * by hovering a symbol and converting the tooltip to kebab-case. For example,
     * the "Oil barrel" symbol is `oil-barrel`.
     */
    symbol: z.ZodString;
    /**
     * The frame that is rendered around the Place's symbol. This is
     * only available for non-emoji symbols.
     */
    frame: z.ZodNullable<z.ZodEnum<["frame-circle", "frame-square"]>>;
    /**
     * Whether the element's label is hidden on the map. This allows you
     * to add a name to the element and can show in popups, but not have
     * it visible on the map.
     *
     * This will also hide the faint placeholder label that is shown when
     * an editable Place is selected.
     *
     * @default false
     */
    hideLabel: z.ZodBoolean;
}>, "strip", z.ZodTypeAny, {
    symbol: string;
    type: "Place";
    coordinates: [number, number];
    id: string;
    groupId: string | null;
    color: string;
    name: string | null;
    description: string | null;
    attributes: Record<string, unknown>;
    imageUrl: string | null;
    frame: "frame-circle" | "frame-square" | null;
    hideLabel: boolean;
    interaction?: "default" | "locked" | undefined;
}, {
    symbol: string;
    type: "Place";
    coordinates: [number, number];
    id: string;
    groupId: string | null;
    color: string;
    name: string | null;
    description: string | null;
    attributes: Record<string, unknown>;
    imageUrl: string | null;
    frame: "frame-circle" | "frame-square" | null;
    hideLabel: boolean;
    interaction?: "default" | "locked" | undefined;
}>;
declare const PathReadSchema: z.ZodObject<Omit<z.objectUtil.extendShape<z.objectUtil.extendShape<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    /**
     * The URL of an image that has been added to the element.
     */
    imageUrl: z.ZodNullable<z.ZodString>;
}>, {
    /**
     * A value between 0 and 1 that describes the opacity of the element's stroke.
     *
     * @default 1
     */
    strokeOpacity: z.ZodNumber;
    /**
     * The width of the element's stroke in pixels.
     *
     * @default 2
     */
    strokeWidth: z.ZodNumber;
    /**
     * The style of the element's stroke.
     *
     * @default "solid"
     */
    strokeStyle: z.ZodEnum<["solid", "dashed", "dotted"]>;
}>, {
    type: z.ZodLiteral<"Path">;
    coordinates: z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">;
    /**
     * Whether a distance marker is shown at the midpoint of the path.
     *
     * @default false
     */
    distanceMarker: z.ZodBoolean;
    /**
     * Whether this represents a route, and if so, what mode of transport
     * is used.
     *
     * If this is `null`, the path is not considered to be a route, so while it
     * can have a `distanceMarker`, it will does not have a start or end cap.
     *
     * @default null
     */
    routingMode: z.ZodNullable<z.ZodEnum<["driving", "cycling", "walking", "flying"]>>;
    /**
     * Whether or not to show Start and End caps on the path. This is
     * only available if the `routingMode` is set.
     *
     * @default false
     */
    endCaps: z.ZodBoolean;
}>, "coordinates">, "strip", z.ZodTypeAny, {
    type: "Path";
    id: string;
    groupId: string | null;
    color: string;
    name: string | null;
    description: string | null;
    attributes: Record<string, unknown>;
    imageUrl: string | null;
    strokeOpacity: number;
    strokeWidth: number;
    strokeStyle: "solid" | "dashed" | "dotted";
    distanceMarker: boolean;
    routingMode: "driving" | "cycling" | "walking" | "flying" | null;
    endCaps: boolean;
    interaction?: "default" | "locked" | undefined;
}, {
    type: "Path";
    id: string;
    groupId: string | null;
    color: string;
    name: string | null;
    description: string | null;
    attributes: Record<string, unknown>;
    imageUrl: string | null;
    strokeOpacity: number;
    strokeWidth: number;
    strokeStyle: "solid" | "dashed" | "dotted";
    distanceMarker: boolean;
    routingMode: "driving" | "cycling" | "walking" | "flying" | null;
    endCaps: boolean;
    interaction?: "default" | "locked" | undefined;
}>;
declare const PolygonReadSchema: z.ZodObject<Omit<z.objectUtil.extendShape<z.objectUtil.extendShape<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    /**
     * The URL of an image that has been added to the element.
     */
    imageUrl: z.ZodNullable<z.ZodString>;
}>, {
    /**
     * A value between 0 and 1 that describes the opacity of the element's stroke.
     *
     * @default 1
     */
    strokeOpacity: z.ZodNumber;
    /**
     * The width of the element's stroke in pixels.
     *
     * @default 2
     */
    strokeWidth: z.ZodNumber;
    /**
     * The style of the element's stroke.
     *
     * @default "solid"
     */
    strokeStyle: z.ZodEnum<["solid", "dashed", "dotted"]>;
}>, {
    type: z.ZodLiteral<"Polygon">;
    coordinates: z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">;
    /**
     * The opacity of the polygon's fill, between 0 and 1.
     *
     * @default 0.25
     */
    fillOpacity: z.ZodNumber;
    /**
     * Whether to show an area marker on the polygon.
     *
     * @default false
     */
    areaMarker: z.ZodBoolean;
}>, "coordinates">, "strip", z.ZodTypeAny, {
    type: "Polygon";
    id: string;
    groupId: string | null;
    color: string;
    name: string | null;
    description: string | null;
    attributes: Record<string, unknown>;
    imageUrl: string | null;
    strokeOpacity: number;
    strokeWidth: number;
    strokeStyle: "solid" | "dashed" | "dotted";
    fillOpacity: number;
    areaMarker: boolean;
    interaction?: "default" | "locked" | undefined;
}, {
    type: "Polygon";
    id: string;
    groupId: string | null;
    color: string;
    name: string | null;
    description: string | null;
    attributes: Record<string, unknown>;
    imageUrl: string | null;
    strokeOpacity: number;
    strokeWidth: number;
    strokeStyle: "solid" | "dashed" | "dotted";
    fillOpacity: number;
    areaMarker: boolean;
    interaction?: "default" | "locked" | undefined;
}>;
declare const CircleReadSchema: z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    /**
     * The URL of an image that has been added to the element.
     */
    imageUrl: z.ZodNullable<z.ZodString>;
}>, {
    /**
     * A value between 0 and 1 that describes the opacity of the element's stroke.
     *
     * @default 1
     */
    strokeOpacity: z.ZodNumber;
    /**
     * The width of the element's stroke in pixels.
     *
     * @default 2
     */
    strokeWidth: z.ZodNumber;
    /**
     * The style of the element's stroke.
     *
     * @default "solid"
     */
    strokeStyle: z.ZodEnum<["solid", "dashed", "dotted"]>;
}>, {
    type: z.ZodLiteral<"Circle">;
    /**
     * The center of the circle.
     */
    center: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
    /**
     * The radius of the circle in meters.
     */
    radius: z.ZodNumber;
    /**
     * Whether to show a marker on the circle that indicates the radius
     *
     * @default false
     */
    radiusMarker: z.ZodBoolean;
    /**
     * The angle at which the control point for setting the radius is displayed,
     * in degrees. When the `radiusMarker` is `true`, there is a dotted line rendered
     * from the center of the circle to the control point, and the marker is shown
     * at the midpoint of this line.
     *
     * @default 90
     */
    radiusDisplayAngle: z.ZodNumber;
    /**
     * The unit of the radius used when the `radiusMarker` is `true`.
     *
     * A value of `null` means that the unit matches the user's locale.
     *
     * @default null
     */
    radiusDisplayUnit: z.ZodNullable<z.ZodEnum<["meter", "kilometer", "foot", "mile"]>>;
    /**
     * The opacity of the circle's fill.
     *
     * @default 0.25
     */
    fillOpacity: z.ZodNumber;
}>, "strip", z.ZodTypeAny, {
    type: "Circle";
    id: string;
    groupId: string | null;
    color: string;
    name: string | null;
    description: string | null;
    attributes: Record<string, unknown>;
    imageUrl: string | null;
    strokeOpacity: number;
    strokeWidth: number;
    strokeStyle: "solid" | "dashed" | "dotted";
    fillOpacity: number;
    center: [number, number];
    radius: number;
    radiusMarker: boolean;
    radiusDisplayAngle: number;
    radiusDisplayUnit: "meter" | "kilometer" | "foot" | "mile" | null;
    interaction?: "default" | "locked" | undefined;
}, {
    type: "Circle";
    id: string;
    groupId: string | null;
    color: string;
    name: string | null;
    description: string | null;
    attributes: Record<string, unknown>;
    imageUrl: string | null;
    strokeOpacity: number;
    strokeWidth: number;
    strokeStyle: "solid" | "dashed" | "dotted";
    fillOpacity: number;
    center: [number, number];
    radius: number;
    radiusMarker: boolean;
    radiusDisplayAngle: number;
    radiusDisplayUnit: "meter" | "kilometer" | "foot" | "mile" | null;
    interaction?: "default" | "locked" | undefined;
}>;
declare const MarkerReadSchema: z.ZodObject<Omit<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    type: z.ZodLiteral<"Marker">;
    coordinates: z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">;
    /**
     * The opacity of the marker, between 0 and 1.
     *
     * @default 1
     */
    opacity: z.ZodNumber;
    /**
     * The size of the marker, used in conjunction with the `zoom` to determine
     * the actual size of the marker.
     *
     * @default 10
     */
    size: z.ZodNumber;
    /**
     * The zoom level at which the marker was created. This is combined with
     * the `size` to determine the actual size of the marker.
     *
     * When creating a marker, if you don't supply this value it defaults to
     * the current zoom of the map when you call `createElement`.
     */
    zoom: z.ZodNumber;
}>, "coordinates">, "strip", z.ZodTypeAny, {
    type: "Marker";
    id: string;
    groupId: string | null;
    color: string;
    name: string | null;
    description: string | null;
    attributes: Record<string, unknown>;
    opacity: number;
    size: number;
    zoom: number;
    interaction?: "default" | "locked" | undefined;
}, {
    type: "Marker";
    id: string;
    groupId: string | null;
    color: string;
    name: string | null;
    description: string | null;
    attributes: Record<string, unknown>;
    opacity: number;
    size: number;
    zoom: number;
    interaction?: "default" | "locked" | undefined;
}>;
declare const HighlighterReadSchema: z.ZodObject<Omit<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    type: z.ZodLiteral<"Highlighter">;
    /**
     * A multipolygon describing the area that is highlighted.
     *
     * If `renderHoles` is set to false, only the outer ring of each polygon
     * will be rendered, filling in the area inside the highlighted region.
     */
    coordinates: z.ZodArray<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">, "many">;
    /**
     * Whether to render the holes of the highlighted area.
     *
     * @default false
     */
    renderHoles: z.ZodBoolean;
    /**
     * The opacity of the highlighter, between 0 and 1.
     *
     * @default 0.5
     */
    opacity: z.ZodNumber;
}>, "coordinates">, "strip", z.ZodTypeAny, {
    type: "Highlighter";
    id: string;
    groupId: string | null;
    color: string;
    name: string | null;
    description: string | null;
    attributes: Record<string, unknown>;
    opacity: number;
    renderHoles: boolean;
    interaction?: "default" | "locked" | undefined;
}, {
    type: "Highlighter";
    id: string;
    groupId: string | null;
    color: string;
    name: string | null;
    description: string | null;
    attributes: Record<string, unknown>;
    opacity: number;
    renderHoles: boolean;
    interaction?: "default" | "locked" | undefined;
}>;
declare const TextReadSchema: z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    /**
     * The geographical position of the center of the element.
     */
    position: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
    /**
     * The rotation of the element in degrees.
     *
     * @default 0
     */
    rotation: z.ZodNumber;
    /**
     * The relative scale of the element from the default size. This is combined
     * with the `zoom` to determine the actual size of the element.
     *
     * @default 1
     */
    scale: z.ZodNumber;
    /**
     * The zoom level at which the element was created. This is combined with
     * the `scale` to determine the actual size of the element.
     *
     * When creating an element, if you don't supply this value it defaults to
     * the current zoom of the map when you call `createElement`.
     */
    zoom: z.ZodNumber;
    /**
     * The text in the element.
     */
    text: z.ZodString;
    /**
     * The alignment of the text, either `left`, `center` or `right`.
     *
     * @default "center"
     */
    align: z.ZodEnum<["left", "center", "right"]>;
    /**
     * The style of the text, either `italic`, `light`, `regular` or `caps`.
     *
     * @default "regular"
     */
    style: z.ZodEnum<["italic", "light", "regular", "caps"]>;
    /**
     * The text shown in the element, which is identical to the `text` property.
     *
     * @remarks This is added for consistency with other elements that have a `name`
     * property.
     */
    name: z.ZodString;
}>, {
    type: z.ZodLiteral<"Text">;
}>, "strip", z.ZodTypeAny, {
    type: "Text";
    id: string;
    groupId: string | null;
    color: string;
    name: string;
    description: string | null;
    attributes: Record<string, unknown>;
    zoom: number;
    position: [number, number];
    rotation: number;
    scale: number;
    text: string;
    align: "center" | "left" | "right";
    style: "italic" | "light" | "regular" | "caps";
    interaction?: "default" | "locked" | undefined;
}, {
    type: "Text";
    id: string;
    groupId: string | null;
    color: string;
    name: string;
    description: string | null;
    attributes: Record<string, unknown>;
    zoom: number;
    position: [number, number];
    rotation: number;
    scale: number;
    text: string;
    align: "center" | "left" | "right";
    style: "italic" | "light" | "regular" | "caps";
    interaction?: "default" | "locked" | undefined;
}>;
declare const NoteReadSchema: z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    /**
     * The geographical position of the center of the element.
     */
    position: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
    /**
     * The rotation of the element in degrees.
     *
     * @default 0
     */
    rotation: z.ZodNumber;
    /**
     * The relative scale of the element from the default size. This is combined
     * with the `zoom` to determine the actual size of the element.
     *
     * @default 1
     */
    scale: z.ZodNumber;
    /**
     * The zoom level at which the element was created. This is combined with
     * the `scale` to determine the actual size of the element.
     *
     * When creating an element, if you don't supply this value it defaults to
     * the current zoom of the map when you call `createElement`.
     */
    zoom: z.ZodNumber;
    /**
     * The text in the element.
     */
    text: z.ZodString;
    /**
     * The alignment of the text, either `left`, `center` or `right`.
     *
     * @default "center"
     */
    align: z.ZodEnum<["left", "center", "right"]>;
    /**
     * The style of the text, either `italic`, `light`, `regular` or `caps`.
     *
     * @default "regular"
     */
    style: z.ZodEnum<["italic", "light", "regular", "caps"]>;
    /**
     * The text shown in the element, which is identical to the `text` property.
     *
     * @remarks This is added for consistency with other elements that have a `name`
     * property.
     */
    name: z.ZodString;
}>, {
    type: z.ZodLiteral<"Note">;
    widthScale: z.ZodNumber;
}>, "strip", z.ZodTypeAny, {
    type: "Note";
    id: string;
    groupId: string | null;
    color: string;
    name: string;
    description: string | null;
    attributes: Record<string, unknown>;
    zoom: number;
    position: [number, number];
    rotation: number;
    scale: number;
    text: string;
    align: "center" | "left" | "right";
    style: "italic" | "light" | "regular" | "caps";
    widthScale: number;
    interaction?: "default" | "locked" | undefined;
}, {
    type: "Note";
    id: string;
    groupId: string | null;
    color: string;
    name: string;
    description: string | null;
    attributes: Record<string, unknown>;
    zoom: number;
    position: [number, number];
    rotation: number;
    scale: number;
    text: string;
    align: "center" | "left" | "right";
    style: "italic" | "light" | "regular" | "caps";
    widthScale: number;
    interaction?: "default" | "locked" | undefined;
}>;
declare const ImageReadSchema: z.ZodObject<Omit<Omit<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    type: z.ZodLiteral<"Image">;
    coordinates: z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">;
    /**
     * The URL of the image that is rendered in this element
     */
    imageUrl: z.ZodString;
    /**
     * The opacity of the image, between 0 and 1.
     *
     * @default 1
     */
    opacity: z.ZodNumber;
}>, "color">, "coordinates">, "strip", z.ZodTypeAny, {
    type: "Image";
    id: string;
    groupId: string | null;
    name: string | null;
    description: string | null;
    attributes: Record<string, unknown>;
    imageUrl: string;
    opacity: number;
    interaction?: "default" | "locked" | undefined;
}, {
    type: "Image";
    id: string;
    groupId: string | null;
    name: string | null;
    description: string | null;
    attributes: Record<string, unknown>;
    imageUrl: string;
    opacity: number;
    interaction?: "default" | "locked" | undefined;
}>;
declare const LinkReadSchema: z.ZodObject<Omit<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    type: z.ZodLiteral<"Link">;
    coordinates: z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">;
    /**
     * The URL of the link that is rendered in this element.
     */
    url: z.ZodString;
}>, "coordinates">, "strip", z.ZodTypeAny, {
    type: "Link";
    id: string;
    groupId: string | null;
    color: string;
    name: string | null;
    description: string | null;
    attributes: Record<string, unknown>;
    url: string;
    interaction?: "default" | "locked" | undefined;
}, {
    type: "Link";
    id: string;
    groupId: string | null;
    color: string;
    name: string | null;
    description: string | null;
    attributes: Record<string, unknown>;
    url: string;
    interaction?: "default" | "locked" | undefined;
}>;
declare const PlaceUpdateSchema: z.ZodObject<z.objectUtil.extendShape<{
    id: z.ZodOptional<z.ZodString>;
    groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    color: z.ZodOptional<z.ZodString>;
    name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
    imageUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    type: z.ZodOptional<z.ZodLiteral<"Place">>;
    coordinates: z.ZodOptional<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>>;
    symbol: z.ZodOptional<z.ZodString>;
    frame: z.ZodOptional<z.ZodNullable<z.ZodEnum<["frame-circle", "frame-square"]>>>;
    hideLabel: z.ZodOptional<z.ZodBoolean>;
}, Pick<z.objectUtil.extendShape<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    /**
     * The URL of an image that has been added to the element.
     */
    imageUrl: z.ZodNullable<z.ZodString>;
}>, {
    type: z.ZodLiteral<"Place">;
    coordinates: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
    /**
     * The symbol that is rendered for the Place.
     *
     * This can be an emoji by using colon-enclosed characters (e.g. `":smiley:"`)
     * or one of the symbols available in Felt's symbol library.
     *
     * You can see the available symbols in the Felt UI when editing a Place
     * by hovering a symbol and converting the tooltip to kebab-case. For example,
     * the "Oil barrel" symbol is `oil-barrel`.
     */
    symbol: z.ZodString;
    /**
     * The frame that is rendered around the Place's symbol. This is
     * only available for non-emoji symbols.
     */
    frame: z.ZodNullable<z.ZodEnum<["frame-circle", "frame-square"]>>;
    /**
     * Whether the element's label is hidden on the map. This allows you
     * to add a name to the element and can show in popups, but not have
     * it visible on the map.
     *
     * This will also hide the faint placeholder label that is shown when
     * an editable Place is selected.
     *
     * @default false
     */
    hideLabel: z.ZodBoolean;
}>, "type" | "id">>, "strip", z.ZodTypeAny, {
    type: "Place";
    id: string;
    symbol?: string | undefined;
    coordinates?: [number, number] | undefined;
    groupId?: string | null | undefined;
    color?: string | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    imageUrl?: string | null | undefined;
    frame?: "frame-circle" | "frame-square" | null | undefined;
    hideLabel?: boolean | undefined;
}, {
    type: "Place";
    id: string;
    symbol?: string | undefined;
    coordinates?: [number, number] | undefined;
    groupId?: string | null | undefined;
    color?: string | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    imageUrl?: string | null | undefined;
    frame?: "frame-circle" | "frame-square" | null | undefined;
    hideLabel?: boolean | undefined;
}>;
declare const PathUpdateSchema: z.ZodObject<z.objectUtil.extendShape<{
    id: z.ZodOptional<z.ZodString>;
    groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    color: z.ZodOptional<z.ZodString>;
    name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
    imageUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    strokeOpacity: z.ZodOptional<z.ZodNumber>;
    strokeWidth: z.ZodOptional<z.ZodNumber>;
    strokeStyle: z.ZodOptional<z.ZodEnum<["solid", "dashed", "dotted"]>>;
    type: z.ZodOptional<z.ZodLiteral<"Path">>;
    coordinates: z.ZodOptional<z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">>;
    distanceMarker: z.ZodOptional<z.ZodBoolean>;
    routingMode: z.ZodOptional<z.ZodNullable<z.ZodEnum<["driving", "cycling", "walking", "flying"]>>>;
    endCaps: z.ZodOptional<z.ZodBoolean>;
}, Pick<z.objectUtil.extendShape<z.objectUtil.extendShape<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    /**
     * The URL of an image that has been added to the element.
     */
    imageUrl: z.ZodNullable<z.ZodString>;
}>, {
    /**
     * A value between 0 and 1 that describes the opacity of the element's stroke.
     *
     * @default 1
     */
    strokeOpacity: z.ZodNumber;
    /**
     * The width of the element's stroke in pixels.
     *
     * @default 2
     */
    strokeWidth: z.ZodNumber;
    /**
     * The style of the element's stroke.
     *
     * @default "solid"
     */
    strokeStyle: z.ZodEnum<["solid", "dashed", "dotted"]>;
}>, {
    type: z.ZodLiteral<"Path">;
    coordinates: z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">;
    /**
     * Whether a distance marker is shown at the midpoint of the path.
     *
     * @default false
     */
    distanceMarker: z.ZodBoolean;
    /**
     * Whether this represents a route, and if so, what mode of transport
     * is used.
     *
     * If this is `null`, the path is not considered to be a route, so while it
     * can have a `distanceMarker`, it will does not have a start or end cap.
     *
     * @default null
     */
    routingMode: z.ZodNullable<z.ZodEnum<["driving", "cycling", "walking", "flying"]>>;
    /**
     * Whether or not to show Start and End caps on the path. This is
     * only available if the `routingMode` is set.
     *
     * @default false
     */
    endCaps: z.ZodBoolean;
}>, "type" | "id">>, "strip", z.ZodTypeAny, {
    type: "Path";
    id: string;
    coordinates?: [number, number][][] | undefined;
    groupId?: string | null | undefined;
    color?: string | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    imageUrl?: string | null | undefined;
    strokeOpacity?: number | undefined;
    strokeWidth?: number | undefined;
    strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
    distanceMarker?: boolean | undefined;
    routingMode?: "driving" | "cycling" | "walking" | "flying" | null | undefined;
    endCaps?: boolean | undefined;
}, {
    type: "Path";
    id: string;
    coordinates?: [number, number][][] | undefined;
    groupId?: string | null | undefined;
    color?: string | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    imageUrl?: string | null | undefined;
    strokeOpacity?: number | undefined;
    strokeWidth?: number | undefined;
    strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
    distanceMarker?: boolean | undefined;
    routingMode?: "driving" | "cycling" | "walking" | "flying" | null | undefined;
    endCaps?: boolean | undefined;
}>;
declare const PolygonUpdateSchema: z.ZodObject<z.objectUtil.extendShape<{
    id: z.ZodOptional<z.ZodString>;
    groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    color: z.ZodOptional<z.ZodString>;
    name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
    imageUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    strokeOpacity: z.ZodOptional<z.ZodNumber>;
    strokeWidth: z.ZodOptional<z.ZodNumber>;
    strokeStyle: z.ZodOptional<z.ZodEnum<["solid", "dashed", "dotted"]>>;
    type: z.ZodOptional<z.ZodLiteral<"Polygon">>;
    coordinates: z.ZodOptional<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">>;
    fillOpacity: z.ZodOptional<z.ZodNumber>;
    areaMarker: z.ZodOptional<z.ZodBoolean>;
}, Pick<z.objectUtil.extendShape<z.objectUtil.extendShape<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    /**
     * The URL of an image that has been added to the element.
     */
    imageUrl: z.ZodNullable<z.ZodString>;
}>, {
    /**
     * A value between 0 and 1 that describes the opacity of the element's stroke.
     *
     * @default 1
     */
    strokeOpacity: z.ZodNumber;
    /**
     * The width of the element's stroke in pixels.
     *
     * @default 2
     */
    strokeWidth: z.ZodNumber;
    /**
     * The style of the element's stroke.
     *
     * @default "solid"
     */
    strokeStyle: z.ZodEnum<["solid", "dashed", "dotted"]>;
}>, {
    type: z.ZodLiteral<"Polygon">;
    coordinates: z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">;
    /**
     * The opacity of the polygon's fill, between 0 and 1.
     *
     * @default 0.25
     */
    fillOpacity: z.ZodNumber;
    /**
     * Whether to show an area marker on the polygon.
     *
     * @default false
     */
    areaMarker: z.ZodBoolean;
}>, "type" | "id">>, "strip", z.ZodTypeAny, {
    type: "Polygon";
    id: string;
    coordinates?: [number, number][][] | undefined;
    groupId?: string | null | undefined;
    color?: string | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    imageUrl?: string | null | undefined;
    strokeOpacity?: number | undefined;
    strokeWidth?: number | undefined;
    strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
    fillOpacity?: number | undefined;
    areaMarker?: boolean | undefined;
}, {
    type: "Polygon";
    id: string;
    coordinates?: [number, number][][] | undefined;
    groupId?: string | null | undefined;
    color?: string | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    imageUrl?: string | null | undefined;
    strokeOpacity?: number | undefined;
    strokeWidth?: number | undefined;
    strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
    fillOpacity?: number | undefined;
    areaMarker?: boolean | undefined;
}>;
declare const CircleUpdateSchema: z.ZodObject<z.objectUtil.extendShape<{
    id: z.ZodOptional<z.ZodString>;
    groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    color: z.ZodOptional<z.ZodString>;
    name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
    imageUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    strokeOpacity: z.ZodOptional<z.ZodNumber>;
    strokeWidth: z.ZodOptional<z.ZodNumber>;
    strokeStyle: z.ZodOptional<z.ZodEnum<["solid", "dashed", "dotted"]>>;
    type: z.ZodOptional<z.ZodLiteral<"Circle">>;
    center: z.ZodOptional<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>>;
    radius: z.ZodOptional<z.ZodNumber>;
    radiusMarker: z.ZodOptional<z.ZodBoolean>;
    radiusDisplayAngle: z.ZodOptional<z.ZodNumber>;
    radiusDisplayUnit: z.ZodOptional<z.ZodNullable<z.ZodEnum<["meter", "kilometer", "foot", "mile"]>>>;
    fillOpacity: z.ZodOptional<z.ZodNumber>;
}, Pick<z.objectUtil.extendShape<z.objectUtil.extendShape<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    /**
     * The URL of an image that has been added to the element.
     */
    imageUrl: z.ZodNullable<z.ZodString>;
}>, {
    /**
     * A value between 0 and 1 that describes the opacity of the element's stroke.
     *
     * @default 1
     */
    strokeOpacity: z.ZodNumber;
    /**
     * The width of the element's stroke in pixels.
     *
     * @default 2
     */
    strokeWidth: z.ZodNumber;
    /**
     * The style of the element's stroke.
     *
     * @default "solid"
     */
    strokeStyle: z.ZodEnum<["solid", "dashed", "dotted"]>;
}>, {
    type: z.ZodLiteral<"Circle">;
    /**
     * The center of the circle.
     */
    center: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
    /**
     * The radius of the circle in meters.
     */
    radius: z.ZodNumber;
    /**
     * Whether to show a marker on the circle that indicates the radius
     *
     * @default false
     */
    radiusMarker: z.ZodBoolean;
    /**
     * The angle at which the control point for setting the radius is displayed,
     * in degrees. When the `radiusMarker` is `true`, there is a dotted line rendered
     * from the center of the circle to the control point, and the marker is shown
     * at the midpoint of this line.
     *
     * @default 90
     */
    radiusDisplayAngle: z.ZodNumber;
    /**
     * The unit of the radius used when the `radiusMarker` is `true`.
     *
     * A value of `null` means that the unit matches the user's locale.
     *
     * @default null
     */
    radiusDisplayUnit: z.ZodNullable<z.ZodEnum<["meter", "kilometer", "foot", "mile"]>>;
    /**
     * The opacity of the circle's fill.
     *
     * @default 0.25
     */
    fillOpacity: z.ZodNumber;
}>, "type" | "id">>, "strip", z.ZodTypeAny, {
    type: "Circle";
    id: string;
    groupId?: string | null | undefined;
    color?: string | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    imageUrl?: string | null | undefined;
    strokeOpacity?: number | undefined;
    strokeWidth?: number | undefined;
    strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
    fillOpacity?: number | undefined;
    center?: [number, number] | undefined;
    radius?: number | undefined;
    radiusMarker?: boolean | undefined;
    radiusDisplayAngle?: number | undefined;
    radiusDisplayUnit?: "meter" | "kilometer" | "foot" | "mile" | null | undefined;
}, {
    type: "Circle";
    id: string;
    groupId?: string | null | undefined;
    color?: string | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    imageUrl?: string | null | undefined;
    strokeOpacity?: number | undefined;
    strokeWidth?: number | undefined;
    strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
    fillOpacity?: number | undefined;
    center?: [number, number] | undefined;
    radius?: number | undefined;
    radiusMarker?: boolean | undefined;
    radiusDisplayAngle?: number | undefined;
    radiusDisplayUnit?: "meter" | "kilometer" | "foot" | "mile" | null | undefined;
}>;
declare const MarkerUpdateSchema: z.ZodObject<z.objectUtil.extendShape<{
    id: z.ZodOptional<z.ZodString>;
    groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    color: z.ZodOptional<z.ZodString>;
    name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
    type: z.ZodOptional<z.ZodLiteral<"Marker">>;
    coordinates: z.ZodOptional<z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">>;
    opacity: z.ZodOptional<z.ZodNumber>;
    size: z.ZodOptional<z.ZodNumber>;
    zoom: z.ZodOptional<z.ZodNumber>;
}, Pick<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    type: z.ZodLiteral<"Marker">;
    coordinates: z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">;
    /**
     * The opacity of the marker, between 0 and 1.
     *
     * @default 1
     */
    opacity: z.ZodNumber;
    /**
     * The size of the marker, used in conjunction with the `zoom` to determine
     * the actual size of the marker.
     *
     * @default 10
     */
    size: z.ZodNumber;
    /**
     * The zoom level at which the marker was created. This is combined with
     * the `size` to determine the actual size of the marker.
     *
     * When creating a marker, if you don't supply this value it defaults to
     * the current zoom of the map when you call `createElement`.
     */
    zoom: z.ZodNumber;
}>, "type" | "id">>, "strip", z.ZodTypeAny, {
    type: "Marker";
    id: string;
    coordinates?: [number, number][][] | undefined;
    groupId?: string | null | undefined;
    color?: string | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    opacity?: number | undefined;
    size?: number | undefined;
    zoom?: number | undefined;
}, {
    type: "Marker";
    id: string;
    coordinates?: [number, number][][] | undefined;
    groupId?: string | null | undefined;
    color?: string | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    opacity?: number | undefined;
    size?: number | undefined;
    zoom?: number | undefined;
}>;
declare const HighlighterUpdateSchema: z.ZodObject<z.objectUtil.extendShape<{
    id: z.ZodOptional<z.ZodString>;
    groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    color: z.ZodOptional<z.ZodString>;
    name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
    type: z.ZodOptional<z.ZodLiteral<"Highlighter">>;
    coordinates: z.ZodOptional<z.ZodArray<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">, "many">>;
    renderHoles: z.ZodOptional<z.ZodBoolean>;
    opacity: z.ZodOptional<z.ZodNumber>;
}, Pick<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    type: z.ZodLiteral<"Highlighter">;
    /**
     * A multipolygon describing the area that is highlighted.
     *
     * If `renderHoles` is set to false, only the outer ring of each polygon
     * will be rendered, filling in the area inside the highlighted region.
     */
    coordinates: z.ZodArray<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">, "many">;
    /**
     * Whether to render the holes of the highlighted area.
     *
     * @default false
     */
    renderHoles: z.ZodBoolean;
    /**
     * The opacity of the highlighter, between 0 and 1.
     *
     * @default 0.5
     */
    opacity: z.ZodNumber;
}>, "type" | "id">>, "strip", z.ZodTypeAny, {
    type: "Highlighter";
    id: string;
    coordinates?: [number, number][][][] | undefined;
    groupId?: string | null | undefined;
    color?: string | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    opacity?: number | undefined;
    renderHoles?: boolean | undefined;
}, {
    type: "Highlighter";
    id: string;
    coordinates?: [number, number][][][] | undefined;
    groupId?: string | null | undefined;
    color?: string | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    opacity?: number | undefined;
    renderHoles?: boolean | undefined;
}>;
declare const TextUpdateSchema: z.ZodObject<Omit<z.objectUtil.extendShape<{
    id: z.ZodOptional<z.ZodString>;
    groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    color: z.ZodOptional<z.ZodString>;
    description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
    position: z.ZodOptional<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>>;
    rotation: z.ZodOptional<z.ZodNumber>;
    scale: z.ZodOptional<z.ZodNumber>;
    zoom: z.ZodOptional<z.ZodNumber>;
    text: z.ZodOptional<z.ZodString>;
    align: z.ZodOptional<z.ZodEnum<["left", "center", "right"]>>;
    style: z.ZodOptional<z.ZodEnum<["italic", "light", "regular", "caps"]>>;
    name: z.ZodOptional<z.ZodString>;
    type: z.ZodOptional<z.ZodLiteral<"Text">>;
}, Pick<z.objectUtil.extendShape<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    /**
     * The geographical position of the center of the element.
     */
    position: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
    /**
     * The rotation of the element in degrees.
     *
     * @default 0
     */
    rotation: z.ZodNumber;
    /**
     * The relative scale of the element from the default size. This is combined
     * with the `zoom` to determine the actual size of the element.
     *
     * @default 1
     */
    scale: z.ZodNumber;
    /**
     * The zoom level at which the element was created. This is combined with
     * the `scale` to determine the actual size of the element.
     *
     * When creating an element, if you don't supply this value it defaults to
     * the current zoom of the map when you call `createElement`.
     */
    zoom: z.ZodNumber;
    /**
     * The text in the element.
     */
    text: z.ZodString;
    /**
     * The alignment of the text, either `left`, `center` or `right`.
     *
     * @default "center"
     */
    align: z.ZodEnum<["left", "center", "right"]>;
    /**
     * The style of the text, either `italic`, `light`, `regular` or `caps`.
     *
     * @default "regular"
     */
    style: z.ZodEnum<["italic", "light", "regular", "caps"]>;
    /**
     * The text shown in the element, which is identical to the `text` property.
     *
     * @remarks This is added for consistency with other elements that have a `name`
     * property.
     */
    name: z.ZodString;
}>, {
    type: z.ZodLiteral<"Text">;
}>, "type" | "id">>, "name">, "strip", z.ZodTypeAny, {
    type: "Text";
    id: string;
    groupId?: string | null | undefined;
    color?: string | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    zoom?: number | undefined;
    position?: [number, number] | undefined;
    rotation?: number | undefined;
    scale?: number | undefined;
    text?: string | undefined;
    align?: "center" | "left" | "right" | undefined;
    style?: "italic" | "light" | "regular" | "caps" | undefined;
}, {
    type: "Text";
    id: string;
    groupId?: string | null | undefined;
    color?: string | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    zoom?: number | undefined;
    position?: [number, number] | undefined;
    rotation?: number | undefined;
    scale?: number | undefined;
    text?: string | undefined;
    align?: "center" | "left" | "right" | undefined;
    style?: "italic" | "light" | "regular" | "caps" | undefined;
}>;
declare const NoteUpdateSchema: z.ZodObject<Omit<z.objectUtil.extendShape<{
    id: z.ZodOptional<z.ZodString>;
    groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    color: z.ZodOptional<z.ZodString>;
    description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
    position: z.ZodOptional<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>>;
    rotation: z.ZodOptional<z.ZodNumber>;
    scale: z.ZodOptional<z.ZodNumber>;
    zoom: z.ZodOptional<z.ZodNumber>;
    text: z.ZodOptional<z.ZodString>;
    align: z.ZodOptional<z.ZodEnum<["left", "center", "right"]>>;
    style: z.ZodOptional<z.ZodEnum<["italic", "light", "regular", "caps"]>>;
    name: z.ZodOptional<z.ZodString>;
    type: z.ZodOptional<z.ZodLiteral<"Note">>;
    widthScale: z.ZodOptional<z.ZodNumber>;
}, Pick<z.objectUtil.extendShape<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    /**
     * The geographical position of the center of the element.
     */
    position: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
    /**
     * The rotation of the element in degrees.
     *
     * @default 0
     */
    rotation: z.ZodNumber;
    /**
     * The relative scale of the element from the default size. This is combined
     * with the `zoom` to determine the actual size of the element.
     *
     * @default 1
     */
    scale: z.ZodNumber;
    /**
     * The zoom level at which the element was created. This is combined with
     * the `scale` to determine the actual size of the element.
     *
     * When creating an element, if you don't supply this value it defaults to
     * the current zoom of the map when you call `createElement`.
     */
    zoom: z.ZodNumber;
    /**
     * The text in the element.
     */
    text: z.ZodString;
    /**
     * The alignment of the text, either `left`, `center` or `right`.
     *
     * @default "center"
     */
    align: z.ZodEnum<["left", "center", "right"]>;
    /**
     * The style of the text, either `italic`, `light`, `regular` or `caps`.
     *
     * @default "regular"
     */
    style: z.ZodEnum<["italic", "light", "regular", "caps"]>;
    /**
     * The text shown in the element, which is identical to the `text` property.
     *
     * @remarks This is added for consistency with other elements that have a `name`
     * property.
     */
    name: z.ZodString;
}>, {
    type: z.ZodLiteral<"Note">;
    widthScale: z.ZodNumber;
}>, "type" | "id">>, "name">, "strip", z.ZodTypeAny, {
    type: "Note";
    id: string;
    groupId?: string | null | undefined;
    color?: string | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    zoom?: number | undefined;
    position?: [number, number] | undefined;
    rotation?: number | undefined;
    scale?: number | undefined;
    text?: string | undefined;
    align?: "center" | "left" | "right" | undefined;
    style?: "italic" | "light" | "regular" | "caps" | undefined;
    widthScale?: number | undefined;
}, {
    type: "Note";
    id: string;
    groupId?: string | null | undefined;
    color?: string | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    zoom?: number | undefined;
    position?: [number, number] | undefined;
    rotation?: number | undefined;
    scale?: number | undefined;
    text?: string | undefined;
    align?: "center" | "left" | "right" | undefined;
    style?: "italic" | "light" | "regular" | "caps" | undefined;
    widthScale?: number | undefined;
}>;
declare const ImageUpdateSchema: z.ZodObject<z.objectUtil.extendShape<{
    type: z.ZodOptional<z.ZodLiteral<"Image">>;
    coordinates: z.ZodOptional<z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">>;
    id: z.ZodOptional<z.ZodString>;
    groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
    imageUrl: z.ZodOptional<z.ZodString>;
    opacity: z.ZodOptional<z.ZodNumber>;
}, Pick<Omit<z.objectUtil.extendShape<{
    /**
     * The unique identifier for the element.
     */
    id: z.ZodString;
    /**
     * The ID of the element group that the element belongs to.
     * For elements that are not part of a group, this will be null.
     */
    groupId: z.ZodNullable<z.ZodString>;
    /**
     * The color of the element in some CSS-like format.
     *
     * @example
     * ```typescript
     * "#ABC123";
     * "rgb(255, 0, 0)";
     * "hsl(200, 100%, 50%)";
     * ```
     *
     * @default "#C93535"
     */
    color: z.ZodString;
    /**
     * The element's name. For elements that can show a label or text on
     * the map (e.g. a Place or Text element) this is the text that will be shown.
     *
     * For elements such as Polygons or Paths, the name is what is shown when
     * the element is selected by clicking on it.
     */
    name: z.ZodNullable<z.ZodString>;
    /**
     * Text describing the element, which is shown in an element's popup when it
     * is selected.
     *
     * Note that some elements are not selectable on the map, such as Notes, Text
     * and Markers, so their description will not be shown.
     */
    description: z.ZodNullable<z.ZodString>;
    /**
     * A set of key-value pairs that can be used to store arbitrary data about the element.
     *
     * This is most useful for associating additional data with an element that is not
     * part of the element's core data, such as a Place's address or some other
     * data.
     */
    attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    /**
     * Whether the element is interactive.
     *
     * The `default` interaction mode means that the element can be selected and edited by
     * the user, if it was created by the SDK or by the user using a tool.
     *
     * If the interaction mode is `locked`, the element will not be editable by the user,
     * which is often used for elements that you don't want the user to edit or move by
     * accident.
     *
     * Elements that were created by the map author (i.e. not during an SDK "session") are
     * not editable and have special behaviour depending on their name, description and
     * attributes.
     *
     * @default "default"
     */
    interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
}, {
    type: z.ZodLiteral<"Image">;
    coordinates: z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">;
    /**
     * The URL of the image that is rendered in this element
     */
    imageUrl: z.ZodString;
    /**
     * The opacity of the image, between 0 and 1.
     *
     * @default 1
     */
    opacity: z.ZodNumber;
}>, "color">, "type" | "id">>, "strip", z.ZodTypeAny, {
    type: "Image";
    id: string;
    coordinates?: [number, number][][] | undefined;
    groupId?: string | null | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    imageUrl?: string | undefined;
    opacity?: number | undefined;
}, {
    type: "Image";
    id: string;
    coordinates?: [number, number][][] | undefined;
    groupId?: string | null | undefined;
    name?: string | null | undefined;
    description?: string | null | undefined;
    attributes?: Record<string, unknown> | undefined;
    interaction?: "default" | "locked" | undefined;
    imageUrl?: string | undefined;
    opacity?: number | undefined;
}>;
interface PlaceElementCreate extends zInfer<typeof PlaceCreateSchema> {
    coordinates: LngLatTuple;
}
interface PathElementCreate extends zInfer<typeof PathCreateSchema> {
    coordinates: LngLatTuple[][];
}
interface PolygonElementCreate extends zInfer<typeof PolygonCreateSchema> {
    coordinates: LngLatTuple[][];
}
interface CircleElementCreate extends zInfer<typeof CircleCreateSchema> {
    center: LngLatTuple;
}
interface MarkerElementCreate extends zInfer<typeof MarkerCreateSchema> {
    coordinates: LngLatTuple[][];
}
interface HighlighterElementCreate extends zInfer<typeof HighlighterCreateSchema> {
    coordinates: LngLatTuple[][][];
}
interface TextElementCreate extends zInfer<typeof TextCreateSchema> {
    /**
     * The geographical position of the center of the text element.
     *
     * If this is omitted, the text will be placed at the center of the current
     * viewport.
     */
    position?: LngLatTuple;
}
interface NoteElementCreate extends zInfer<typeof NoteCreateSchema> {
    /**
     * The geographical position of the center of the note element.
     *
     * If this is omitted, the note will be placed at the center of the current
     * viewport.
     */
    position?: LngLatTuple;
}
interface ImageElementCreate extends zInfer<typeof ImageCreateSchema> {
}
interface PlaceElementRead extends zInfer<typeof PlaceReadSchema> {
    coordinates: LngLatTuple;
}
interface PathElementRead extends zInfer<typeof PathReadSchema> {
}
interface PolygonElementRead extends zInfer<typeof PolygonReadSchema> {
}
interface CircleElementRead extends zInfer<typeof CircleReadSchema> {
    center: LngLatTuple;
}
interface MarkerElementRead extends zInfer<typeof MarkerReadSchema> {
}
interface HighlighterElementRead extends zInfer<typeof HighlighterReadSchema> {
}
interface TextElementRead extends zInfer<typeof TextReadSchema> {
    /**
     * The geographical position of the center of the text element.
     */
    position: LngLatTuple;
}
interface NoteElementRead extends zInfer<typeof NoteReadSchema> {
    /**
     * The geographical position of the center of the note element.
     */
    position: LngLatTuple;
}
interface ImageElementRead extends zInfer<typeof ImageReadSchema> {
}
interface LinkElementRead extends zInfer<typeof LinkReadSchema> {
}
interface PlaceElementUpdate extends zInfer<typeof PlaceUpdateSchema> {
    coordinates?: LngLatTuple;
}
interface PathElementUpdate extends zInfer<typeof PathUpdateSchema> {
    coordinates?: LngLatTuple[][];
}
interface PolygonElementUpdate extends zInfer<typeof PolygonUpdateSchema> {
    coordinates?: LngLatTuple[][];
}
interface CircleElementUpdate extends zInfer<typeof CircleUpdateSchema> {
    center?: LngLatTuple;
}
interface MarkerElementUpdate extends zInfer<typeof MarkerUpdateSchema> {
    coordinates?: LngLatTuple[][];
}
interface HighlighterElementUpdate extends zInfer<typeof HighlighterUpdateSchema> {
    coordinates?: LngLatTuple[][][];
}
interface TextElementUpdate extends zInfer<typeof TextUpdateSchema> {
    /**
     * The geographical position of the center of the text element.
     */
    position?: LngLatTuple;
}
interface NoteElementUpdate extends zInfer<typeof NoteUpdateSchema> {
    /**
     * The geographical position of the center of the note element.
     */
    position?: LngLatTuple;
}
interface ImageElementUpdate extends zInfer<typeof ImageUpdateSchema> {
}
type ElementCreate = PlaceElementCreate | PathElementCreate | PolygonElementCreate | CircleElementCreate | MarkerElementCreate | HighlighterElementCreate | ImageElementCreate | TextElementCreate | NoteElementCreate;
type ElementUpdate = PlaceElementUpdate | PathElementUpdate | PolygonElementUpdate | CircleElementUpdate | MarkerElementUpdate | HighlighterElementUpdate | TextElementUpdate | NoteElementUpdate | ImageElementUpdate;
/**
 * @group Elements
 */
type Element = PlaceElementRead | PathElementRead | PolygonElementRead | CircleElementRead | MarkerElementRead | HighlighterElementRead | TextElementRead | NoteElementRead | ImageElementRead | LinkElementRead;
/**
 * @group Element Groups
 */
interface ElementGroup {
    /**
     * A string identifying the element group.
     */
    id: string;
    /**
     * The name of the element group. This is shown in the legend.
     */
    name: string;
    /**
     * The caption of the element group. This is shown in the legend.
     */
    caption: string | null;
    /**
     * The ids of the elements in the element group.
     *
     * @remarks
     * You can use these ids to get the full element objects via the {@link ElementsController.getElements | `getElements`} method.
     */
    elementIds: Array<string>;
    /**
     * Whether the element group is visible or not.
     */
    visible: boolean;
    /**
     * Whether the element group is shown in the legend or not.
     */
    shownInLegend: boolean;
}
/**
 * The constraints to apply when getting elements.
 *
 * @group Elements
 */
interface GetElementsConstraint extends zInfer<typeof GetElementsConstraintSchema> {
}
declare const GetElementsConstraintSchema: z.ZodObject<{
    /**
     * The ids of the elements to get.
     */
    ids: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
}, "strip", z.ZodTypeAny, {
    ids?: string[] | undefined;
}, {
    ids?: string[] | undefined;
}>;
/**
 * The constraints to apply when getting element groups.
 *
 * @group Element Groups
 */
interface GetElementGroupsConstraint extends zInfer<typeof GetElementGroupsConstraintSchema> {
}
/**
 * @ignore
 */
declare const GetElementGroupsConstraintSchema: z.ZodObject<{
    /**
     * The ids of the element groups to get.
     */
    ids: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
}, "strip", z.ZodTypeAny, {
    ids?: string[] | undefined;
}, {
    ids?: string[] | undefined;
}>;
/**
 * The parameters for the {@link ElementsController.onElementChange | `onElementChange`} and the {@link ElementsController.onElementCreate | `onElementCreate`} listeners.
 *
 * @group Elements
 */
interface ElementChangeCallbackParams {
    /**
     * The new data for the element or null if the element was removed.
     */
    element: Element | null;
    /**
     * Whether or not this element is still being created by a drawing tool.
     *
     * For example, if the user begins drawing a polygon, they need to place
     * multiple points until they've ultimately completed the polygon. All
     * the time they are still placing points, this will be true.
     *
     * For elements that require text entry (such as Places, Text and Notes)
     * this will be true all the time the user is typing text until the point
     * at which the user finishes, by pressing Escape for example.
     *
     * If the user is editing an existing element, this will be false.
     *
     * For elements that are created programatically, this will be false.
     */
    isBeingCreated: boolean;
}
/**
 * The parameters for the {@link ElementsController.onElementGroupChange | `onElementGroupChange`} listener.
 *
 * @group Element Groups
 */
interface ElementGroupChangeCallbackParams {
    elementGroup: ElementGroup | null;
}

/**
 * The Elements controller allows you to get information about the elements on the
 * map, and make changes to their visibility.
 *
 * @group Controller
 * @public
 */
interface ElementsController {
    /**
     * Get a single element from the map by its id.
     *
     * @example
     * ```typescript
     * const element = await felt.getElement("element-1");
     * ```
     * @returns The requested element.
     */
    getElement(
    /**
     * The id of the element you want to get.
     */
    id: string): Promise<Element | null>;
    /**
     * Get the geometry of an element in GeoJSON geometry format.
     *
     * For most element types, the geometry returned is based on the `coordinates`
     * property of the element, with some differences:
     *
     * - For Circle elements, the geometry is a Polygon drawn from the `center` and
     * `radius` properties.
     *
     * - Path elements become MultiLineString geometries.
     *
     * - Marker elements return a MultiLineString of the path traced by the user
     * as they drew the marker. Note that this is not the polygon formed by filled-in
     * "pen" stroke, which doesn't exactly follow the path traced by the user as it
     * is smoothed and interpolated to create a continuous line.
     *
     * - Text, Note and Image elements do not return geometry, so will return `null`.
     *
     *
     * @example
     * ```typescript
     * const geometry = await felt.getElementGeometry("element-1");
     * console.log(geometry?.type, geometry?.coordinates);
     * ```
     */
    getElementGeometry(
    /**
     * The id of the element you want to get the geometry of.
     */
    id: string): Promise<GeoJsonGeometry | null>;
    /**
     * Gets elements from the map, according to the constraints supplied. If no
     * constraints are supplied, all elements will be returned.
     *
     * @remarks The elements in the map, ordered by the order specified in Felt. This is not
     * necessarily the order that they are drawn in, as Felt draws points above
     * lines and lines above polygons, for instance.
     *
     * @example
     * ```typescript
     * const elements = await felt.getElements();
     * ```
     * @returns All elements on the map.
     */
    getElements(
    /**
     * The constraints to apply to the elements returned from the map.
     */
    constraint?: GetElementsConstraint): Promise<Array<Element | null>>;
    /**
     * Get an element group from the map by its id.
     *
     * @example
     * ```typescript
     * const elementGroup = await felt.getElementGroup("element-group-1");
     * ```
     * @returns The requested element group.
     */
    getElementGroup(id: string): Promise<ElementGroup | null>;
    /**
     * Gets element groups from the map, according to the filters supplied. If no
     * constraints are supplied, all element groups will be returned in rendering order.
     *
     * @example
     * ```typescript
     * const elementGroups = await felt.getElementGroups({ ids: ["element-group-1", "element-group-2"] });
     * ```
     * @returns The requested element groups.
     */
    getElementGroups(
    /**
     * The constraints to apply to the element groups returned from the map.
     */
    constraint?: GetElementGroupsConstraint): Promise<Array<ElementGroup | null>>;
    /**
     * Hide or show element groups with the given ids.
     *
     * @example
     * ```typescript
     * felt.setElementGroupVisibility({ show: ["element-group-1", "element-group-2"], hide: ["element-group-3"] });
     * ```
     */
    setElementGroupVisibility(visibility: SetVisibilityRequest): Promise<void>;
    /**
     * Adds a listener for when an element is created.
     *
     * @returns A function to unsubscribe from the listener
     *
     * @event
     * @example
     * ```typescript
     * const unsubscribe = felt.onElementCreate({
     *   handler: (element) => console.log(element.id),
     * });
     *
     * // later on...
     * unsubscribe();
     * ```
     */
    onElementCreate(args: {
        /**
         * The handler that is called when an element is created.
         *
         * This will fire when elements are created programatically, or when the
         * user starts creating an element with a drawing tool.
         *
         * When the user creates an element with a drawing tool, it can begin in
         * an invalid state, such as if you've just placed a single point in a polygon.
         *
         * You can use the `isBeingCreated` property to determine if the element is
         * still being created by a drawing tool.
         *
         * If you want to know when the element is finished being created, you can
         * use the {@link ElementsController.onElementCreateEnd | `onElementCreateEnd`} listener.
         *
         * @param change - An object describing the change that occurred.
         */
        handler: (change: ElementChangeCallbackParams) => void;
    }): VoidFunction;
    /**
     * Listens for when a new element is finished being created by a drawing tool.
     *
     * This differs from the {@link ElementsController.onElementCreate | `onElementCreate`} listener, which fires whenever an
     * element is first created. This fires when the user finishes creating an element
     * which could be after a series of interactions.
     *
     * For example, when creating a polygon, the user places a series of points then
     * finishes by pressing Enter or Escape. Or when creating a Place element, they
     * add the marker, type a label, then finally deselect the element.
     *
     * @returns A function to unsubscribe from the listener
     *
     * @event
     * @example
     * ```typescript
     * const unsubscribe = felt.onToolCreatedElement({
     *   handler: (params) => console.log(params),
     * });
     *
     * // later on...
     * unsubscribe();
     * ```
     */
    onElementCreateEnd(args: {
        /**
         * The handler to call whenever this event fires.
         *
         * @param params - An object containing the element that was created.
         */
        handler: (params: {
            element: Element;
        }) => void;
    }): VoidFunction;
    /**
     * Adds a listener for when an element changes.
     *
     * This will fire when an element is being edited, either on the map by the user
     * or programatically.
     *
     * Like the {@link ElementsController.onElementCreate | `onElementCreate`} listener, this will fire when an element is
     * still being created by a drawing tool.
     *
     * You can check the {@link ElementChangeCallbackParams.isBeingCreated | `isBeingCreated`} property to determine if the element is
     * still being created by a drawing tool.
     *
     * @returns A function to unsubscribe from the listener
     *
     * @event
     * @example
     * ```typescript
     * const unsubscribe = felt.onElementChange({
     *   options: { id: "element-1" },
     *   handler: ({element}) => console.log(element.id),
     * });
     *
     * // later on...
     * unsubscribe();
     * ```
     */
    onElementChange(args: {
        options: {
            /**
             * The id of the element to listen for changes to.
             */
            id: string;
        };
        /**
         * The handler that is called when the element changes.
         */
        handler: (
        /**
         * An object describing the change that occurred.
         */
        change: ElementChangeCallbackParams) => void;
    }): VoidFunction;
    /**
     * Adds a listener for when an element is deleted.
     *
     * @returns A function to unsubscribe from the listener
     *
     * @event
     * @example
     * ```typescript
     * const unsubscribe = felt.onElementDelete({
     *   options: { id: "element-1" },
     *   handler: () => console.log("element-1 deleted"),
     * });
     *
     * // later on...
     * unsubscribe();
     * ```
     */
    onElementDelete(args: {
        options: {
            /**
             * The id of the element to listen for deletions of.
             */
            id: string;
        };
        /**
         * The handler that is called when the element is deleted.
         */
        handler: () => void;
    }): VoidFunction;
    /**
     * Adds a listener for when an element group changes.
     *
     * @returns A function to unsubscribe from the listener
     *
     * @event
     * @example
     * ```typescript
     * const unsubscribe = felt.onElementGroupChange({
     *   options: { id: "element-group-1" },
     *   handler: elementGroup => console.log(elementGroup.id),
     * });
     *
     * // later on...
     * unsubscribe();
     * ```
     */
    onElementGroupChange(args: {
        options: {
            id: string;
        };
        handler: (change: ElementGroupChangeCallbackParams) => void;
    }): VoidFunction;
    /**
     * Create a new element on the map.
     *
     * @example
     * ```typescript
     * const element = await felt.createElement({ type: "Place", coordinates: [10, 10] });
     * ```
     */
    createElement(element: ElementCreate): Promise<Element>;
    /**
     * Update an element on the map.
     *
     * @example
     * ```typescript
     * // Update a place element's coordinates
     * await felt.updateElement({
     *   id: "element-1",
     *   coordinates: [10, 20]
     * });
     *
     * // Update a polygon's style
     * await felt.updateElement({
     *   id: "element-2",
     *   color: "#ABC123",
     *   fillOpacity: 0.5
     * });
     * ```
     */
    updateElement(element: ElementUpdate): Promise<Element>;
    /**
     * Delete an element from the map.
     *
     * @example
     * ```typescript
     * await felt.deleteElement("element-1");
     * ```
     */
    deleteElement(id: string): Promise<void>;
}

/**
 * A LayerFeature is a single geographical item in a layer.
 *
 * It is intended to be a lightweight object that contains the properties of a
 * feature, but not the geometry. It is returned by methods like
 * {@link FeltController.getRenderedFeatures} and {@link FeltController.getFeature},
 * and as part of the methods in the {@link SelectionController}
 *
 * The geometry can be obtained via the {@link FeltController.getGeoJsonFeature}
 * method, which returns a {@link GeoJsonFeature} object.
 *
 * @group Features
 */
interface LayerFeature {
    /**
     * The identifier of the feature, unique within the layer.
     */
    id: string | number;
    /**
     * The identifier of the layer that the feature belongs to.
     */
    layerId: string;
    /**
     * The type of geometry of the feature.
     *
     * @remarks Because LayerFeatures can be read from tiled features, it's
     * possible that this `geometryType` won't match the `geometry.type` of the
     * {@link GeoJsonFeature} returned by {@link FeltController.getGeoJsonFeature}.
     *
     * For example, this may return `LineString` but the full feature is a `MultiLineString`,
     * or, similarly `Polygon` here may be a `MultiPolygon` in the full feature.
     *
     * As a result, you should treat this property as being indicative only.
     */
    geometryType: GeoJsonGeometry["type"] | (string & {});
    /**
     * The bounding box of the feature.
     *
     * @remarks Because LayerFeatures can be read from tiled features and considering
     * that feature geometry can go through multiple tiles, it's possible that this
     * is not the complete bounding box of the feature.
     */
    bbox: FeltBoundary | undefined;
    /**
     * The properties of the feature, as a bag of attributes.
     */
    properties: GeoJsonProperties;
}
/**
 * A raster pixel value for a specific layer.
 *
 * @group Features
 */
interface RasterValue {
    /**
     * The value of the pixel.
     */
    value: number;
    /**
     * The ID of the layer that the pixel belongs to.
     */
    layerId: string;
    /**
     * The name of the category that the pixel belongs to.
     */
    categoryName: null | string;
    /**
     * The color of the pixel. Each value is between 0 and 255.
     */
    color: null | {
        r: number;
        g: number;
        b: number;
        a: number;
    };
}

/**
 * This describes the processing status of a layer.
 *
 * The various values are:
 * - `processing`: The layer has been uploaded or updated and is still processing.
 * - `completed`: The layer has been processed and can be viewed on the map.
 * - `failed`: The layer failed to process and cannot be viewed on the map.
 * - `incomplete`: The layer has not been processed.
 *
 * @group Layers
 */
type LayerProcessingStatus = z.infer<typeof LayerProcessingStatusSchema>;
declare const LayerProcessingStatusSchema: z.ZodEnum<["processing", "completed", "failed", "incomplete"]>;
/**
 * The common properties for all layers.
 *
 * @group Layers
 */
interface LayerCommon {
    /**
     * A string identifying the layer
     */
    id: string;
    /**
     * The ID of the layer group that the layer belongs to.
     *
     * Layers that appear at the root level in Felt will not have a group ID.
     */
    groupId: string | null;
    /**
     * The name of the layer can be displayed in the Legend, depending
     * on how the layer's legend is configured in its style.
     */
    name: string;
    /**
     * The layer's caption is shown in the legend.
     */
    caption: string | null;
    /**
     * The layer description forms part of the layer's metadata. This is visible
     * to users via the layer info button in the legend.
     */
    description: string | null;
    /**
     * Whether the layer is visible or not.
     */
    visible: boolean;
    /**
     * Whether the layer is shown in the legend or not.
     */
    shownInLegend: boolean;
    /**
     * The FSL style for the layer.
     *
     * See the [FSL documentation](https://developers.felt.com/felt-style-language) for details
     * on how to read and write styles.
     *
     * As the types of the styles are very complex, we return `object` here and advise that you
     * program defensively while reading the styles.
     */
    style: object;
    /**
     * The current processing status of the layer.
     */
    status: LayerProcessingStatus;
    /**
     * The bounding box of the layer in [west, south, east, north] order
     *
     * There are cases where the bounds are not available, such as for layers added to the map
     * from URL sources, as these are not (depending on their type) processed and analyzed by
     * Felt.
     *
     * {@link FeltBoundary}
     */
    bounds: FeltBoundary | null;
}
/**
 * @group Layers
 */
type Layer = RasterLayer | VectorLayer | DataOnlyLayer;
/**
 * A raster layer is a layer that contains raster data that can be rendered on the map
 *
 * @group Layers
 */
interface RasterLayer extends LayerCommon {
    /**
     * Identifies the type of geometry in the layer.
     */
    geometryType: "Raster";
    /**
     * The source of the raster layer's data.
     */
    source: RasterLayerSource;
}
/**
 * The source of a raster layer's data.
 *
 * @group Layer sources
 */
interface RasterLayerSource {
    /**
     * A URL template for fetching image tiles for the raster.
     */
    imageTileTemplateUrl: string;
    /**
     * A URL template for fetching encoded tiles for the raster.
     *
     * The encoded raster value can be calculated from the red, green, and blue values of the pixel
     * using the following formula:
     *
     * ```
     * base + ((RED << 16) + (GREEN <<8) + BLUE) * interval
     * ```
     * or
     * ```
     * base + (RED * 256 * 256 + GREEN * 256 + BLUE) * interval
     * ```
     */
    encodedTileTemplateUrl: string;
    /**
     * List of encoded raster bands
     */
    bands: Array<RasterBand>;
}
/**
 * The RasterBand interface describes the metadata for a raster band, necessary for
 * calculating the encoded raster value from the red, green, and blue values of the pixel.
 *
 * @group Layer sources
 */
interface RasterBand {
    /**
     * Encoding base value as a floating point number
     */
    base: number;
    /**
     * Encoding interval as a floating point number
     */
    interval: number;
    /**
     * 1-based index of the band in the raster
     */
    bandIndex: number;
}
/**
 * A vector layer is a layer that contains vector data that can be rendered on the map
 *
 * @group Layers
 */
interface VectorLayer extends LayerCommon {
    /**
     * Identifies the type of geometry in the layer.
     */
    geometryType: "Point" | "Line" | "Polygon";
    /**
     * The source of the vector layer's data.
     */
    source: FeltTiledVectorSource | GeoJsonUrlVectorSource | Omit<GeoJsonDataVectorSource, "data">;
}
/**
 * A tiled vector source is a layer that is populated from data the has been uploaded
 * to Felt, and processed into vector tiles.
 *
 * @group Layer sources
 */
type FeltTiledVectorSource = {
    /**
     * Identifies this as a tiled vector source. Typically, these tiles will have been
     * uploaded to and processed by Felt.
     */
    type: "felt";
    /**
     * The template URL used for fetching tiles.
     */
    tileTemplateUrl: string;
};
declare const GeoJsonUrlVectorSourceSchema: z.ZodObject<{
    /**
     * Identifies this as a GeoJSON URL source.
     */
    type: z.ZodLiteral<"geoJsonUrl">;
    /**
     * The remote URL of the GeoJSON file used to populate the layer.
     */
    url: z.ZodString;
    /**
     * The interval in milliseconds between automatic refreshes of the GeoJSON.
     *
     * The value must be in the range of 250ms - 5 minutes (300,000ms).
     *
     * If the value is `null`, the GeoJSON will not be refreshed automatically.
     */
    refreshInterval: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
}, "strip", z.ZodTypeAny, {
    type: "geoJsonUrl";
    url: string;
    refreshInterval?: number | null | undefined;
}, {
    type: "geoJsonUrl";
    url: string;
    refreshInterval?: number | null | undefined;
}>;
/**
 * A GeoJSON URL source is a layer that is populated from a GeoJSON file at a remote URL.
 *
 * These sources are ones that have not been uploaded to and processed by Felt, and as such
 * their capabilities are limited.
 *
 * For instance, they cannot be filtered, nor can statistics be fetched for them.
 *
 * @group Layer sources
 */
interface GeoJsonUrlVectorSource extends zInfer<typeof GeoJsonUrlVectorSourceSchema> {
}
/**
 * A GeoJSON data source is a layer that is populated from GeoJSON data, such as
 * from a local file, or programatically-created data.
 *
 * @group Layer sources
 */
interface GeoJsonDataVectorSource {
    /**
     * Identifies this as a GeoJSON data source.
     */
    type: "geoJsonData";
    /**
     * The GeoJSON data for the layer.
     *
     * This must be a GeoJSON FeatureCollection.
     */
    data: object;
}
declare const GeoJsonFileVectorSourceSchema: z.ZodObject<{
    /**
     * Identifies this as a GeoJSON file source.
     */
    type: z.ZodLiteral<"geoJsonFile">;
    /**
     * The GeoJSON file for the layer.
     */
    file: z.ZodType<File, z.ZodTypeDef, File>;
}, "strip", z.ZodTypeAny, {
    type: "geoJsonFile";
    file: File;
}, {
    type: "geoJsonFile";
    file: File;
}>;
/**
 * A GeoJSON file source is a layer that is populated from a GeoJSON file
 * on your local machine.
 *
 * This is an input-only type. It is converted to a {@link GeoJsonDataVectorSource}
 * when passed to {@link LayersController.createLayersFromGeoJson}.
 *
 * @group Layer sources
 */
interface GeoJsonFileVectorSource extends zInfer<typeof GeoJsonFileVectorSourceSchema> {
}
/**
 * The parameters for the {@link LayersController.updateLayer} method.
 */
declare const UpdateLayerSchema: z.ZodObject<{
    /**
     * The id of the layer to update.
     */
    id: z.ZodString;
    style: z.ZodOptional<z.ZodObject<{}, "passthrough", z.ZodTypeAny, z.objectOutputType<{}, z.ZodTypeAny, "passthrough">, z.objectInputType<{}, z.ZodTypeAny, "passthrough">>>;
    /**
     * Changes whether the layer is shown in the legend.
     */
    shownInLegend: z.ZodOptional<z.ZodBoolean>;
    /**
     * Changes the name of the layer.
     */
    name: z.ZodOptional<z.ZodString>;
    /**
     * Changes the caption of the layer.
     */
    caption: z.ZodOptional<z.ZodString>;
    /**
     * Changes the description of the layer.
     */
    description: z.ZodOptional<z.ZodString>;
    /**
     * Changes the bounds of the layer.
     */
    bounds: z.ZodOptional<z.ZodTuple<[z.ZodNumber, z.ZodNumber, z.ZodNumber, z.ZodNumber], null>>;
    source: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
        /**
         * Identifies this as a GeoJSON URL source.
         */
        type: z.ZodLiteral<"geoJsonUrl">;
        /**
         * The remote URL of the GeoJSON file used to populate the layer.
         */
        url: z.ZodString;
        /**
         * The interval in milliseconds between automatic refreshes of the GeoJSON.
         *
         * The value must be in the range of 250ms - 5 minutes (300,000ms).
         *
         * If the value is `null`, the GeoJSON will not be refreshed automatically.
         */
        refreshInterval: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
    }, "strip", z.ZodTypeAny, {
        type: "geoJsonUrl";
        url: string;
        refreshInterval?: number | null | undefined;
    }, {
        type: "geoJsonUrl";
        url: string;
        refreshInterval?: number | null | undefined;
    }>, z.ZodObject<{
        type: z.ZodLiteral<"geoJsonData">;
        data: z.ZodUnion<[z.ZodObject<{}, "passthrough", z.ZodTypeAny, z.objectOutputType<{}, z.ZodTypeAny, "passthrough">, z.objectInputType<{}, z.ZodTypeAny, "passthrough">>, z.ZodType<ArrayBuffer, z.ZodTypeDef, ArrayBuffer>]>;
    }, "strip", z.ZodTypeAny, {
        type: "geoJsonData";
        data: ArrayBuffer | z.objectOutputType<{}, z.ZodTypeAny, "passthrough">;
    }, {
        type: "geoJsonData";
        data: ArrayBuffer | z.objectInputType<{}, z.ZodTypeAny, "passthrough">;
    }>, z.ZodObject<{
        /**
         * Identifies this as a GeoJSON file source.
         */
        type: z.ZodLiteral<"geoJsonFile">;
        /**
         * The GeoJSON file for the layer.
         */
        file: z.ZodType<File, z.ZodTypeDef, File>;
    }, "strip", z.ZodTypeAny, {
        type: "geoJsonFile";
        file: File;
    }, {
        type: "geoJsonFile";
        file: File;
    }>]>>;
}, "strip", z.ZodTypeAny, {
    id: string;
    name?: string | undefined;
    description?: string | undefined;
    style?: z.objectOutputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
    source?: {
        type: "geoJsonUrl";
        url: string;
        refreshInterval?: number | null | undefined;
    } | {
        type: "geoJsonFile";
        file: File;
    } | {
        type: "geoJsonData";
        data: ArrayBuffer | z.objectOutputType<{}, z.ZodTypeAny, "passthrough">;
    } | undefined;
    bounds?: [number, number, number, number] | undefined;
    caption?: string | undefined;
    shownInLegend?: boolean | undefined;
}, {
    id: string;
    name?: string | undefined;
    description?: string | undefined;
    style?: z.objectInputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
    source?: {
        type: "geoJsonUrl";
        url: string;
        refreshInterval?: number | null | undefined;
    } | {
        type: "geoJsonFile";
        file: File;
    } | {
        type: "geoJsonData";
        data: ArrayBuffer | z.objectInputType<{}, z.ZodTypeAny, "passthrough">;
    } | undefined;
    bounds?: [number, number, number, number] | undefined;
    caption?: string | undefined;
    shownInLegend?: boolean | undefined;
}>;
/**
 * The value you need to pass to {@link LayersController.updateLayer}
 *
 * @group Layers
 */
interface UpdateLayerParams extends Omit<zInfer<typeof UpdateLayerSchema>, "style" | "source"> {
    /**
     * The style of the layer.
     */
    style?: object;
    /**
     * Updates the source of the layer.
     *
     * Only layers that have a GeoJSON source can have their source udpated.
     *
     * For URL sources, if you pass the same URL again it will cause the data to be
     * refreshed.
     */
    source?: GeoJsonUrlVectorSource | GeoJsonDataVectorSource | GeoJsonFileVectorSource;
}
/**
 * A data-only layer doesn't have any geometry, but can be used to join with other layers
 *
 * @group Layers
 */
interface DataOnlyLayer extends LayerCommon {
    /**
     * Indicates that this layer has no geometry.
     */
    geometryType: null;
    /**
     * This is always null for data-only layers.
     */
    bounds: null;
}
/**
 * @group Layer Groups
 */
interface LayerGroup {
    /**
     * A string identifying the layer group.
     */
    id: string;
    /**
     * The name of the layer group. This is shown in the legend.
     */
    name: string;
    /**
     * The caption of the layer group. This is shown in the legend.
     */
    caption: string | null;
    /**
     * The ids of the layers in the layer group.
     *
     * @remarks
     * You can use these ids to get the full layer objects via the {@link LayersController.getLayers | `getLayers`} method.
     */
    layerIds: Array<string>;
    /**
     * Whether the layer group is visible or not.
     */
    visible: boolean;
    /**
     * Whether the layer group is shown in the legend or not.
     */
    shownInLegend: boolean;
    /**
     * The bounding box of the layer group in [west, south, east, north] order.
     *
     * {@link FeltBoundary}
     */
    bounds: FeltBoundary | null;
}
/**
 * The constraints to apply when getting layers.
 *
 * @group Layers
 */
interface GetLayersConstraint extends zInfer<typeof GetLayersConstraintSchema> {
}
/**
 * @ignore
 */
declare const GetLayersConstraintSchema: z.ZodObject<{
    /**
     * The ids of the layers to get.
     */
    ids: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
}, "strip", z.ZodTypeAny, {
    ids?: string[] | undefined;
}, {
    ids?: string[] | undefined;
}>;
/**
 * The constraints to apply when getting layer groups.
 *
 * @group Layer Groups
 */
interface GetLayerGroupsConstraint extends zInfer<typeof GetLayerGroupsFilterSchema> {
}
/**
 * @ignore
 */
declare const GetLayerGroupsFilterSchema: z.ZodObject<{
    /**
     * The ids of the layer groups to get.
     */
    ids: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
}, "strip", z.ZodTypeAny, {
    ids?: string[] | undefined;
}, {
    ids?: string[] | undefined;
}>;
/**
 * The parameters for the {@link LayersController.onLayerChange | `onLayerChange`} listener.
 *
 * @group Layers
 */
interface LayerChangeCallbackParams {
    /**
     * The new data for the layer or null if the layer was removed.
     */
    layer: Layer | null;
}
/**
 * The parameters for the {@link LayersController.onLayerGroupChange | `onLayerGroupChange`} listener.
 *
 * @group Layer Groups
 */
interface LayerGroupChangeCallbackParams {
    layerGroup: LayerGroup | null;
}
/**
 * A legend item, which often represents a sub-class of features in a
 * layer in the case of categorical or classed layers.
 *
 * @group Legend Items
 */
interface LegendItem extends LegendItemIdentifier {
    /**
     * The title of the legend item.
     */
    title: string | Array<string>;
    /**
     * Whether the title depends on the zoom level or not. If it does, you
     * need to call {@link LayersController.getLegendItem | `getLegendItem`} when the zoom level changes.
     *
     * Note that as the zoom level changes, the {@link LayersController.onLegendItemChange | `onLegendItemChange`} handler
     * will not be called, so you need to call {@link LayersController.getLegendItem | `getLegendItem`} yourself.
     */
    titleDependsOnZoom: boolean;
    /**
     * Whether the legend item is visible or not.
     */
    visible: boolean;
}
/**
 * The identifier for a legend item. It is a compound key of the layer to
 * which the legend item belongs and the legend item's own id.
 *
 * @group Legend Items
 */
interface LegendItemIdentifier extends zInfer<typeof LegendItemIdentifierSchema> {
}
/** @ignore */
declare const LegendItemIdentifierSchema: z.ZodObject<{
    /**
     * The id of the legend item.
     */
    id: z.ZodString;
    /**
     * The id of the layer the legend item belongs to.
     */
    layerId: z.ZodString;
}, "strip", z.ZodTypeAny, {
    id: string;
    layerId: string;
}, {
    id: string;
    layerId: string;
}>;
/**
 * Constraints for legend items. If nothing is passed, all legend items will be returned.
 *
 * @group Legend Items
 */
interface LegendItemsConstraint extends zInfer<typeof LegendItemsConstraintSchema> {
}
/** @ignore */
declare const LegendItemsConstraintSchema: z.ZodObject<{
    /**
     * Array of legend item identifiers to constrain by.
     */
    ids: z.ZodOptional<z.ZodArray<z.ZodObject<{
        /**
         * The id of the legend item.
         */
        id: z.ZodString;
        /**
         * The id of the layer the legend item belongs to.
         */
        layerId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        id: string;
        layerId: string;
    }, {
        id: string;
        layerId: string;
    }>, "many">>;
    /**
     * Array of layer ids to constrain legend items by.
     */
    layerIds: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
}, "strip", z.ZodTypeAny, {
    ids?: {
        id: string;
        layerId: string;
    }[] | undefined;
    layerIds?: string[] | undefined;
}, {
    ids?: {
        id: string;
        layerId: string;
    }[] | undefined;
    layerIds?: string[] | undefined;
}>;
/**
 * The parameters for the {@link LayersController.onLegendItemChange | `onLegendItemChange`} listener.
 *
 * @group Legend Items
 */
interface LegendItemChangeCallbackParams {
    /**
     * The new data for the legend item or null if the legend item was removed.
     */
    legendItem: LegendItem | null;
}
/**
 * Constraints for the {@link LayersController.getRenderedFeatures | `getRenderedFeatures`} method. This can include layer constriants, spatial constraints, or both. If no constraints are
 * provided, all rendered features will be returned.
 *
 * @group Layers
 */
interface GetRenderedFeaturesConstraint extends zInfer<typeof GetRenderedFeaturesConstraintSchema> {
    /**
     * The area to query for rendered features. This can be specific coordinates or a {@link FeltBoundary}. If omitted, the entire viewport will be queried.
     */
    areaQuery?: {
        coordinates: LatLng;
    } | {
        boundary: FeltBoundary;
    };
}
/** @ignore */
declare const GetRenderedFeaturesConstraintSchema: z.ZodObject<{
    /**
     * The ids of the layers to get rendered features for.
     */
    layerIds: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    areaQuery: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
        coordinates: z.ZodObject<{
            latitude: z.ZodNumber;
            longitude: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            latitude: number;
            longitude: number;
        }, {
            latitude: number;
            longitude: number;
        }>;
    }, "strip", z.ZodTypeAny, {
        coordinates: {
            latitude: number;
            longitude: number;
        };
    }, {
        coordinates: {
            latitude: number;
            longitude: number;
        };
    }>, z.ZodObject<{
        boundary: z.ZodTuple<[z.ZodNumber, z.ZodNumber, z.ZodNumber, z.ZodNumber], null>;
    }, "strip", z.ZodTypeAny, {
        boundary: [number, number, number, number];
    }, {
        boundary: [number, number, number, number];
    }>]>>;
}, "strip", z.ZodTypeAny, {
    layerIds?: string[] | undefined;
    areaQuery?: {
        coordinates: {
            latitude: number;
            longitude: number;
        };
    } | {
        boundary: [number, number, number, number];
    } | undefined;
}, {
    layerIds?: string[] | undefined;
    areaQuery?: {
        coordinates: {
            latitude: number;
            longitude: number;
        };
    } | {
        boundary: [number, number, number, number];
    } | undefined;
}>;
/**
 * The schema that describes the structure of the features in a layer.
 *
 * @remarks This can be useful to build generic UIs that need to know the structure of the data in
 * a layer, such as a dropdown to choose an attribute.
 *
 * @group Layer Schema
 */
interface LayerSchema {
    /**
     * The total number of features in the layer.
     */
    featureCount: number;
    /**
     * Array of attribute schemas describing the properties available on features in this layer.
     */
    attributes: Array<LayerSchemaAttribute>;
}
/**
 * A single attribute from the layer schema.
 *
 * @remarks Each feature in a layer has a set of attributes, and these types describe the
 * structure of a single attribute, including things like id, display name, type, and sample values.
 *
 * @group Layer Schema
 */
type LayerSchemaAttribute = LayerSchemaNumericAttribute | LayerSchemaTextAttribute | LayerSchemaBooleanAttribute | LayerSchemaDateAttribute | LayerSchemaDateTimeAttribute;
/**
 * The common schema for all attributes.
 *
 * @group Layer Schema
 */
interface LayerSchemaCommonAttribute {
    /**
     * The unique identifier for this attribute.
     *
     * This can be used to fetch statistics, categories, histograms etc. for this attribute
     * via the {@link LayersController.getCategoryData}, {@link LayersController.getHistogramData},
     * and {@link LayersController.getAggregates} methods.
     */
    id: string;
    /**
     * The human-readable name of this attribute.
     */
    displayName: string;
    /**
     * The specific data type of this attribute, providing more detail than the basic type.
     *
     * For instance, a numeric attribute might be "INTEGER", "FLOAT, etc.
     */
    detailedType: string;
    /**
     * The number of distinct values present for this attribute across all features.
     */
    distinctCount: number;
}
/**
 * The schema for a numeric attribute on a layer.
 *
 * @group Layer Schema
 */
interface LayerSchemaNumericAttribute extends LayerSchemaCommonAttribute {
    /**
     * Indicates this is a numeric attribute.
     */
    type: "numeric";
    /**
     * A small sample of values for this attribute and their frequency.
     */
    sampleValues: Array<{
        value: number;
        count: number;
    }>;
    /**
     * The minimum value present for this attribute across all features.
     */
    min: number;
    /**
     * The maximum value present for this attribute across all features.
     */
    max: number;
}
/**
 * The schema for a text attribute on a layer.
 *
 * @group Layer Schema
 */
interface LayerSchemaTextAttribute extends LayerSchemaCommonAttribute {
    /**
     * Indicates this is a text attribute.
     */
    type: "text";
    /**
     * A small sample of string values for this attribute and their frequency.
     */
    sampleValues: Array<{
        value: string;
        count: number;
    }>;
}
/**
 * The schema for a boolean attribute on a layer.
 *
 * @group Layer Schema
 */
interface LayerSchemaBooleanAttribute extends LayerSchemaCommonAttribute {
    /**
     * Indicates this is a boolean attribute.
     */
    type: "boolean";
    /**
     * A representative sample of boolean values for this attribute and their frequency.
     */
    sampleValues: Array<{
        value: boolean;
        count: number;
    }>;
}
/**
 * The schema for a date attribute on a layer.
 *
 * @group Layer Schema
 */
interface LayerSchemaDateAttribute extends LayerSchemaCommonAttribute {
    /**
     * Indicates this is a date attribute.
     */
    type: "date";
    /**
     * The earliest date present for this attribute in truncated ISO8601 format (YYYY-MM-DD).
     */
    min: string;
    /**
     * The latest date present for this attribute in truncated ISO8601 format (YYYY-MM-DD).
     */
    max: string;
    /**
     * A representative sample of date values for this attribute and their frequency.
     */
    sampleValues: Array<{
        value: string;
        count: number;
    }>;
}
/**
 * The schema for a datetime attribute on a layer.
 *
 * @group Layer Schema
 */
interface LayerSchemaDateTimeAttribute extends LayerSchemaCommonAttribute {
    /**
     * Indicates this is a datetime attribute.
     */
    type: "datetime";
    /**
     * The earliest datetime present for this attribute in ISO8601 format.
     */
    min: string;
    /**
     * The latest datetime present for this attribute in ISO8601 format.
     */
    max: string;
    /**
     * A representative sample of datetime values for this attribute and their frequency.
     */
    sampleValues: Array<{
        value: string;
        count: number;
    }>;
}
/**
 * The parameters for the {@link LayersController.createLayersFromGeoJson} method.
 *
 * @group Layers
 */
declare const CreateLayersFromGeoJsonSchema: z.ZodObject<{
    source: z.ZodUnion<[z.ZodObject<{
        /**
         * Identifies this as a GeoJSON URL source.
         */
        type: z.ZodLiteral<"geoJsonUrl">;
        /**
         * The remote URL of the GeoJSON file used to populate the layer.
         */
        url: z.ZodString;
        /**
         * The interval in milliseconds between automatic refreshes of the GeoJSON.
         *
         * The value must be in the range of 250ms - 5 minutes (300,000ms).
         *
         * If the value is `null`, the GeoJSON will not be refreshed automatically.
         */
        refreshInterval: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
    }, "strip", z.ZodTypeAny, {
        type: "geoJsonUrl";
        url: string;
        refreshInterval?: number | null | undefined;
    }, {
        type: "geoJsonUrl";
        url: string;
        refreshInterval?: number | null | undefined;
    }>, z.ZodObject<{
        type: z.ZodLiteral<"geoJsonData">;
        data: z.ZodUnion<[z.ZodObject<{}, "passthrough", z.ZodTypeAny, z.objectOutputType<{}, z.ZodTypeAny, "passthrough">, z.objectInputType<{}, z.ZodTypeAny, "passthrough">>, z.ZodType<ArrayBuffer, z.ZodTypeDef, ArrayBuffer>]>;
    }, "strip", z.ZodTypeAny, {
        type: "geoJsonData";
        data: ArrayBuffer | z.objectOutputType<{}, z.ZodTypeAny, "passthrough">;
    }, {
        type: "geoJsonData";
        data: ArrayBuffer | z.objectInputType<{}, z.ZodTypeAny, "passthrough">;
    }>, z.ZodObject<{
        /**
         * Identifies this as a GeoJSON file source.
         */
        type: z.ZodLiteral<"geoJsonFile">;
        /**
         * The GeoJSON file for the layer.
         */
        file: z.ZodType<File, z.ZodTypeDef, File>;
    }, "strip", z.ZodTypeAny, {
        type: "geoJsonFile";
        file: File;
    }, {
        type: "geoJsonFile";
        file: File;
    }>]>;
    /**
     * The name of the layer to create.
     */
    name: z.ZodString;
    /**
     * Sets the bounds of the layer.
     */
    bounds: z.ZodOptional<z.ZodTuple<[z.ZodNumber, z.ZodNumber, z.ZodNumber, z.ZodNumber], null>>;
    /**
     * Sets the caption of the layer.
     */
    caption: z.ZodOptional<z.ZodString>;
    /**
     * Sets the description of the layer.
     */
    description: z.ZodOptional<z.ZodString>;
    /**
     * Sets the styles to apply to each geometry on the layer.
     */
    geometryStyles: z.ZodOptional<z.ZodObject<{
        Point: z.ZodOptional<z.ZodObject<{}, "passthrough", z.ZodTypeAny, z.objectOutputType<{}, z.ZodTypeAny, "passthrough">, z.objectInputType<{}, z.ZodTypeAny, "passthrough">>>;
        Line: z.ZodOptional<z.ZodObject<{}, "passthrough", z.ZodTypeAny, z.objectOutputType<{}, z.ZodTypeAny, "passthrough">, z.objectInputType<{}, z.ZodTypeAny, "passthrough">>>;
        Polygon: z.ZodOptional<z.ZodObject<{}, "passthrough", z.ZodTypeAny, z.objectOutputType<{}, z.ZodTypeAny, "passthrough">, z.objectInputType<{}, z.ZodTypeAny, "passthrough">>>;
    }, "strip", z.ZodTypeAny, {
        Point?: z.objectOutputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
        Polygon?: z.objectOutputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
        Line?: z.objectOutputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
    }, {
        Point?: z.objectInputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
        Polygon?: z.objectInputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
        Line?: z.objectInputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
    }>>;
}, "strip", z.ZodTypeAny, {
    name: string;
    source: {
        type: "geoJsonUrl";
        url: string;
        refreshInterval?: number | null | undefined;
    } | {
        type: "geoJsonFile";
        file: File;
    } | {
        type: "geoJsonData";
        data: ArrayBuffer | z.objectOutputType<{}, z.ZodTypeAny, "passthrough">;
    };
    description?: string | undefined;
    bounds?: [number, number, number, number] | undefined;
    caption?: string | undefined;
    geometryStyles?: {
        Point?: z.objectOutputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
        Polygon?: z.objectOutputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
        Line?: z.objectOutputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
    } | undefined;
}, {
    name: string;
    source: {
        type: "geoJsonUrl";
        url: string;
        refreshInterval?: number | null | undefined;
    } | {
        type: "geoJsonFile";
        file: File;
    } | {
        type: "geoJsonData";
        data: ArrayBuffer | z.objectInputType<{}, z.ZodTypeAny, "passthrough">;
    };
    description?: string | undefined;
    bounds?: [number, number, number, number] | undefined;
    caption?: string | undefined;
    geometryStyles?: {
        Point?: z.objectInputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
        Polygon?: z.objectInputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
        Line?: z.objectInputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
    } | undefined;
}>;
/**
 * The parameters for the {@link LayersController.createLayersFromGeoJson} method.
 *
 * @group Layers
 */
interface CreateLayersFromGeoJsonParams extends Omit<zInfer<typeof CreateLayersFromGeoJsonSchema>, "source" | "geometryStyles"> {
    /**
     * The source of the GeoJSON data.
     */
    source: GeoJsonDataVectorSource | GeoJsonFileVectorSource | GeoJsonUrlVectorSource;
    /**
     * The styles to apply to each geometry on the layer.
     *
     * Each style should be a valid FSL style, as described in {@link Layer.style}.
     *
     * These are optional, and if missing will use a default style determined by
     * Felt, which you can consider to be undefined behaviour.
     *
     * @example
     * ```typescript
     * const layer = await layersController.createLayersFromGeoJson({
     *   name: "My Layer",
     *   geometryStyles: {
     *     Point: {
     *       paint: { color: "red", size: 8 },
     *     },
     *     Line: {
     *       paint: { color: "blue", size: 4 },
     *       config: { labelAttribute: ["name"] },
     *       label: { minZoom: 0 },
     *     },
     *     Polygon: {
     *       paint: { color: "green", strokeColor: "darkgreen" },
     *     },
     *   },
     * });
     * ```
     */
    geometryStyles?: {
        Point?: object;
        Line?: object;
        Polygon?: object;
    };
}

/**
 * @group Filters
 */
type FilterLogicGate = z.infer<typeof FilterLogicGateSchema>;
declare const FilterLogicGateSchema: z.ZodEnum<["and", "or"]>;
/**
 * @group Filters
 */
type FilterExpression = z.infer<typeof FilterExpressionSchema>;
declare const FilterExpressionSchema: z.ZodUnion<[z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["in", "ni"]>, z.ZodUnion<[z.ZodArray<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>, "many">, z.ZodNull]>], null>, z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["lt", "gt", "le", "ge", "eq", "ne", "cn", "nc", "is", "isnt"]>, z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>], null>]>;
/**
 * A `FilterTernary` is a tree structure for combining expressions with logical operators.
 *
 * When combining three or more conditions, you must use proper nesting rather than a flat list.
 *
 * @example
 * ```typescript
 * // A simple filter with a single condition
 * const filter = [
 *   ["AREA", "gt", 30_000],
 *   "and",
 *   ["COLOR", "eq", "red"]
 * ]
 *
 * // A complex filter with multiple conditions
 * const filter = [
 *   ["AREA", "gt", 30_000],
 *   "and",
 *   [
 *     ["COLOR", "eq", "red"],
 *     "or",
 *     ["TYPE", "eq", "residential"]
 *   ]
 * ]
 * ```
 *
 * @group Filters
 */
type FilterTernary = [
    FilterTernary | FilterExpression | null | boolean,
    FilterLogicGate,
    FilterTernary | FilterExpression | null | boolean
];
/**
 *
 * Filters can be used to change which features in a layer are rendered. Filters can be
 * applied to a layer by the {@link LayersController.setLayerFilters | `setLayerFilters`} method on the Felt controller.
 *
 * Filters use a tree structure for combining expressions with logical operators, called a
 * {@link FilterTernary}. When combining three or more conditions, you must use proper nesting
 * rather than a flat list.
 *
 * See the examples below for the correct structure to use when building complex filters.
 *
 * @remarks
 * The possible operators are:
 * - `lt`: Less than
 * - `gt`: Greater than
 * - `le`: Less than or equal to
 * - `ge`: Greater than or equal to
 * - `eq`: Equal to
 * - `ne`: Not equal to
 * - `cn`: Contains
 * - `nc`: Does not contain
 *
 * The allowed boolean operators are:
 * - `and`: Logical AND
 * - `or`: Logical OR
 *
 * @example
 * ```typescript
 * // 1. Simple filter: single condition
 * felt.setLayerFilters({
 *   layerId: "layer-1",
 *   filters: ["AREA", "gt", 30_000],
 * });
 *
 * // 2. Basic compound filter: two conditions with AND
 * felt.setLayerFilters({
 *   layerId: "layer-1",
 *   filters: [
 *     ["AREA", "gt", 30_000],  // First condition
 *     "and",                   // Logic operator
 *     ["COLOR", "eq", "red"]   // Second condition
 *   ]
 * });
 *
 * // 3. Complex filter: three or more conditions require nesting
 * // ⚠️ IMPORTANT: Filters use a tree structure, not a flat list
 * felt.setLayerFilters({
 *   layerId: "layer-1",
 *   filters: [
 *     ["AREA", "gt", 30_000],                // First condition
 *     "and",                                 // First logic operator
 *     [                                      // Nested group starts
 *       ["COLOR", "eq", "red"],              //   Second condition
 *       "and",                               //   Second logic operator
 *       ["TYPE", "eq", "residential"]        //   Third condition
 *     ]                                      // Nested group ends
 *   ]
 * });
 *
 * // 4. Even more complex: four conditions with proper nesting
 * // Visual structure:
 * //          AND
 * //         /   \
 * //    condition  AND
 * //              /   \
 * //        condition  AND
 * //                  /   \
 * //            condition  condition
 * felt.setLayerFilters({
 *   layerId: "layer-1",
 *   filters: [
 *     ["AREA", "gt", 30_000],                // First condition
 *     "and",
 *     [
 *       ["COLOR", "eq", "red"],              // Second condition
 *       "and",
 *       [
 *         ["TYPE", "eq", "residential"],     // Third condition
 *         "and",
 *         ["YEAR", "gt", 2000]               // Fourth condition
 *       ]
 *     ]
 *   ]
 * });
 *
 * // 5. Mixed operators: combining AND and OR
 * // Visual structure:
 * //          AND
 * //         /   \
 * //    condition  OR
 * //              /  \
 * //        condition condition
 * felt.setLayerFilters({
 *   layerId: "layer-1",
 *   filters: [
 *     ["AREA", "gt", 30_000],                // Must have large area
 *     "and",
 *     [
 *       ["COLOR", "eq", "red"],              // Must be either red
 *       "or",
 *       ["TYPE", "eq", "residential"]        // OR residential type
 *     ]
 *   ]
 * });
 * ```
 *
 * @group Filters
 */
type Filters = FilterTernary | FilterExpression | null | boolean;
/**
 * The filters that are currently set on a layer.
 *
 * A layer's filters are the combination of various different places
 * in which filters can be applied.
 *
 * @group Filters
 */
interface LayerFilters {
    /**
     * Filters that are set in the layer's style. These are the lowest level
     * of filters, and can only be set by editing the map.
     */
    style: Filters;
    /**
     * Filters that are set in the layer's components, which are interactive
     * elements in the legend. These can be set by viewers for their own session,
     * but their default value can be set by the map creator.
     */
    components: Filters;
    /**
     * Filters that are set ephemerally by viewers in their own session.
     *
     * These are the filters that are set when the {@link LayersController.setLayerFilters | `setLayerFilters`} method is
     * called. There is no way to set these in the Felt UI - they can only be
     * set using the SDK.
     */
    ephemeral: Filters;
    /**
     * The combined result of all the filters set on the layer.
     */
    combined: Filters;
}
/**
 * The common type for filtering data by a spatial boundary.
 *
 * This can be either:
 * - `FeltBoundary`: a [w, s, e, n] bounding box
 * - `PolygonGeometry`: a GeoJSON Polygon geometry
 * - `MultiPolygonGeometry`: a GeoJSON MultiPolygon geometry
 * - `LngLatTuple[]`: a list of coordinates describing a single ring of a polygon
 *
 * @group Filters
 */
type GeometryFilter = FeltBoundary | PolygonGeometry | MultiPolygonGeometry | LngLatTuple[];
/**
 * All the different sources for boundaries for a layer, including their combined result.
 *
 * @group Filters
 */
interface LayerBoundaries {
    /**
     * Boundaries set by drawing spatial filters on the map.
     *
     * When there are multiple spatial filters, they are combined into a multi-polygon.
     */
    spatialFilters: MultiPolygonGeometry | null;
    /**
     * Boundaries that are set ephemerally by viewers in their own session.
     *
     * These are the filters that are set when the {@link LayersController.setLayerBoundary}
     * method is called. There is no way to set these in the Felt UI - they can only be
     * set using the SDK.
     */
    ephemeral: GeometryFilter | null;
    /**
     * The combined result of all the boundaries set on the layer.
     *
     * Each different source of boundary is intersected to produce the combined result.
     *
     */
    combined: MultiPolygonGeometry | null;
}

declare const AggregateMethodSchema: z.ZodEnum<["avg", "max", "min", "sum", "median"]>;
declare const AggregationConfigSchema: z.ZodObject<{
    /**
     * The operation to use on the values from the features in the layer
     */
    method: z.ZodEnum<["avg", "max", "min", "sum", "median"]>;
    /**
     * The attribute to use for the aggregation. This must be a numeric attribute.
     */
    attribute: z.ZodString;
}, "strip", z.ZodTypeAny, {
    attribute: string;
    method: "avg" | "max" | "min" | "sum" | "median";
}, {
    attribute: string;
    method: "avg" | "max" | "min" | "sum" | "median";
}>;
declare const MutliAggregationConfigSchema: z.ZodObject<{
    /**
     * The operations to use on the values from the features in the layer
     */
    methods: z.ZodArray<z.ZodUnion<[z.ZodEnum<["avg", "max", "min", "sum", "median"]>, z.ZodLiteral<"count">]>, "many">;
    /**
     * The attribute to use for the aggregation. This must be a numeric attribute.
     */
    attribute: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    methods: ("avg" | "max" | "min" | "sum" | "median" | "count")[];
    attribute?: string | undefined;
}, {
    methods: ("avg" | "max" | "min" | "sum" | "median" | "count")[];
    attribute?: string | undefined;
}>;
/**
 * Defines how to aggregate a value across features in a layer.
 *
 * @group Stats
 */
interface AggregationConfig extends zInfer<typeof AggregationConfigSchema> {
    /**
     * The method to use for the aggregation.
     */
    method: AggregationMethod;
}
/**
 * The method to use for the aggregation.
 *
 * @group Stats
 */
type AggregationMethod = z.infer<typeof AggregateMethodSchema>;
/**
 * Defines how to aggregate a value across features in a layer with multiple aggregations
 * returned at once.
 *
 * @group Stats
 */
interface MultiAggregationConfig<T extends AggregationMethod | "count"> extends zInfer<typeof MutliAggregationConfigSchema> {
    methods: T[];
    /**
     * The attribute to use for the aggregation when aggregations other than "count" are used.
     *
     * This can be omitted if the only aggregation is "count", but must be a numeric attribute
     * otherwise.
     */
    attribute?: string;
}
declare const ValueConfigurationSchema: z.ZodObject<{
    boundary: z.ZodOptional<z.ZodUnion<[z.ZodTuple<[z.ZodNumber, z.ZodNumber, z.ZodNumber, z.ZodNumber], null>, z.ZodObject<{
        type: z.ZodLiteral<"Polygon">;
        coordinates: z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">;
    }, "strip", z.ZodTypeAny, {
        type: "Polygon";
        coordinates: [number, number][][];
    }, {
        type: "Polygon";
        coordinates: [number, number][][];
    }>, z.ZodObject<{
        type: z.ZodLiteral<"MultiPolygon">;
        coordinates: z.ZodArray<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">, "many">;
    }, "strip", z.ZodTypeAny, {
        type: "MultiPolygon";
        coordinates: [number, number][][][];
    }, {
        type: "MultiPolygon";
        coordinates: [number, number][][][];
    }>, z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">]>>;
    filters: z.ZodOptional<z.ZodUnion<[z.ZodType<FilterTernary, z.ZodTypeDef, FilterTernary>, z.ZodUnion<[z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["in", "ni"]>, z.ZodUnion<[z.ZodArray<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>, "many">, z.ZodNull]>], null>, z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["lt", "gt", "le", "ge", "eq", "ne", "cn", "nc", "is", "isnt"]>, z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>], null>]>, z.ZodNull, z.ZodBoolean]>>;
    aggregation: z.ZodOptional<z.ZodObject<{
        /**
         * The operation to use on the values from the features in the layer
         */
        method: z.ZodEnum<["avg", "max", "min", "sum", "median"]>;
        /**
         * The attribute to use for the aggregation. This must be a numeric attribute.
         */
        attribute: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        attribute: string;
        method: "avg" | "max" | "min" | "sum" | "median";
    }, {
        attribute: string;
        method: "avg" | "max" | "min" | "sum" | "median";
    }>>;
}, "strip", z.ZodTypeAny, {
    boundary?: [number, number, number, number] | [number, number][] | {
        type: "Polygon";
        coordinates: [number, number][][];
    } | {
        type: "MultiPolygon";
        coordinates: [number, number][][][];
    } | undefined;
    filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
    aggregation?: {
        attribute: string;
        method: "avg" | "max" | "min" | "sum" | "median";
    } | undefined;
}, {
    boundary?: [number, number, number, number] | [number, number][] | {
        type: "Polygon";
        coordinates: [number, number][][];
    } | {
        type: "MultiPolygon";
        coordinates: [number, number][][][];
    } | undefined;
    filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
    aggregation?: {
        attribute: string;
        method: "avg" | "max" | "min" | "sum" | "median";
    } | undefined;
}>;
/**
 * Configuration for filtering and aggregating values across features.
 *
 * This can be used to restrict the features considered for aggregation via the `boundary`
 * and `filters` properties.
 *
 * It can also be used to specify how to aggregate the values via the `aggregation` property.
 *
 * @group Stats
 */
interface ValueConfiguration extends zInfer<typeof ValueConfigurationSchema> {
    /**
     * The spatial boundary for what to count or aggregate.
     */
    boundary?: GeometryFilter;
    /**
     * Attribute filters to determine what gets counted or aggregated.
     */
    filters?: Filters;
    /**
     * Specifies how to aggregate values within each category or bin. When omitted,
     * features are counted. When specified, the chosen calculation (avg, sum, etc.)
     * is performed on the specified attribute.
     *
     * For example, instead of counting buildings in each category, you might want
     * to sum their square footage or average their assessed values.
     */
    aggregation?: AggregationConfig;
}
declare const GetLayerCategoriesParamsSchema: z.ZodObject<{
    /**
     * The ID of the layer to get categories from.
     */
    layerId: z.ZodString;
    /**
     * The attribute to use for categorization.
     */
    attribute: z.ZodString;
    /**
     * The maximum number of categories to return.
     */
    limit: z.ZodOptional<z.ZodNumber>;
    boundary: z.ZodOptional<z.ZodUnion<[z.ZodTuple<[z.ZodNumber, z.ZodNumber, z.ZodNumber, z.ZodNumber], null>, z.ZodObject<{
        type: z.ZodLiteral<"Polygon">;
        coordinates: z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">;
    }, "strip", z.ZodTypeAny, {
        type: "Polygon";
        coordinates: [number, number][][];
    }, {
        type: "Polygon";
        coordinates: [number, number][][];
    }>, z.ZodObject<{
        type: z.ZodLiteral<"MultiPolygon">;
        coordinates: z.ZodArray<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">, "many">;
    }, "strip", z.ZodTypeAny, {
        type: "MultiPolygon";
        coordinates: [number, number][][][];
    }, {
        type: "MultiPolygon";
        coordinates: [number, number][][][];
    }>, z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">]>>;
    filters: z.ZodOptional<z.ZodUnion<[z.ZodType<FilterTernary, z.ZodTypeDef, FilterTernary>, z.ZodUnion<[z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["in", "ni"]>, z.ZodUnion<[z.ZodArray<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>, "many">, z.ZodNull]>], null>, z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["lt", "gt", "le", "ge", "eq", "ne", "cn", "nc", "is", "isnt"]>, z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>], null>]>, z.ZodNull, z.ZodBoolean]>>;
    values: z.ZodOptional<z.ZodObject<{
        boundary: z.ZodOptional<z.ZodUnion<[z.ZodTuple<[z.ZodNumber, z.ZodNumber, z.ZodNumber, z.ZodNumber], null>, z.ZodObject<{
            type: z.ZodLiteral<"Polygon">;
            coordinates: z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">;
        }, "strip", z.ZodTypeAny, {
            type: "Polygon";
            coordinates: [number, number][][];
        }, {
            type: "Polygon";
            coordinates: [number, number][][];
        }>, z.ZodObject<{
            type: z.ZodLiteral<"MultiPolygon">;
            coordinates: z.ZodArray<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">, "many">;
        }, "strip", z.ZodTypeAny, {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        }, {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        }>, z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">]>>;
        filters: z.ZodOptional<z.ZodUnion<[z.ZodType<FilterTernary, z.ZodTypeDef, FilterTernary>, z.ZodUnion<[z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["in", "ni"]>, z.ZodUnion<[z.ZodArray<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>, "many">, z.ZodNull]>], null>, z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["lt", "gt", "le", "ge", "eq", "ne", "cn", "nc", "is", "isnt"]>, z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>], null>]>, z.ZodNull, z.ZodBoolean]>>;
        aggregation: z.ZodOptional<z.ZodObject<{
            /**
             * The operation to use on the values from the features in the layer
             */
            method: z.ZodEnum<["avg", "max", "min", "sum", "median"]>;
            /**
             * The attribute to use for the aggregation. This must be a numeric attribute.
             */
            attribute: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            attribute: string;
            method: "avg" | "max" | "min" | "sum" | "median";
        }, {
            attribute: string;
            method: "avg" | "max" | "min" | "sum" | "median";
        }>>;
    }, "strip", z.ZodTypeAny, {
        boundary?: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | undefined;
        filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
        aggregation?: {
            attribute: string;
            method: "avg" | "max" | "min" | "sum" | "median";
        } | undefined;
    }, {
        boundary?: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | undefined;
        filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
        aggregation?: {
            attribute: string;
            method: "avg" | "max" | "min" | "sum" | "median";
        } | undefined;
    }>>;
}, "strip", z.ZodTypeAny, {
    attribute: string;
    layerId: string;
    values?: {
        boundary?: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | undefined;
        filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
        aggregation?: {
            attribute: string;
            method: "avg" | "max" | "min" | "sum" | "median";
        } | undefined;
    } | undefined;
    boundary?: [number, number, number, number] | [number, number][] | {
        type: "Polygon";
        coordinates: [number, number][][];
    } | {
        type: "MultiPolygon";
        coordinates: [number, number][][][];
    } | undefined;
    filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
    limit?: number | undefined;
}, {
    attribute: string;
    layerId: string;
    values?: {
        boundary?: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | undefined;
        filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
        aggregation?: {
            attribute: string;
            method: "avg" | "max" | "min" | "sum" | "median";
        } | undefined;
    } | undefined;
    boundary?: [number, number, number, number] | [number, number][] | {
        type: "Polygon";
        coordinates: [number, number][][];
    } | {
        type: "MultiPolygon";
        coordinates: [number, number][][][];
    } | undefined;
    filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
    limit?: number | undefined;
}>;
/**
 * The parameters for getting categories from a layer, passed to
 * the {@link LayersController.getCategoryData} method.
 *
 * @group Stats
 */
interface GetLayerCategoriesParams extends zInfer<typeof GetLayerCategoriesParamsSchema> {
    /**
     * Attribute filters for the features to include when calculating the categories.
     */
    filters?: Filters;
    /**
     * The spatial boundary for the features to include when calculating the categories.
     */
    boundary?: GeometryFilter;
    /**
     * Configuration for filtering and aggregating values while preserving the full set of
     * categories in the results.
     *
     * This is particularly useful when you want to compare different subsets of data while
     * maintaining consistent categories. For example:
     *
     * - Show all building types in a city, but only count recent buildings in each type
     * - Keep all neighborhood categories but only sum up residential square footage
     *
     * Unlike top-level filters which affect both what categories appear AND their values,
     * filters in this configuration only affect the values while keeping all possible
     * categories in the results.
     */
    values?: ValueConfiguration;
}
declare const GetLayerCategoriesGroupSchema: z.ZodObject<{
    /**
     * The category for which the value was calculated.
     */
    key: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
    /**
     * The value calculated for the category, whether a count, sum, average, etc.
     *
     * `null` is returned if there are no features in the category as opposed to zero,
     * so as not to confuse with a real zero value from some aggregation.
     */
    value: z.ZodNullable<z.ZodNumber>;
}, "strip", z.ZodTypeAny, {
    value: number | null;
    key: string | number | boolean;
}, {
    value: number | null;
    key: string | number | boolean;
}>;
/**
 * A single category from the response from the {@link LayersController.getCategoryData} method.
 *
 * @group Stats
 */
interface GetLayerCategoriesGroup extends zInfer<typeof GetLayerCategoriesGroupSchema> {
}
declare const GetLayerHistogramParamsSchema: z.ZodObject<{
    layerId: z.ZodString;
    attribute: z.ZodString;
    steps: z.ZodUnion<[z.ZodObject<{
        type: z.ZodLiteral<"equal-intervals">;
        count: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        type: "equal-intervals";
        count: number;
    }, {
        type: "equal-intervals";
        count: number;
    }>, z.ZodObject<{
        type: z.ZodLiteral<"time-interval">;
        interval: z.ZodEnum<["hour", "day", "week", "month", "year"]>;
    }, "strip", z.ZodTypeAny, {
        type: "time-interval";
        interval: "hour" | "day" | "week" | "month" | "year";
    }, {
        type: "time-interval";
        interval: "hour" | "day" | "week" | "month" | "year";
    }>, z.ZodArray<z.ZodNumber, "many">]>;
    boundary: z.ZodOptional<z.ZodUnion<[z.ZodTuple<[z.ZodNumber, z.ZodNumber, z.ZodNumber, z.ZodNumber], null>, z.ZodObject<{
        type: z.ZodLiteral<"Polygon">;
        coordinates: z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">;
    }, "strip", z.ZodTypeAny, {
        type: "Polygon";
        coordinates: [number, number][][];
    }, {
        type: "Polygon";
        coordinates: [number, number][][];
    }>, z.ZodObject<{
        type: z.ZodLiteral<"MultiPolygon">;
        coordinates: z.ZodArray<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">, "many">;
    }, "strip", z.ZodTypeAny, {
        type: "MultiPolygon";
        coordinates: [number, number][][][];
    }, {
        type: "MultiPolygon";
        coordinates: [number, number][][][];
    }>, z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">]>>;
    filters: z.ZodOptional<z.ZodUnion<[z.ZodType<FilterTernary, z.ZodTypeDef, FilterTernary>, z.ZodUnion<[z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["in", "ni"]>, z.ZodUnion<[z.ZodArray<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>, "many">, z.ZodNull]>], null>, z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["lt", "gt", "le", "ge", "eq", "ne", "cn", "nc", "is", "isnt"]>, z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>], null>]>, z.ZodNull, z.ZodBoolean]>>;
    /**
     * Configuration for filtering and aggregating values while preserving the full set of
     * bin ranges in the results.
     *
     * This is particularly useful when you want to compare different subsets of data while
     * maintaining consistent ranges. For example:
     *
     * - Use the same height ranges for comparing old vs new buildings
     *
     * Unlike top-level filters which affect both what ranges appear AND their values,
     * filters in this configuration only affect the values while keeping all possible
     * ranges in the results.
     */
    values: z.ZodOptional<z.ZodObject<{
        boundary: z.ZodOptional<z.ZodUnion<[z.ZodTuple<[z.ZodNumber, z.ZodNumber, z.ZodNumber, z.ZodNumber], null>, z.ZodObject<{
            type: z.ZodLiteral<"Polygon">;
            coordinates: z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">;
        }, "strip", z.ZodTypeAny, {
            type: "Polygon";
            coordinates: [number, number][][];
        }, {
            type: "Polygon";
            coordinates: [number, number][][];
        }>, z.ZodObject<{
            type: z.ZodLiteral<"MultiPolygon">;
            coordinates: z.ZodArray<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">, "many">;
        }, "strip", z.ZodTypeAny, {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        }, {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        }>, z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">]>>;
        filters: z.ZodOptional<z.ZodUnion<[z.ZodType<FilterTernary, z.ZodTypeDef, FilterTernary>, z.ZodUnion<[z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["in", "ni"]>, z.ZodUnion<[z.ZodArray<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>, "many">, z.ZodNull]>], null>, z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["lt", "gt", "le", "ge", "eq", "ne", "cn", "nc", "is", "isnt"]>, z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>], null>]>, z.ZodNull, z.ZodBoolean]>>;
        aggregation: z.ZodOptional<z.ZodObject<{
            /**
             * The operation to use on the values from the features in the layer
             */
            method: z.ZodEnum<["avg", "max", "min", "sum", "median"]>;
            /**
             * The attribute to use for the aggregation. This must be a numeric attribute.
             */
            attribute: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            attribute: string;
            method: "avg" | "max" | "min" | "sum" | "median";
        }, {
            attribute: string;
            method: "avg" | "max" | "min" | "sum" | "median";
        }>>;
    }, "strip", z.ZodTypeAny, {
        boundary?: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | undefined;
        filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
        aggregation?: {
            attribute: string;
            method: "avg" | "max" | "min" | "sum" | "median";
        } | undefined;
    }, {
        boundary?: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | undefined;
        filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
        aggregation?: {
            attribute: string;
            method: "avg" | "max" | "min" | "sum" | "median";
        } | undefined;
    }>>;
}, "strip", z.ZodTypeAny, {
    attribute: string;
    layerId: string;
    steps: number[] | {
        type: "equal-intervals";
        count: number;
    } | {
        type: "time-interval";
        interval: "hour" | "day" | "week" | "month" | "year";
    };
    values?: {
        boundary?: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | undefined;
        filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
        aggregation?: {
            attribute: string;
            method: "avg" | "max" | "min" | "sum" | "median";
        } | undefined;
    } | undefined;
    boundary?: [number, number, number, number] | [number, number][] | {
        type: "Polygon";
        coordinates: [number, number][][];
    } | {
        type: "MultiPolygon";
        coordinates: [number, number][][][];
    } | undefined;
    filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
}, {
    attribute: string;
    layerId: string;
    steps: number[] | {
        type: "equal-intervals";
        count: number;
    } | {
        type: "time-interval";
        interval: "hour" | "day" | "week" | "month" | "year";
    };
    values?: {
        boundary?: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | undefined;
        filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
        aggregation?: {
            attribute: string;
            method: "avg" | "max" | "min" | "sum" | "median";
        } | undefined;
    } | undefined;
    boundary?: [number, number, number, number] | [number, number][] | {
        type: "Polygon";
        coordinates: [number, number][][];
    } | {
        type: "MultiPolygon";
        coordinates: [number, number][][][];
    } | undefined;
    filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
}>;
/**
 * The params used to request a histogram of values from a layer, passed to
 * the {@link LayersController.getHistogramData} method.
 *
 * @group Stats
 */
interface GetLayerHistogramParams extends zInfer<typeof GetLayerHistogramParamsSchema> {
    /**
     * Attribute filters for the features to include when calculating the histogram bins.
     */
    filters?: Filters;
    /**
     * The spatial boundary for the features to include when calculating the histogram bins.
     */
    boundary?: GeometryFilter;
}
declare const GetLayerHistogramBinSchema: z.ZodObject<{
    /**
     * The left edge of the bin.
     */
    min: z.ZodNumber;
    /**
     * The right edge of the bin.
     */
    max: z.ZodNumber;
    /**
     * The number of features in the bin.
     */
    value: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    value: number;
    max: number;
    min: number;
}, {
    value: number;
    max: number;
    min: number;
}>;
/**
 * One bin from the response from the {@link LayersController.getHistogramData} method.
 *
 * @group Stats
 */
interface GetLayerHistogramBin extends zInfer<typeof GetLayerHistogramBinSchema> {
}
declare const GetLayerCalculationParamsSchema: z.ZodObject<{
    /**
     * The ID of the layer to calculate an aggregate value for.
     */
    layerId: z.ZodString;
    boundary: z.ZodOptional<z.ZodUnion<[z.ZodTuple<[z.ZodNumber, z.ZodNumber, z.ZodNumber, z.ZodNumber], null>, z.ZodObject<{
        type: z.ZodLiteral<"Polygon">;
        coordinates: z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">;
    }, "strip", z.ZodTypeAny, {
        type: "Polygon";
        coordinates: [number, number][][];
    }, {
        type: "Polygon";
        coordinates: [number, number][][];
    }>, z.ZodObject<{
        type: z.ZodLiteral<"MultiPolygon">;
        coordinates: z.ZodArray<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">, "many">;
    }, "strip", z.ZodTypeAny, {
        type: "MultiPolygon";
        coordinates: [number, number][][][];
    }, {
        type: "MultiPolygon";
        coordinates: [number, number][][][];
    }>, z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">]>>;
    filters: z.ZodOptional<z.ZodUnion<[z.ZodType<FilterTernary, z.ZodTypeDef, FilterTernary>, z.ZodUnion<[z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["in", "ni"]>, z.ZodUnion<[z.ZodArray<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>, "many">, z.ZodNull]>], null>, z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["lt", "gt", "le", "ge", "eq", "ne", "cn", "nc", "is", "isnt"]>, z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>], null>]>, z.ZodNull, z.ZodBoolean]>>;
    aggregation: z.ZodObject<{
        /**
         * The operations to use on the values from the features in the layer
         */
        methods: z.ZodArray<z.ZodUnion<[z.ZodEnum<["avg", "max", "min", "sum", "median"]>, z.ZodLiteral<"count">]>, "many">;
        /**
         * The attribute to use for the aggregation. This must be a numeric attribute.
         */
        attribute: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        methods: ("avg" | "max" | "min" | "sum" | "median" | "count")[];
        attribute?: string | undefined;
    }, {
        methods: ("avg" | "max" | "min" | "sum" | "median" | "count")[];
        attribute?: string | undefined;
    }>;
}, "strip", z.ZodTypeAny, {
    aggregation: {
        methods: ("avg" | "max" | "min" | "sum" | "median" | "count")[];
        attribute?: string | undefined;
    };
    layerId: string;
    boundary?: [number, number, number, number] | [number, number][] | {
        type: "Polygon";
        coordinates: [number, number][][];
    } | {
        type: "MultiPolygon";
        coordinates: [number, number][][][];
    } | undefined;
    filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
}, {
    aggregation: {
        methods: ("avg" | "max" | "min" | "sum" | "median" | "count")[];
        attribute?: string | undefined;
    };
    layerId: string;
    boundary?: [number, number, number, number] | [number, number][] | {
        type: "Polygon";
        coordinates: [number, number][][];
    } | {
        type: "MultiPolygon";
        coordinates: [number, number][][][];
    } | undefined;
    filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
}>;
/**
 * The parameters for calculating a single aggregate value for a layer, passed to
 * the {@link LayersController.getAggregates} method.
 *
 * @group Stats
 */
interface GetLayerCalculationParams<T extends AggregationMethod | "count"> extends z.infer<typeof GetLayerCalculationParamsSchema> {
    /**
     * Attribute filters for the features to include when calculating the aggregate value.
     */
    filters?: Filters;
    /**
     * The spatial boundary for the features to include when calculating the aggregate value.
     */
    boundary?: GeometryFilter;
    /**
     * Specifies how to aggregate values within each category or bin. When omitted,
     * features are counted. When specified, the chosen calculation (avg, sum, etc.)
     * is performed on the specified attribute.
     */
    aggregation: MultiAggregationConfig<T>;
}

/**
 * The Layers controller allows you to get information about the layers on the
 * map, and make changes to their visibility.
 *
 * Layers can be organised into groups, and their groups can also have their
 * visibility toggled.
 *
 * @group Controller
 * @public
 */
interface LayersController {
    /**
     * Get a single layer from the map by its id.
     *
     * @example
     * ```typescript
     * const layer = await felt.getLayer("layer-1");
     * ```
     * @returns The requested layer.
     */
    getLayer(
    /**
     * The id of the layer you want to get.
     */
    id: string): Promise<Layer | null>;
    /**
     * Gets layers from the map, according to the constraints supplied. If no
     * constraints are supplied, all layers will be returned.
     *
     * @remarks The layers in the map, ordered by the order specified in Felt. This is not
     * necessarily the order that they are drawn in, as Felt draws points above
     * lines and lines above polygons, for instance.
     *
     * @example
     * ```typescript
     * const layers = await felt.getLayers();
     * ```
     * @returns All layers on the map.
     */
    getLayers(
    /**
     * The constraints to apply to the layers returned from the map.
     */
    constraint?: GetLayersConstraint): Promise<Array<Layer | null>>;
    /**
     * Hide or show layers with the given ids.
     *
     * @example
     * ```typescript
     * felt.setLayerVisibility({ show: ["layer-1", "layer-2"], hide: ["layer-3"] });
     * ```
     */
    setLayerVisibility(visibility: SetVisibilityRequest): Promise<void>;
    /**
     * Set the style for a layer using FSL, the Felt Style Language.
     *
     * Changes are only for this session, and not persisted. This is useful to make
     * temporary changes to a layer's style, such as to highlight a particular layer
     * or feature.
     *
     * See the [FSL documentation](https://developers.felt.com/felt-style-language) for details
     * on how to read and write styles.
     *
     * If the style you set is invalid, you will receive an error explaining the problem
     * in the rejected promise value.
     *
     * @example
     * ```typescript
     * // first get the current style
     * const oldStyle = (await felt.getLayer("layer-1")).style;
     *
     * felt.setLayerStyle({ id: "layer-1", style: {
     *   ...oldStyle,
     *   paint: {
     *     ...oldStyle.paint,
     *     color: "red",
     *   },
     * } });
     * ```
     */
    setLayerStyle(params: {
        /**
         * The id of the layer to set the style for.
         */
        id: string;
        /**
         * The style to set for the layer.
         */
        style: object;
    }): Promise<void>;
    /**
     * Hide or show layers with the given ids from the legend.
     *
     * @example
     * ```typescript
     * felt.setLayerLegendVisibility({ show: ["layer-1", "layer-2"], hide: ["layer-3"] });
     * ```
     */
    setLayerLegendVisibility(params: SetVisibilityRequest): Promise<void>;
    /**
     * Adds a listener for when a layer changes.
     *
     * @returns A function to unsubscribe from the listener
     *
     * @event
     * @example
     * ```typescript
     * const unsubscribe = felt.onLayerChange({
     *   options: { id: "layer-1" },
     *   handler: ({layer}) => console.log(layer.bounds),
     * });
     *
     * // later on...
     * unsubscribe();
     * ```
     */
    onLayerChange(args: {
        options: {
            /**
             * The id of the layer to listen for changes to.
             */
            id: string;
        };
        /**
         * The handler that is called when the layer changes.
         */
        handler: (
        /**
         * An object describing the change that occurred.
         */
        change: LayerChangeCallbackParams) => void;
    }): VoidFunction;
    /**
     * Adds layers to the map from file or URL sources.
     *
     * @remarks This allows you to add temporary layers to the map that don't depend on
     * any processing by Felt. This is useful for viewing data from external sources or
     * remote files.
     *
     * @returns The layer groups that were created.
     *
     * @example
     * ```typescript
     * const layerFromFile = await felt.createLayersFromGeoJson({
     *   source: {
     *     type: "geoJsonFile",
     *     file: someFile,
     *   },
     *   name: "Parcels",
     * });
     *
     * const layerFromUrl = await felt.createLayersFromGeoJson({
     *   source: {
     *     sourceType: "geoJsonUrl",
     *     url: "https://example.com/parcels.geojson",
     *   },
     *   name: "Parcels",
     * ```
     */
    createLayersFromGeoJson(params: CreateLayersFromGeoJsonParams): Promise<{
        /**
         * The layer group that was created containing the created layers.
         */
        layerGroup: LayerGroup;
        /**
         * The layers that were created from the source.
         */
        layers: Array<Layer>;
    } | null>;
    /**
     * Update a layer by passing a subset of the layer's properties.
     *
     * Note that not all properties can be updated, so check the {@link UpdateLayerParams}
     * type to see which properties can be updated.
     *
     * @example
     * ```typescript
     * await felt.updateLayer({
     *   id: "layer-1",
     *   name: "My Layer",
     *   caption: "A description of the layer",
     * });
     * ```
     */
    updateLayer(params: UpdateLayerParams): Promise<Layer>;
    /**
     * Delete a layer from the map by its id.
     *
     * @remarks This only works for layers created via the SDK `createLayersFromGeoJson` method, not layers added via the Felt UI.
     *
     * @example
     * ```typescript
     * await felt.deleteLayer("layer-1");
     * ```
     */
    deleteLayer(id: string): Promise<void>;
    /**
     * Get a layer group from the map by its id.
     *
     * @example
     * ```typescript
     * const layerGroup = await felt.getLayerGroup("layer-group-1");
     * ```
     * @returns The requested layer group.
     */
    getLayerGroup(id: string): Promise<LayerGroup | null>;
    /**
     * Gets layer groups from the map, according to the constraints supplied. If no
     * constraints are supplied, all layer groups will be returned in rendering order.
     *
     * @example
     * ```typescript
     * const layerGroups = await felt.getLayerGroups({ ids: ["layer-group-1", "layer-group-2"] });
     * ```
     * @returns The requested layer groups.
     */
    getLayerGroups(
    /**
     * The constraints to apply to the layer groups returned from the map.
     */
    constraint?: GetLayerGroupsConstraint): Promise<Array<LayerGroup | null>>;
    /**
     * Hide or show layer groups with the given ids.
     *
     * @example
     * ```typescript
     * felt.setLayerGroupVisibility({ show: ["layer-group-1", "layer-group-2"], hide: ["layer-group-3"] });
     * ```
     */
    setLayerGroupVisibility(visibility: SetVisibilityRequest): Promise<void>;
    /**
     * Hide or show layer groups with the given ids from the legend.
     *
     * @example
     * ```typescript
     * felt.setLayerGroupLegendVisibility({ show: ["layer-1", "layer-2"], hide: ["layer-3"] });
     * ```
     */
    setLayerGroupLegendVisibility(params: SetVisibilityRequest): Promise<void>;
    /**
     * Adds a listener for when a layer group changes.
     *
     * @returns A function to unsubscribe from the listener
     *
     * @event
     * @example
     * ```typescript
     * const unsubscribe = felt.onLayerGroupChange({
     *   options: { id: "layer-group-1" },
     *   handler: ({layerGroup}) => console.log(layerGroup.id),
     * });
     *
     * // later on...
     * unsubscribe();
     * ```
     */
    onLayerGroupChange(args: {
        options: {
            id: string;
        };
        handler: (change: LayerGroupChangeCallbackParams) => void;
    }): VoidFunction;
    /**
     * Allows you to get the state of a single legend item.
     *
     * @example
     * ```typescript
     * const legendItem = await felt.getLegendItem({
     *   id: "legend-item-1",
     *   layerId: "layer-1",
     * })
     * ```
     */
    getLegendItem(id: LegendItemIdentifier): Promise<LegendItem | null>;
    /**
     * Allows you to obtain the state of several legend items, by passing in
     * constraints describing which legend items you want.
     *
     * If you do not pass any constraints, you will receive all legend items.
     *
     * @example
     * ```typescript
     * const legendItems = await felt.getLegendItems({layerId: "layer-1"});
     * ```
     */
    getLegendItems(constraint?: LegendItemsConstraint): Promise<Array<LegendItem | null>>;
    /**
     * Hide or show legend items with the given identifiers.
     *
     * @example
     * ```typescript
     * felt.setLegendItemVisibility({
     *   show: [{layerId: "layer-group-1", id: "item-1-0"}],
     *   hide: [{layerId: "layer-group-2", id: "item-2-0"}],
     * })
     * ```
     */
    setLegendItemVisibility(visibility: {
        show?: Array<LegendItemIdentifier>;
        hide?: Array<LegendItemIdentifier>;
    }): Promise<void>;
    /**
     * Adds a listener for when a legend item changes.
     *
     * @returns A function to unsubscribe from the listener
     *
     * @event
     * @example
     * ```typescript
     * const unsubscribe = felt.onLegendItemChange({
     *   options: { layerId: "layer-1", id: "item-1-0" },
     *   handler: ({legendItem}) => console.log(legendItem.visible),
     * });
     *
     * // later on...
     * unsubscribe();
     * ```
     */
    onLegendItemChange(args: {
        options: LegendItemIdentifier;
        handler: (change: LegendItemChangeCallbackParams) => void;
    }): VoidFunction;
    /**
     * Get the filters for a layer.
     *
     * @remarks
     * The return type gives you the filters split up into the various sources
     * that make up the overall filters for a layer.
     *
     * @example
     * ```typescript
     * const filters = await felt.getLayerFilters("layer-1");
     * console.log(filters.combined, filters.style, filters.ephemeral, filters.components);
     * ```
     */
    getLayerFilters(layerId: string): Promise<LayerFilters | null>;
    /**
     * Sets the **ephemeral** filters for a layer.
     *
     * @example
     * ```typescript
     * await felt.setLayerFilters({
     *   layerId: "layer-1",
     *   filters: ["AREA", "gt", 30_000],
     * });
     * ```
     */
    setLayerFilters(params: {
        /**
         * The layer that you want to set the filters for.
         */
        layerId: string;
        /**
         * The filters to set for the layer. This will replace any ephemeral filters
         * that are currently set for the layer.
         */
        filters: Filters;
        /**
         * A note to display on the layer legend when this filter is applied. When the
         * note is shown, a reset button will also be shown, allowing the user to clear
         * the filter.
         */
        note?: string;
    }): Promise<void>;
    /**
     * Adds a listener for when a layer's filters change.
     *
     * @returns A function to unsubscribe from the listener
     *
     * @remarks
     * This event fires whenever any type of filter changes on the layer, including
     * ephemeral filters set via the SDK, style-based filters, or filters set through
     * the Felt UI via Components.
     *
     * @event
     * @example
     * ```typescript
     * const unsubscribe = felt.onLayerFiltersChange({
     *   options: { layerId: "layer-1" },
     *   handler: ({combined, ephemeral, style, components}) => {
     *     console.log("Layer filters updated:", {
     *       combined,  // All filters combined
     *       ephemeral, // Filters set via SDK
     *       style,     // Filters from layer style
     *       components // Filters from UI components
     *     });
     *   },
     * });
     *
     * // later on...
     * unsubscribe();
     * ```
     */
    onLayerFiltersChange(params: {
        options: {
            layerId: string;
        };
        handler: (change: LayerFilters) => void;
    }): VoidFunction;
    /**
     * Get the spatial boundaries that are filtering a layer.
     *
     * @remarks
     * The return type gives you the boundaries split up into the various sources
     * that make up the overall boundary for a layer.
     *
     * The combined boundary is the intersection of the other sources of boundaries.
     *
     * @example
     * ```typescript
     * const boundaries = await felt.getLayerBoundaries("layer-1");
     *
     * console.log(boundaries?.combined);
     * console.log(boundaries?.spatialFilters);
     * console.log(boundaries?.ephemeral);
     * ```
     */
    getLayerBoundaries(layerId: string): Promise<LayerBoundaries | null>;
    /**
     * Set the {@link LayerBoundaries.ephemeral | `ephemeral`} boundary for one or more layers.
     *
     * @example
     * ```typescript
     * await felt.setLayerBoundary({
     *   layerIds: ["layer-1", "layer-2"],
     *   boundary: { type: "MultiPolygon", coordinates: [[[100, 0], [101, 0], [101, 1], [100, 1], [100, 0]]] }
     * });
     * ```
     */
    setLayerBoundary(params: {
        /**
         * The ids of the layers to set the boundary for.
         */
        layerIds: Array<string>;
        /**
         * The boundary to set for the layer.
         *
         * Passing `null` clears the ephemeral boundary for the layer.
         */
        boundary: GeometryFilter | null;
    }): Promise<void>;
    /**
     * Adds a listener for when a layer's spatial boundaries change.
     *
     * @returns A function to unsubscribe from the listener
     *
     * @remarks
     * This event fires whenever any type of spatial boundary changes on the layer, including
     * ephemeral boundaries set via the SDK or boundaries set through the Felt UI via
     * Spatial filter components.
     *
     * @event
     * @example
     * ```typescript
     * const unsubscribe = felt.onLayerBoundariesChange({
     *   options: { layerId: "layer-1" },
     *   handler: ({combined, ephemeral, spatialFilters}) => {
     *     console.log("Layer boundaries updated:", {
     *       combined,  // All boundaries combined
     *       ephemeral, // Boundaries set via SDK
     *       spatialFilters // Boundaries set via UI
     *     });
     *   },
     * });
     *
     * // later on...
     * unsubscribe();
     * ```
     */
    onLayerBoundariesChange(params: {
        options: {
            /**
             * The id of the layer to listen for boundary changes on.
             */
            layerId: string;
        };
        /**
         * A function that is called when the boundaries change.
         *
         * @param boundaries - The new boundaries for the layer.
         */
        handler: (boundaries: LayerBoundaries | null) => void;
    }): VoidFunction;
    /**
     * Get the features that are currently **rendered** on the map in the viewport.
     *
     * Note that this is explicitly about the features that are rendered, which isn't
     * necessarily a complete list of all the features in the viewport. This is because
     * of the way features are tiled: at low zoom levels or high feature densities, many
     * features are omitted from what is rendered on the screen.
     *
     * @example
     * ```typescript
     * const features = await felt.getRenderedFeatures();
     * ```
     */
    getRenderedFeatures(
    /**
     * The constraints to apply to the features returned from the map.
     */
    params?: GetRenderedFeaturesConstraint): Promise<Array<LayerFeature>>;
    /**
     * Get a feature from the map by its ID and layer ID.
     *
     * The response is a {@link LayerFeature} object, which does not include the
     * geometry of the feature.
     *
     * You may want to use this when you don't need the geometry of a feature,
     * but you know the ID of the feature you need.
     *
     * @example
     * ```typescript
     * const feature = await felt.getFeature({ layerId: "layer-1", id: 123 });
     * ```
     */
    getFeature(params: {
        id: string | number;
        layerId: string;
    }): Promise<LayerFeature | null>;
    /**
     * Get a list of layer features.
     *
     * @remarks This list is paginated in sets of 20 features for each page. In order to paginate
     * between pages, the response includes `previousPage` and `nextPage` that are tokens
     * that should be sent in the `pagination` params for requesting sibling pages.
     *
     * Text search is case-insensitive and looks for matches across all feature properties.
     *
     * @returns
     * The response is an object which contains:
     *   - `features`: list of {@link LayerFeature} objects, which does not include
     * the geometry of the feature but it does include its bounding box.
     *   - `count`: the total number of features that match the query.
     *   - `previousPage` & `nextPage`: The tokens to pass in the `pagination` param
     * to navigate between pages.
     *
     * @example
     * ```typescript
     * const page1Response = await felt.getFeatures({
     *   layerId: "layer-1",
     *   search: "abc123",
     *   pagination: undefined,
     * });
     *
     * // Note that the search term here matches the one for the first page.
     * if (page1Response.nextPage) {
     *   const page2Response = await felt.getFeatures({
     *     layerId: "layer-1",
     *     search: "abc123",
     *     pagination: page1Response.nextPage,
     *   });
     * }
     * ```
     */
    getFeatures(params: {
        /**
         * The ID of the layer to get features from.
         */
        layerId: string;
        /**
         * Filters to be applied. These filters will merge with layer's own filters.
         */
        filters?: Filters;
        /**
         * Attribute to sort by.
         */
        sorting?: SortConfig;
        /**
         * The spatial boundary to be applied.
         */
        boundary?: GeometryFilter;
        /**
         * Search term to search by.
         *
         * Search is case-insensitive and looks for matches across all feature properties.
         */
        search?: string;
        /**
         * Pagination token. It comes from either the `previousPage` or `nextPage`
         * properties of the previous response.
         */
        pagination?: string | null;
    }): Promise<{
        /**
         * The list of features returned from the query.
         */
        features: LayerFeature[];
        /**
         * The total number of features that match the query.
         */
        count: number;
        /**
         * The pagination token to get the previous page of features.
         */
        previousPage: string | null;
        /**
         * The pagination token to get the next page of features.
         */
        nextPage: string | null;
    }>;
    /**
     * Get a feature in GeoJSON format from the map by its ID and layer ID.
     *
     * The response is a GeoJSON Feature object with the complete geometry of the
     * feature. Note that for some _very_ large geometries, the response may take a
     * long time to return, and may return a very large object.
     *
     * @example
     * ```typescript
     * const feature = await felt.getGeoJsonFeature({ layerId: "layer-1", id: 123 });
     * ```
     */
    getGeoJsonFeature(params: {
        id: string | number;
        layerId: string;
    }): Promise<GeoJsonFeature | null>;
    /**
     * Gets values from a layer grouped by a given attribute.
     *
     * @remarks
     * Groups features in your layer by unique values in the specified attribute and calculates
     * a value for each group. By default, this value is the count of features in each group.
     *
     * You can apply filters in two ways:
     * 1. At the top level (using `boundary` and `filters`), which affects both what categories
     *    are included and how values are calculated
     * 2. In the `values` configuration, which only affects the values but keeps all categories
     *
     * This two-level filtering is particularly useful when you want to compare subsets of data
     * while maintaining consistent categories. For example, you might want to show the distribution
     * of all building types in a city, but only count buildings built after 2000 in each category.
     *
     * @example
     * ```typescript
     * // Basic grouping: Count of buildings by type
     * const buildingsByType = await felt.getCategoryData({
     *   layerId: "buildings",
     *   attribute: "type"
     * });
     *
     * // Filtered grouping: Only count buildings in downtown
     * const downtownBuildingsByType = await felt.getCategoryData({
     *   layerId: "buildings",
     *   attribute: "type",
     *   boundary: [-122.43, 47.60, -122.33, 47.62]  // downtown boundary
     * });
     *
     * // Advanced: Show all building types, but only sum floor area of recent buildings
     * const recentBuildingAreaByType = await felt.getCategoryData({
     *   layerId: "buildings",
     *   attribute: "type",
     *   values: {
     *     filters: ["year_built", "gte", 2000],
     *     aggregation: {
     *       method: "sum",
     *       attribute: "floor_area"
     *     }
     *   }
     * });
     *
     * // Compare residential density across neighborhoods while only counting recent buildings
     * const newBuildingDensityByNeighborhood = await felt.getCategoryData({
     *   layerId: "buildings",
     *   attribute: "neighborhood",
     *   values: {
     *     filters: ["year_built", "gte", 2000],
     *     aggregation: {
     *       method: "avg",
     *       attribute: "units_per_acre"
     *     }
     *   }
     * });
     * ```
     */
    getCategoryData(params: GetLayerCategoriesParams): Promise<Array<GetLayerCategoriesGroup>>;
    /**
     * Gets a histogram of values from a layer for a given attribute.
     *
     * @remarks
     * Creates bins (ranges) for numeric data and counts how many features fall into each bin,
     * or returns aggregated values for each bin.
     *
     * You can control how the bins are created using the `steps` parameter, choosing from
     * several methods like equal intervals, quantiles, or natural breaks (Jenks), or passing
     * in the step values directly if you know how you want to bin the data.
     *
     * Like getCategoryData, you can apply filters in two ways:
     * 1. At the top level (using `boundary` and `filters`), which affects both how the bins
     *    are calculated and what features are counted in each bin
     * 2. In the `values` configuration, which only affects what gets counted but keeps the
     *    bin ranges the same
     *
     * This is particularly useful when you want to compare distributions while keeping
     * consistent bin ranges. For example, you might want to compare the distribution of
     * building heights in different years while using the same height ranges.
     *
     * @example
     * ```typescript
     * // Basic histogram: Building heights in 5 natural break bins
     * const buildingHeights = await felt.getHistogramData({
     *   layerId: "buildings",
     *   attribute: "height",
     *   steps: { type: "jenks", count: 5 }
     * });
     *
     * // Compare old vs new buildings using the same height ranges
     * const oldBuildingHeights = await felt.getHistogramData({
     *   layerId: "buildings",
     *   attribute: "height",
     *   steps: [0, 20, 50, 100, 200, 500],
     *   values: {
     *     filters: ["year_built", "lt", 1950]
     *   }
     * });
     *
     * const newBuildingHeights = await felt.getHistogramData({
     *   layerId: "buildings",
     *   attribute: "height",
     *   steps: [0, 20, 50, 100, 200, 500],  // Same ranges as above
     *   values: {
     *     filters: ["year_built", "gte", 1950]
     *   }
     * });
     * ```
     */
    getHistogramData(params: GetLayerHistogramParams): Promise<Array<GetLayerHistogramBin>>;
    /**
     * Calculates a single aggregate value for a layer based on the provided configuration.
     *
     * @remarks
     * Performs statistical calculations on your data, like counting features or computing
     * averages, sums, etc. You can focus your calculation on specific areas or subsets
     * of your data using boundaries and filters.
     *
     * When no aggregation is specified, it counts features. When an aggregation is provided,
     * it performs that calculation (average, sum, etc.) on the specified attribute.
     *
     * @example
     * ```typescript
     * // Count all residential buildings
     * const residentialCount = await felt.getAggregates({
     *   layerId: "buildings",
     *   filters: ["type", "eq", "residential"]
     * });
     *
     * // Calculate average home value in a specific neighborhood
     * const avgHomeValue = await felt.getAggregates({
     *   layerId: "buildings",
     *   boundary: [-122.43, 47.60, -122.33, 47.62],  // neighborhood boundary
     *   aggregation: {
     *     method: "avg",
     *     attribute: "assessed_value"
     *   }
     * });
     *
     * // Find the maximum building height for buildings built after 2000
     * const maxNewBuildingHeight = await felt.getAggregates({
     *   layerId: "buildings",
     *   filters: ["year_built", "gte", 2000],
     *   aggregation: {
     *     method: "max",
     *     attribute: "height"
     *   }
     * });
     * ```
     */
    getAggregates<T extends AggregationMethod | "count">(params: GetLayerCalculationParams<T>): Promise<Record<T, number | null>>;
    /**
     * Get the schema for a layer.
     *
     * @remarks
     * The schema describes the structure of the data in a layer, including the attributes
     * that are available on the features in the layer.
     *
     * This can be useful to build generic UIs that need to know the structure of the data in
     * a layer, such as a dropdown to choose an attribute.
     *
     * @example
     * ```typescript
     * const schema = await felt.getLayerSchema("layer-1");
     * const attributeIds = schema.attributes.map((attr) => attr.id);
     * ```
     */
    getLayerSchema(layerId: string): Promise<LayerSchema>;
}

/**
 * The event object passed to the interaction listeners.
 */
interface MapInteractionEvent {
    /**
     * The cursor position in world coordinates.
     */
    coordinate: LatLng;
    /**
     * The pixel coordinates of the mouse cursor, relative to the map and measured from the top left corner.
     */
    point: {
        x: number;
        y: number;
    };
    /**
     * The vector features that are under the cursor.
     */
    features: Array<LayerFeature>;
    /**
     * The raster pixel values that are under the cursor.
     */
    rasterValues: Array<RasterValue>;
}

/**
 * The Interactions controller allows you to observe interactions with the map
 *
 * @group Controller
 * @public
 */
interface InteractionsController {
    /**
     * Allows you to be notified the user clicks on the map.
     *
     * @returns A function to unsubscribe from the listener
     *
     * @event
     * @example
     * ```typescript
     * const unsubscribe = felt.onPointerClick({
     *   handler: (event) => console.log(event.center, event.features),
     * });
     *
     * // later on...
     * unsubscribe();
     * ```
     */
    onPointerClick(params: {
        handler: (event: MapInteractionEvent) => void;
    }): VoidFunction;
    /**
     * Allows you to be notified the user moves the mouse over the map.
     *
     * @returns A function to unsubscribe from the listener
     *
     * @event
     * @example
     * ```typescript
     * // Track mouse movement and features under cursor
     * const unsubscribe = felt.onPointerMove({
     *   handler: (event) => {
     *     console.log("Mouse position:", event.center);
     *     console.log("Features under cursor:", event.features);
     *   }
     * });
     *
     * // later on...
     * unsubscribe();
     * ```
     */
    onPointerMove(
    /**
     * Params for the listener
     */
    params: {
        /**
         * The handler function
         */
        handler: (event: MapInteractionEvent) => void;
    }): VoidFunction;
}

/**
 * The details of a map.
 *
 * @group Types
 */
type MapDetails = {
    /**
     * The id of the map.
     */
    id: string;
    /**
     * The title of the map.
     */
    title: string;
    /**
     * The description of the map.
     */
    description: string | null;
};

/**
 * @group Controller
 * @public
 */
interface MiscController {
    /**
     * Gets the details of the map.
     *
     * @example
     * ```typescript
     * const details = await felt.getMapDetails();
     * console.log({
     *   id: details.id,
     *   title: details.title,
     *   description: details.description,
     * });
     * ```
     */
    getMapDetails(): Promise<MapDetails>;
}

/**
 * A reference to any kind of entity in the map.
 *
 * @remarks
 * EntityNodes are used when you have some collection of entities and you need to
 *
 * @group Entity Node
 */
type EntityNode = ElementNode | ElementGroupNode | LayerNode | LayerGroupNode | FeatureNode;
/**
 * References an element on the map.
 *
 * @interface
 * @group Entity Nodes
 */
type ElementNode = {
    type: "element";
    entity: Element;
};
/**
 * References an element group.
 *
 * @interface
 * @group Entity Nodes
 */
type ElementGroupNode = {
    type: "elementGroup";
    entity: ElementGroup;
};
/**
 * References a layer on the map.
 *
 * @interface
 * @group Entity Nodes
 */
type LayerNode = {
    type: "layer";
    entity: Layer;
};
/**
 * References a layer group on the map.
 *
 * @interface
 * @group Entity Nodes
 */
type LayerGroupNode = {
    type: "layerGroup";
    entity: LayerGroup;
};
/**
 * References a feature on the map.
 *
 * @interface
 * @group Entity Nodes
 */
type FeatureNode = {
    type: "feature";
    entity: LayerFeature;
};
/**
 * The options for selecting a feature in a layer.
 */
interface FeatureSelection extends zInfer<typeof FeatureSelectionSchema> {
}
/**
 * @ignore
 */
declare const FeatureSelectionSchema: z.ZodObject<{
    /**
     * The id of the feature to select.
     */
    id: z.ZodUnion<[z.ZodString, z.ZodNumber]>;
    /**
     * The id of the layer that the feature belongs to.
     */
    layerId: z.ZodString;
    /**
     * Whether to show the feature's popup, if it is configured in the layer's style.
     *
     * @default true
     */
    showPopup: z.ZodOptional<z.ZodBoolean>;
    /**
     * Whether to center the view on the feature after selecting it.
     *
     * When true, the viewport will be centered on the feature and zoomed to fit the feature
     * in the viewport. If you need to control the zoom level to prevent it zooming in too
     * far, you can pass an object with a `maxZoom` property.
     *
     * This is useful for avoiding zooming in too far on point features, or if you want
     * to maintain the current zoom level.
     *
     * @default true
     */
    fitViewport: z.ZodOptional<z.ZodUnion<[z.ZodBoolean, z.ZodObject<{
        maxZoom: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        maxZoom: number;
    }, {
        maxZoom: number;
    }>]>>;
}, "strip", z.ZodTypeAny, {
    id: string | number;
    layerId: string;
    showPopup?: boolean | undefined;
    fitViewport?: boolean | {
        maxZoom: number;
    } | undefined;
}, {
    id: string | number;
    layerId: string;
    showPopup?: boolean | undefined;
    fitViewport?: boolean | {
        maxZoom: number;
    } | undefined;
}>;

/**
 * The Selection controller allows you to listen for changes to the selection on the map.
 *
 * @group Controller
 * @public
 */
interface SelectionController {
    /**
     * Gets the current selection as a list of entity identifiers.
     *
     * @example
     * ```typescript
     * const selection = await felt.getSelection();
     * ```
     */
    getSelection(): Promise<EntityNode[]>;
    /**
     * Adds a listener for when the selection changes.
     *
     * @returns A function to unsubscribe from the listener
     *
     * @event
     * @example
     * ```typescript
     * const unsubscribe = felt.onSelectionChange({
     *   handler: ({selection}) => console.log(selection),
     * });
     *
     * // later on...
     * unsubscribe();
     * ```
     */
    onSelectionChange(params: {
        handler: (change: {
            /**
             * The new selection. In the case where there are multiple entities selected,
             * the array describes the chronological and semeantic order of the selection.
             *
             * Entities of the same type that are selected later will appear later in the
             * list, but there are cases where multiple entity types can be selected at once,
             * such as elements and features. In this case, the order of the _types_ of entities
             * tells you which are considered more semantically important.
             *
             * For example, if a feature and element are selected, the feature will be at the
             * tail of the list because pressing Escape will deselect the feature first, then
             * pressing Escape again will deselect the element.
             */
            selection: EntityNode[];
        }) => void;
    }): VoidFunction;
    /**
     * Selects a feature on a layer. This will show the feature's popup, modal or
     * sidebar (if configured) and highlight the feature.
     *
     * @example
     * ```typescript
     * felt.selectFeature({
     *   id: 123,
     *   layerId: "my-layer",
     *   showPopup: true,
     *   fitViewport: { maxZoom: 15 },
     * });
     * ```
     */
    selectFeature(params: FeatureSelection): Promise<void>;
    /**
     * Clears the current selection. This clears the selection of
     *
     * @example
     * ```typescript
     *
     * // Removes all features and elements from the selection
     * felt.clearSelection();
     *
     * // Removes only features from the selection
     * felt.clearSelection({ features: true });
     *
     * // Removes only elements from the selection
     * felt.clearSelection({ elements: true });
     * ```
     *
     * @default
     * ```typescript
     * { features: true, elements: true }
     * ```
     *
     * @param params - The parameters to clear the selection. If this is not provided,
     * both features and elements will be cleared.
     */
    clearSelection(params?: {
        /**
         * Whether to clear the features from the selection.
         */
        features?: boolean;
        /**
         * Whether to clear the elements from the selection.
         */
        elements?: boolean;
    }): Promise<void>;
}

declare const ToolSchema: z.ZodEnum<["pin", "line", "route", "polygon", "circle", "marker", "highlighter", "text", "note", "link"]>;
type ToolType = z.infer<typeof ToolSchema>;
type ConfigurableToolType = keyof ToolSettingsMap;
declare const PinToolSettingsSchema: z.ZodObject<{
    symbol: z.ZodString;
    color: z.ZodString;
    frame: z.ZodNullable<z.ZodEnum<["frame-circle", "frame-square"]>>;
    afterCreation: z.ZodEnum<["enter name", "add another", "select"]>;
}, "strip", z.ZodTypeAny, {
    symbol: string;
    color: string;
    frame: "frame-circle" | "frame-square" | null;
    afterCreation: "enter name" | "add another" | "select";
}, {
    symbol: string;
    color: string;
    frame: "frame-circle" | "frame-square" | null;
    afterCreation: "enter name" | "add another" | "select";
}>;
interface PinToolSettings extends zInfer<typeof PinToolSettingsSchema> {
    symbol: PlaceSymbol;
    /**
     * What to do after creating the Place element.
     *
     * - `"enter name"`: Enter a name for the Place, focusing the name input.
     * - `"add another"`: Add another Place, leaving the tool still selected.
     * - `"select"`: Puts the tool down and selects the new Place element.
     *
     * @defaultValue `"enter name"`
     */
    afterCreation: "enter name" | "add another" | "select";
}
declare const LineToolSettingsSchema: z.ZodObject<{
    color: z.ZodString;
    strokeOpacity: z.ZodNumber;
    strokeWidth: z.ZodNumber;
    strokeStyle: z.ZodEnum<["solid", "dashed", "dotted"]>;
    distanceMarker: z.ZodBoolean;
}, "strip", z.ZodTypeAny, {
    color: string;
    strokeOpacity: number;
    strokeWidth: number;
    strokeStyle: "solid" | "dashed" | "dotted";
    distanceMarker: boolean;
}, {
    color: string;
    strokeOpacity: number;
    strokeWidth: number;
    strokeStyle: "solid" | "dashed" | "dotted";
    distanceMarker: boolean;
}>;
interface LineToolSettings extends zInfer<typeof LineToolSettingsSchema> {
}
declare const RouteToolSettingsSchema: z.ZodObject<{
    color: z.ZodString;
    strokeOpacity: z.ZodNumber;
    strokeWidth: z.ZodNumber;
    strokeStyle: z.ZodEnum<["solid", "dashed", "dotted"]>;
    distanceMarker: z.ZodBoolean;
    routingMode: z.ZodNullable<z.ZodEnum<["driving", "cycling", "walking", "flying"]>>;
    endCaps: z.ZodBoolean;
}, "strip", z.ZodTypeAny, {
    color: string;
    strokeOpacity: number;
    strokeWidth: number;
    strokeStyle: "solid" | "dashed" | "dotted";
    distanceMarker: boolean;
    routingMode: "driving" | "cycling" | "walking" | "flying" | null;
    endCaps: boolean;
}, {
    color: string;
    strokeOpacity: number;
    strokeWidth: number;
    strokeStyle: "solid" | "dashed" | "dotted";
    distanceMarker: boolean;
    routingMode: "driving" | "cycling" | "walking" | "flying" | null;
    endCaps: boolean;
}>;
interface RouteToolSettings extends zInfer<typeof RouteToolSettingsSchema> {
}
declare const PolygonToolSettingsSchema: z.ZodObject<{
    color: z.ZodString;
    strokeOpacity: z.ZodNumber;
    strokeWidth: z.ZodNumber;
    strokeStyle: z.ZodEnum<["solid", "dashed", "dotted"]>;
    fillOpacity: z.ZodNumber;
    areaMarker: z.ZodBoolean;
}, "strip", z.ZodTypeAny, {
    color: string;
    strokeOpacity: number;
    strokeWidth: number;
    strokeStyle: "solid" | "dashed" | "dotted";
    fillOpacity: number;
    areaMarker: boolean;
}, {
    color: string;
    strokeOpacity: number;
    strokeWidth: number;
    strokeStyle: "solid" | "dashed" | "dotted";
    fillOpacity: number;
    areaMarker: boolean;
}>;
interface PolygonToolSettings extends zInfer<typeof PolygonToolSettingsSchema> {
}
declare const CircleToolSettingsSchema: z.ZodObject<{
    color: z.ZodString;
    strokeOpacity: z.ZodNumber;
    strokeWidth: z.ZodNumber;
    strokeStyle: z.ZodEnum<["solid", "dashed", "dotted"]>;
    fillOpacity: z.ZodNumber;
    radiusMarker: z.ZodBoolean;
}, "strip", z.ZodTypeAny, {
    color: string;
    strokeOpacity: number;
    strokeWidth: number;
    strokeStyle: "solid" | "dashed" | "dotted";
    fillOpacity: number;
    radiusMarker: boolean;
}, {
    color: string;
    strokeOpacity: number;
    strokeWidth: number;
    strokeStyle: "solid" | "dashed" | "dotted";
    fillOpacity: number;
    radiusMarker: boolean;
}>;
interface CircleToolSettings extends zInfer<typeof CircleToolSettingsSchema> {
}
declare const MarkerToolSettingsSchema: z.ZodObject<{
    color: z.ZodString;
    opacity: z.ZodNumber;
    size: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    color: string;
    opacity: number;
    size: number;
}, {
    color: string;
    opacity: number;
    size: number;
}>;
interface MarkerToolSettings extends zInfer<typeof MarkerToolSettingsSchema> {
}
declare const HighlighterToolSettingsSchema: z.ZodObject<{
    color: z.ZodString;
    opacity: z.ZodNumber;
    renderHoles: z.ZodBoolean;
    size: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    color: string;
    opacity: number;
    size: number;
    renderHoles: boolean;
}, {
    color: string;
    opacity: number;
    size: number;
    renderHoles: boolean;
}>;
interface HighlighterToolSettings extends zInfer<typeof HighlighterToolSettingsSchema> {
}
declare const TextToolSettingsSchema: z.ZodObject<{
    color: z.ZodString;
    align: z.ZodEnum<["left", "center", "right"]>;
    style: z.ZodEnum<["italic", "light", "regular", "caps"]>;
}, "strip", z.ZodTypeAny, {
    color: string;
    align: "center" | "left" | "right";
    style: "italic" | "light" | "regular" | "caps";
}, {
    color: string;
    align: "center" | "left" | "right";
    style: "italic" | "light" | "regular" | "caps";
}>;
interface TextToolSettings extends zInfer<typeof TextToolSettingsSchema> {
}
declare const NoteToolSettingsSchema: z.ZodObject<{
    color: z.ZodString;
    align: z.ZodEnum<["left", "center", "right"]>;
    style: z.ZodEnum<["italic", "light", "regular", "caps"]>;
}, "strip", z.ZodTypeAny, {
    color: string;
    align: "center" | "left" | "right";
    style: "italic" | "light" | "regular" | "caps";
}, {
    color: string;
    align: "center" | "left" | "right";
    style: "italic" | "light" | "regular" | "caps";
}>;
interface NoteToolSettings extends zInfer<typeof NoteToolSettingsSchema> {
}
/**
 * The parameters for changing the settings of each tool.
 */
type InputToolSettings = ({
    tool: "pin";
} & Partial<PinToolSettings>) | ({
    tool: "line";
} & Partial<LineToolSettings>) | ({
    tool: "route";
} & Partial<RouteToolSettings>) | ({
    tool: "polygon";
} & Partial<PolygonToolSettings>) | ({
    tool: "circle";
} & Partial<CircleToolSettings>) | ({
    tool: "marker";
} & Partial<MarkerToolSettings>) | ({
    tool: "highlighter";
} & Partial<HighlighterToolSettings>) | ({
    tool: "text";
} & Partial<TextToolSettings>) | ({
    tool: "note";
} & Partial<NoteToolSettings>);
/**
 * The result of listening for changes to the settings of each tool.
 */
type ToolSettingsChangeEvent = ({
    tool: "pin";
} & PinToolSettings) | ({
    tool: "line";
} & LineToolSettings) | ({
    tool: "route";
} & RouteToolSettings) | ({
    tool: "polygon";
} & PolygonToolSettings) | ({
    tool: "circle";
} & CircleToolSettings) | ({
    tool: "marker";
} & MarkerToolSettings) | ({
    tool: "highlighter";
} & HighlighterToolSettings) | ({
    tool: "text";
} & TextToolSettings) | ({
    tool: "note";
} & NoteToolSettings);
type ToolSettingsMap = {
    pin: PinToolSettings;
    line: LineToolSettings;
    route: RouteToolSettings;
    polygon: PolygonToolSettings;
    circle: CircleToolSettings;
    marker: MarkerToolSettings;
    highlighter: HighlighterToolSettings;
    text: TextToolSettings;
    note: NoteToolSettings;
};
type PlaceFrame = "frame-circle" | "frame-square" | null;
type PlaceSymbol = "dot" | "square" | "diamond" | "triangle" | "x" | "plus" | "circle-line" | "circle-slash" | "star" | "heart" | "hexagon" | "octagon" | "pedestrian" | "bicycle" | "wheelchair" | "airport" | "car" | "bus" | "train" | "truck" | "ferry" | "sailboat" | "electric-service" | "gas-service" | "blood-clinic" | "badge" | "traffic-light" | "traffic-cone" | "road-sign-caution" | "person" | "restroom" | "house" | "work" | "letter" | "hotel" | "factory" | "hospital" | "religious-facility" | "school" | "government" | "university" | "bank" | "landmark" | "museum" | "clothing" | "shopping" | "store" | "bar" | "pub" | "cafe" | "food" | "park" | "amusement-park" | "camping-tent" | "cabin" | "picnic" | "water-refill" | "trailhead" | "guidepost" | "viewpoint" | "camera" | "us-football" | "football" | "tennis" | "binoculars" | "swimming" | "zap" | "battery-full" | "battery-half" | "battery-low" | "boom" | "radar" | "wind-turbine" | "solar-panel" | "antenna" | "telephone-pole" | "oil-well" | "oil-barrel" | "railroad-track" | "bridge" | "lighthouse" | "lock-closed" | "lock-open" | "wifi" | "trash" | "recycle" | "tree" | "flower" | "leaf" | "fire" | "mountain" | "snowy-mountain" | "volcano" | "island" | "wave" | "hot-springs" | "water" | "lake" | "ocean" | "animal" | "bird" | "duck" | "dog" | "fish" | "beach" | "wetland" | "sun" | "moon" | "cloud" | "partial-sun" | "rain" | "lightning" | "snowflake" | "wind" | "snow" | "fog" | "sleet" | "hurricane" | "warning" | "parking" | "info" | "circle-exclamation" | "circle-triangle" | "circle-x" | "circle-plus" | (`:${string}:` & {});

/**
 * The Tools controller allows you to let users draw elements on the map.
 *
 * @group Controller
 * @public
 */
interface ToolsController {
    /**
     * Sets the tool to use for drawing elements on the map.
     *
     * @param tool - The tool to set.
     *
     * @example
     * ```typescript
     * // Set the tool to "marker"
     * await felt.setTool("marker");
     *
     * // put down the tool
     * await felt.setTool(null);
     * ```
     */
    setTool(tool: ToolType | null): void;
    /**
     * Gets the current tool, if any is in use.
     *
     * @returns The current tool, or `null` if no tool is in use.
     *
     * @example
     * ```typescript
     * const tool = await felt.getTool(); // "marker", "polygon", etc.
     * ```
     */
    getTool(): Promise<ToolType | null>;
    /**
     * Listens for changes to the current tool.
     *
     * @returns A function to unsubscribe from the listener
     *
     * @example
     * ```typescript
     * const unsubscribe = felt.onToolChange({
     *   handler: tool => console.log(tool),
     * });
     *
     * // later on...
     * unsubscribe();
     * ```
     */
    onToolChange(args: {
        /**
         * This callback is called with the current tool whenever the tool changes.
         *
         * @param tool - The current tool, or `null` if no tool is in use.
         */
        handler: (tool: ToolType | null) => void;
    }): VoidFunction;
    /**
     * Sets the settings for the current tool.
     *
     * @example
     * ```typescript
     * // Set the settings for the marker tool
     * await felt.setToolSettings({
     *   tool: "marker",
     *   color: "#FE17",
     * });
     * ```
     *
     * @param settings - The settings to set.
     */
    setToolSettings(settings: InputToolSettings): void;
    /**
     * Gets the settings for the chosen tool
     *
     * @example
     * ```typescript
     * const settings = await felt.getToolSettings("marker");
     * ```
     *
     * @returns The settings for the chosen tool.
     */
    getToolSettings<T extends ConfigurableToolType>(tool: T): Promise<ToolSettingsMap[T]>;
    /**
     * Listens for changes to the settings on all tools.
     *
     * @example
     * ```typescript
     * const unsubscribe = felt.onToolSettingsChange({
     *   handler: settings => console.log(settings),
     * });
     *
     * // later on...
     * unsubscribe();
     * ```
     * @returns A function to unsubscribe from the listener
     */
    onToolSettingsChange(args: {
        handler: (settings: ToolSettingsChangeEvent) => void;
    }): VoidFunction;
}

/**
 * @public
 */
interface UiControlsOptions extends zInfer<typeof UiControlsOptionsSchema> {
}
/**
 * @internal
 * @ignore
 */
declare const UiControlsOptionsSchema: z.ZodObject<{
    /**
     * Whether or not the legend is shown.
     *
     * @defaultValue true
     */
    showLegend: z.ZodOptional<z.ZodBoolean>;
    /**
     * When co-operative gestures are enabled, the pan and zoom gestures are
     * adjusted to work better when the map is embedded in another page.
     *
     * @remarks
     * On mobile devices, enabling co-operative gestures will allow the user to
     * pan past the embedded map with a single finger drag. To pan the map, they
     * must use two fingers.
     *
     * On desktop devices, enabling co-operative gestures allows the user to
     * scroll past the embedded map using their scroll wheel or trackpad. To
     * zoom the map, they must hold the Ctrl (Windows) or Command key (Mac) while
     * scrolling.
     *
     * @defaultValue true
     */
    cooperativeGestures: z.ZodOptional<z.ZodBoolean>;
    /**
     * Whether or not the full screen button is shown in an embedded map.
     *
     * @remarks
     * When clicked, this will open the map in a new tab or window.
     *
     * @defaultValue true
     */
    fullScreenButton: z.ZodOptional<z.ZodBoolean>;
    /**
     * Whether or not the geolocation button is shown in an embedded map.
     *
     * @remarks
     * The geolocation feature will plot your position on the map. If you
     * click the button again, it will start tracking your position.
     *
     * @defaultValue false
     */
    geolocation: z.ZodOptional<z.ZodBoolean>;
    /**
     * Whether or not the zoom controls are shown in an embedded map.
     *
     * @remarks
     * This does not affect whether or not the map can be zoomed, just
     * the display of the zoom controls in the bottom right corner of the map.
     *
     * @defaultValue true
     */
    zoomControls: z.ZodOptional<z.ZodBoolean>;
    /**
     * Whether or not the scale bar is shown in an embedded map.
     *
     * @defaultValue true
     */
    scaleBar: z.ZodOptional<z.ZodBoolean>;
}, "strip", z.ZodTypeAny, {
    showLegend?: boolean | undefined;
    cooperativeGestures?: boolean | undefined;
    fullScreenButton?: boolean | undefined;
    geolocation?: boolean | undefined;
    zoomControls?: boolean | undefined;
    scaleBar?: boolean | undefined;
}, {
    showLegend?: boolean | undefined;
    cooperativeGestures?: boolean | undefined;
    fullScreenButton?: boolean | undefined;
    geolocation?: boolean | undefined;
    zoomControls?: boolean | undefined;
    scaleBar?: boolean | undefined;
}>;
/**
 * The options for which parts of the Felt UI can be shown when interacting with
 * features and elements on the map.
 *
 * Switching these off can be useful if you add your own click, selection or hover
 * handlers for features and elements.
 *
 * @public
 */
interface UiOnMapInteractionsOptions extends zInfer<typeof UiOnMapInteractionsOptionsSchema> {
}
/**
 * @internal
 * @ignore
 */
declare const UiOnMapInteractionsOptionsSchema: z.ZodObject<{
    /**
     * Set this to `false` to prevent the panel that shows information about a selected
     * feature from being shown.
     */
    featureSelectPanel: z.ZodOptional<z.ZodBoolean>;
    /**
     * Set this to `false` to prevent the panel that shows information about a hovered
     * feature from being shown.
     */
    featureHoverPanel: z.ZodOptional<z.ZodBoolean>;
    /**
     * Set this to `false` to prevent the panel that shows information about a selected
     * element from being shown.
     */
    elementSelectPanel: z.ZodOptional<z.ZodBoolean>;
    /**
     * Set this to `false` to prevent clicking on a map link element from opening that link
     * in a new tab or window.
     */
    linkClickOpen: z.ZodOptional<z.ZodBoolean>;
    /**
     * Set this to `false` to prevent clicking on an image element from opening the image
     * in a lightbox.
     */
    imageLightboxOpen: z.ZodOptional<z.ZodBoolean>;
}, "strip", z.ZodTypeAny, {
    featureSelectPanel?: boolean | undefined;
    featureHoverPanel?: boolean | undefined;
    elementSelectPanel?: boolean | undefined;
    linkClickOpen?: boolean | undefined;
    imageLightboxOpen?: boolean | undefined;
}, {
    featureSelectPanel?: boolean | undefined;
    featureHoverPanel?: boolean | undefined;
    elementSelectPanel?: boolean | undefined;
    linkClickOpen?: boolean | undefined;
    imageLightboxOpen?: boolean | undefined;
}>;

/**
 * The UI controller allows you to control various aspects of the Felt UI in your embedded map.
 *
 * This includes enabling/disabling UI controls, managing on-map interactions, and controlling
 * the visibility of UI components like the data table.
 *
 * @group Controller
 * @public
 */
interface UiController {
    /**
     * Updates the UI controls on the embedded map.
     *
     * @example
     * ```typescript
     * // Show some UI controls
     * await felt.updateUiControls({
     *   showLegend: true,
     *   fullScreenButton: true,
     * });
     *
     * // Disable some UI options
     * await felt.updateUiControls({
     *   cooperativeGestures: false,
     *   geolocation: false,
     * });
     * ```
     *
     * @param controls - The controls to update.
     */
    updateUiControls(controls: UiControlsOptions): void;
    /**
     * Control the on-map UI shown when interacting with features and elements.
     *
     * If you add your own click, selection or hover handlers you may want to disable
     * various parts of the Felt UI. This method allows you to control the visibility of
     * various parts of the UI that might otherwise be shown when people click or hover
     * on things.
     *
     * This does not affect selection. That means that selectable features and elements
     * will still be selected when clicked.
     *
     * @example
     * ```typescript
     * // Disable UI when hovering or selecting features
     * await felt.setOnMapInteractionsUi({
     *   featureSelectPanel: false,
     *   featureHoverPanel: false,
     * });
     * ```
     */
    setOnMapInteractionsUi(options: UiOnMapInteractionsOptions): void;
    /**
     * Shows a data table view for the specified layer, optionally sorted by a given attribute.
     *
     * @example
     * ```typescript
     * // Show data table with default sorting
     * await felt.showLayerDataTable({
     *   layerId: "layer-1",
     * });
     *
     * // Show data table sorted by height in descending order
     * await felt.showLayerDataTable({
     *   layerId: "layer-1",
     *   sorting: {
     *     attribute: "height",
     *     direction: "desc",
     *   },
     * });
     *
     * // Show the data table pane with no table visible
     * await felt.showLayerDataTable();
     * ```
     */
    showLayerDataTable(params?: {
        layerId: string;
        sorting?: SortConfig;
    }): Promise<void>;
    /**
     * Hides the data table.
     *
     * @example
     * ```typescript
     * await felt.hideLayerDataTable();
     * ```
     */
    hideLayerDataTable(): Promise<void>;
}

/**
 * The input type for setting the viewport to a particular center and zoom.
 *
 * @group Types
 */
interface ViewportCenterZoom extends zInfer<typeof ViewportCenterZoomSchema> {
    /**
     * The center of the viewport in latitude and longitude.
     */
    center: LatLng;
    /**
     * The zoom level of the viewport.
     */
    zoom: FeltZoom;
}
declare const ViewportCenterZoomSchema: z.ZodObject<{
    center: z.ZodObject<{
        latitude: z.ZodNumber;
        longitude: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        latitude: number;
        longitude: number;
    }, {
        latitude: number;
        longitude: number;
    }>;
    zoom: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    center: {
        latitude: number;
        longitude: number;
    };
    zoom: number;
}, {
    center: {
        latitude: number;
        longitude: number;
    };
    zoom: number;
}>;
/**
 * The current state of the viewport, including the derived bounds.
 *
 * @group Types
 */
interface ViewportState {
    /**
     * The center of the viewport in latitude and longitude.
     *
     * {@link LatLng}
     */
    center: LatLng;
    /**
     * The zoom level of the viewport.
     *
     * {@link FeltZoom}
     */
    zoom: FeltZoom;
    /**
     * The bounding box of the viewport in [west, south, east, north] order.
     *
     * This is derived, and depends on the center and zoom of the viewport, as
     * well as its size.
     *
     * {@link FeltBoundary}
     */
    bounds: FeltBoundary;
}
/**
 * The parameters for the {@link ViewportController.setViewport | `setViewport`} method.
 *
 * @group Types
 */
interface SetViewportCenterZoomParams extends zInfer<typeof SetViewportCenterZoomParamsSchema> {
}
declare const SetViewportCenterZoomParamsSchema: z.ZodObject<{
    center: z.ZodOptional<z.ZodObject<{
        latitude: z.ZodNumber;
        longitude: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        latitude: number;
        longitude: number;
    }, {
        latitude: number;
        longitude: number;
    }>>;
    zoom: z.ZodOptional<z.ZodNumber>;
}, "strip", z.ZodTypeAny, {
    center?: {
        latitude: number;
        longitude: number;
    } | undefined;
    zoom?: number | undefined;
}, {
    center?: {
        latitude: number;
        longitude: number;
    } | undefined;
    zoom?: number | undefined;
}>;
/**
 * The constraints for the viewport. Used to ensure that the viewport stays
 * within certain bounds and zoom levels.
 *
 * @group Types
 */
interface ViewportConstraints {
    /**
     * The minimum zoom level for the viewport.
     *
     * {@link FeltZoom}
     */
    minZoom: FeltZoom | null;
    /**
     * The maximum zoom level for the viewport.
     *
     * {@link FeltZoom}
     */
    maxZoom: FeltZoom | null;
    /**
     * The bounds for the viewport.
     *
     * {@link FeltBoundary}
     */
    bounds: FeltBoundary | null;
}
/**
 * The parameters for the {@link ViewportController.fitViewportToBounds | `fitViewportToBounds`} method.
 *
 * @group Types
 */
interface ViewportFitBoundsParams extends zInfer<typeof ViewportFitBoundsParamsSchema> {
    /**
     * The bounds to fit the viewport to.
     *
     * {@link FeltBoundary}
     */
    bounds: FeltBoundary;
}
declare const ViewportFitBoundsParamsSchema: z.ZodObject<{
    bounds: z.ZodTuple<[z.ZodNumber, z.ZodNumber, z.ZodNumber, z.ZodNumber], null>;
}, "strip", z.ZodTypeAny, {
    bounds: [number, number, number, number];
}, {
    bounds: [number, number, number, number];
}>;

/**
 * The viewport controller allows you to control the viewport of the map.
 *
 * You can get the current viewport, move the viewport, and be notified when
 * the viewport changes.
 *
 * @group Controller
 * @public
 */
interface ViewportController {
    /**
     * Gets the current state of the viewport.
     *
     * @example
     * ```typescript
     * // Get current viewport state
     * const viewport = await felt.getViewport();
     * console.log({
     *   center: viewport.center,
     *   zoom: viewport.zoom,
     * });
     * ```
     */
    getViewport(): Promise<ViewportState>;
    /**
     * Moves the map to the specified location.
     *
     * @example
     * ```typescript
     * felt.setViewport({
     *   center: { latitude: 0, longitude: 0 },
     *   zoom: 10,
     * });
     * ```
     */
    setViewport(viewport: SetViewportCenterZoomParams): void;
    /**
     * Gets the current state of the viewport constraints.
     *
     * @example
     * ```typescript
     * // Get current viewport constraints
     * const constraints = await felt.getViewportConstraints();
     * if (constraints) {
     *   console.log({
     *     bounds: constraints.bounds,
     *     minZoom: constraints.minZoom,
     *     maxZoom: constraints.maxZoom
     *   });
     * } else {
     *   console.log("No viewport constraints set");
     * }
     * ```
     */
    getViewportConstraints(): Promise<ViewportConstraints | null>;
    /**
     * Constrains the map viewport so it stays inside certain bounds and/or certain zoom levels.
     *
     * @example
     * ```typescript
     * felt.setViewportConstraints({
     *   bounds: [-122.5372532, 37.6652478, -122.1927016, 37.881707],
     *   minZoom: 1,
     *   maxZoom: 23,
     * });
     * ```
     *
     * @example
     * every constraint is optional
     * ```typescript
     * felt.setViewportConstraints({
     *   bounds: [-122.5372532, 37.6652478, -122.1927016, 37.881707],
     * });
     * ```
     *
     * @example
     * if a constraint is null, it will be removed but keeping the others
     * ```typescript
     * felt.setViewportConstraints({ bounds: null });
     * ```
     *
     * @example
     * if method receives null, it will remove the constraints
     * ```typescript
     * felt.setViewportConstraints(null);
     * ```
     */
    setViewportConstraints(constraints: Partial<ViewportConstraints> | null): void;
    /**
     * Fits the map to the specified bounds.
     *
     * @example
     * ```typescript
     * const west = -122.4194;
     * const south = 37.7749;
     * const east = -122.4194;
     * const north = 37.7749;
     * felt.fitViewportToBounds({ bounds: [west, south, east, north] });
     * ```
     */
    fitViewportToBounds(bounds: ViewportFitBoundsParams): void;
    /**
     * Adds a listener for when the viewport changes.
     *
     * @returns A function to unsubscribe from the listener
     *
     * @event
     * @example
     * ```typescript
     * const unsubscribe = felt.onViewportMove({
     *   handler: viewport => console.log(viewport.center.latitude),
     * });
     *
     * // later on...
     * unsubscribe();
     * ```
     */
    onViewportMove(args: {
        /**
         * This callback is called with the current viewport state whenever
         * the viewport changes.
         *
         * @param viewport - The current viewport state.
         */
        handler: (viewport: ViewportState) => void;
    }): VoidFunction;
    /**
     * Adds a listener for when the viewport move ends, which is when the user
     * stops dragging or zooming the map, animations have finished, or inertial
     * dragging ends.
     *
     * @returns A function to unsubscribe from the listener
     *
     * @event
     * @example
     * ```typescript
     * const unsubscribe = felt.onViewportMoveEnd({
     *   handler: viewport => console.log(viewport.center.latitude),
     * });
     *
     * // later on...
     * unsubscribe();
     * ```
     */
    onViewportMoveEnd(args: {
        handler: (viewport: ViewportState) => void;
    }): VoidFunction;
    /**
     * Adds a listener for when the map is idle, which is defined as:
     * - No transitions are in progress
     * - The user is not interacting with the map, e.g. by panning or zooming
     * - All tiles for the current viewport have been loaded
     * - Any fade transitions (e.g. for labels) have completed
     *
     * @returns A function to unsubscribe from the listener
     *
     * @event
     * @example
     * ```typescript
     * const unsubscribe = felt.onMapIdle({ handler: () => console.log("map is idle") });
     *
     * // later on...
     * unsubscribe();
     * ```
     */
    onMapIdle(args: {
        handler: () => void;
    }): VoidFunction;
}

/**
 * This is the main interface for interacting with a Felt map.
 *
 * This interface is composed of the various controllers, each having a
 * different area of responsibility.
 *
 * All the methods are listed here, but each controller is documented on its
 * own to make it easier to find related methods and events.
 *
 * @group Controller
 * @public
 */
interface FeltController extends ViewportController, UiController, LayersController, ElementsController, SelectionController, InteractionsController, ToolsController, InteractionsController, MiscController {
    /**
     * The iframe element containing the Felt map, if it is an embedded map.
     *
     * @readonly
     */
    iframe: HTMLIFrameElement | null;
}

export type { LayerChangeCallbackParams as $, TextElementUpdate as A, ElementsController as B, CircleElementCreate as C, MapInteractionEvent as D, Element as E, FeltController as F, GetElementGroupsConstraint as G, HighlighterElementCreate as H, ImageElementCreate as I, InteractionsController as J, CreateLayersFromGeoJsonParams as K, LinkElementRead as L, MarkerElementCreate as M, NoteElementCreate as N, DataOnlyLayer as O, PathElementCreate as P, FeltTiledVectorSource as Q, GeoJsonDataVectorSource as R, GeoJsonFileVectorSource as S, TextElementCreate as T, UiControlsOptions as U, ViewportCenterZoom as V, GeoJsonUrlVectorSource as W, GetLayerGroupsConstraint as X, GetLayersConstraint as Y, GetRenderedFeaturesConstraint as Z, Layer as _, CircleElementRead as a, SetVisibilityRequest as a$, LayerCommon as a0, LayerGroup as a1, LayerGroupChangeCallbackParams as a2, LayerProcessingStatus as a3, LegendItem as a4, LegendItemChangeCallbackParams as a5, LegendItemIdentifier as a6, LegendItemsConstraint as a7, RasterBand as a8, RasterLayer as a9, GetLayerHistogramParams as aA, MultiAggregationConfig as aB, ValueConfiguration as aC, LayersController as aD, MapDetails as aE, MiscController as aF, ElementGroupNode as aG, ElementNode as aH, EntityNode as aI, FeatureNode as aJ, FeatureSelection as aK, LayerGroupNode as aL, LayerNode as aM, SelectionController as aN, FeltBoundary as aO, FeltZoom as aP, GeoJsonFeature as aQ, GeoJsonGeometry as aR, GeoJsonProperties as aS, LatLng as aT, LineStringGeometry as aU, LngLatTuple as aV, MultiLineStringGeometry as aW, MultiPointGeometry as aX, MultiPolygonGeometry as aY, PointGeometry as aZ, PolygonGeometry as a_, RasterLayerSource as aa, UpdateLayerParams as ab, VectorLayer as ac, LayerFeature as ad, RasterValue as ae, LayerSchema as af, LayerSchemaAttribute as ag, LayerSchemaBooleanAttribute as ah, LayerSchemaCommonAttribute as ai, LayerSchemaDateAttribute as aj, LayerSchemaDateTimeAttribute as ak, LayerSchemaNumericAttribute as al, LayerSchemaTextAttribute as am, FilterExpression as an, FilterLogicGate as ao, FilterTernary as ap, Filters as aq, GeometryFilter as ar, LayerBoundaries as as, LayerFilters as at, AggregationConfig as au, AggregationMethod as av, GetLayerCalculationParams as aw, GetLayerCategoriesGroup as ax, GetLayerCategoriesParams as ay, GetLayerHistogramBin as az, CircleElementUpdate as b, SortConfig as b0, SortDirection as b1, CircleToolSettings as b2, ConfigurableToolType as b3, HighlighterToolSettings as b4, InputToolSettings as b5, LineToolSettings as b6, MarkerToolSettings as b7, NoteToolSettings as b8, PinToolSettings as b9, PlaceFrame as ba, PlaceSymbol as bb, PolygonToolSettings as bc, RouteToolSettings as bd, TextToolSettings as be, ToolSettingsChangeEvent as bf, ToolSettingsMap as bg, ToolType as bh, ToolsController as bi, UiOnMapInteractionsOptions as bj, UiController as bk, SetViewportCenterZoomParams as bl, ViewportConstraints as bm, ViewportFitBoundsParams as bn, ViewportState as bo, ViewportController as bp, UnwrapPromise as bq, UnionToIntersection as br, PromiseOrNot as bs, ElementChangeCallbackParams as c, ElementCreate as d, ElementGroup as e, ElementGroupChangeCallbackParams as f, ElementUpdate as g, GetElementsConstraint as h, HighlighterElementRead as i, HighlighterElementUpdate as j, ImageElementRead as k, ImageElementUpdate as l, MarkerElementRead as m, MarkerElementUpdate as n, NoteElementRead as o, NoteElementUpdate as p, PathElementRead as q, PathElementUpdate as r, PlaceElementCreate as s, PlaceElementRead as t, PlaceElementUpdate as u, PolygonElementCreate as v, PolygonElementRead as w, PolygonElementUpdate as x, TextElementRead as y, zInfer as z };
